Class: StickyIoRestfulApiV2025731::AddCustomFieldValuesRequestAddCustomFieldValues

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/add_custom_field_values_request_add_custom_field_values.rb

Overview

AddCustomFieldValuesRequestAddCustomFieldValues Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(custom_fields:, additional_properties: nil) ⇒ AddCustomFieldValuesRequestAddCustomFieldValues

Returns a new instance of AddCustomFieldValuesRequestAddCustomFieldValues.



33
34
35
36
37
38
39
# File 'lib/sticky_io_restful_api_v2025731/models/add_custom_field_values_request_add_custom_field_values.rb', line 33

def initialize(custom_fields:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @custom_fields = custom_fields
  @additional_properties = additional_properties
end

Instance Attribute Details

#custom_fieldsArray[CustomFieldAddCustomFieldValuesRequest1]

TODO: Write general description for this method



14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/add_custom_field_values_request_add_custom_field_values.rb', line 14

def custom_fields
  @custom_fields
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/sticky_io_restful_api_v2025731/models/add_custom_field_values_request_add_custom_field_values.rb', line 42

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  custom_fields = nil
  unless hash['custom_fields'].nil?
    custom_fields = []
    hash['custom_fields'].each do |structure|
      custom_fields << (CustomFieldAddCustomFieldValuesRequest1.from_hash(structure) if structure)
    end
  end

  custom_fields = nil unless hash.key?('custom_fields')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AddCustomFieldValuesRequestAddCustomFieldValues.new(custom_fields: custom_fields,
                                                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/sticky_io_restful_api_v2025731/models/add_custom_field_values_request_add_custom_field_values.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['custom_fields'] = 'custom_fields'
  @_hash
end

.nullablesObject

An array for nullable fields



29
30
31
# File 'lib/sticky_io_restful_api_v2025731/models/add_custom_field_values_request_add_custom_field_values.rb', line 29

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
# File 'lib/sticky_io_restful_api_v2025731/models/add_custom_field_values_request_add_custom_field_values.rb', line 24

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



77
78
79
80
81
# File 'lib/sticky_io_restful_api_v2025731/models/add_custom_field_values_request_add_custom_field_values.rb', line 77

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} custom_fields: #{@custom_fields.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
74
# File 'lib/sticky_io_restful_api_v2025731/models/add_custom_field_values_request_add_custom_field_values.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} custom_fields: #{@custom_fields}, additional_properties:"\
  " #{@additional_properties}>"
end