Class: StickyIoRestfulApiV2025731::AddProductAttributes
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::AddProductAttributes
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/add_product_attributes.rb
Overview
AddProductAttributes Model.
Instance Attribute Summary collapse
-
#data ⇒ Array[DataAddProductAttributes]
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(status:, data:, additional_properties: nil) ⇒ AddProductAttributes
constructor
A new instance of AddProductAttributes.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(status:, data:, additional_properties: nil) ⇒ AddProductAttributes
Returns a new instance of AddProductAttributes.
38 39 40 41 42 43 44 45 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_product_attributes.rb', line 38 def initialize(status:, data:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @status = status @data = data @additional_properties = additional_properties end |
Instance Attribute Details
#data ⇒ Array[DataAddProductAttributes]
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_product_attributes.rb', line 18 def data @data end |
#status ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_product_attributes.rb', line 14 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_product_attributes.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. status = hash.key?('status') ? hash['status'] : nil # Parameter is an array, so we need to iterate through it data = nil unless hash['data'].nil? data = [] hash['data'].each do |structure| data << (DataAddProductAttributes.from_hash(structure) if structure) end end data = nil unless hash.key?('data') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AddProductAttributes.new(status: status, data: data, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_product_attributes.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['status'] = 'status' @_hash['data'] = 'data' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_product_attributes.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_product_attributes.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_product_attributes.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} status: #{@status.inspect}, data: #{@data.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_product_attributes.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} status: #{@status}, data: #{@data}, additional_properties:"\ " #{@additional_properties}>" end |