Class: StickyIoRestfulApiV2025731::AddProductAttributesRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/add_product_attributes_request.rb

Overview

AddProductAttributesRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(auto_create_variants:, attributes:, additional_properties: nil) ⇒ AddProductAttributesRequest

Returns a new instance of AddProductAttributesRequest.



38
39
40
41
42
43
44
45
46
# File 'lib/sticky_io_restful_api_v2025731/models/add_product_attributes_request.rb', line 38

def initialize(auto_create_variants:, attributes:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @auto_create_variants = auto_create_variants
  @attributes = attributes
  @additional_properties = additional_properties
end

Instance Attribute Details

#attributesArray[Attribute]

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/add_product_attributes_request.rb', line 18

def attributes
  @attributes
end

#auto_create_variantsInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/add_product_attributes_request.rb', line 14

def auto_create_variants
  @auto_create_variants
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/sticky_io_restful_api_v2025731/models/add_product_attributes_request.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  auto_create_variants =
    hash.key?('auto_create_variants') ? hash['auto_create_variants'] : nil
  # Parameter is an array, so we need to iterate through it
  attributes = nil
  unless hash['attributes'].nil?
    attributes = []
    hash['attributes'].each do |structure|
      attributes << (Attribute.from_hash(structure) if structure)
    end
  end

  attributes = nil unless hash.key?('attributes')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AddProductAttributesRequest.new(auto_create_variants: auto_create_variants,
                                  attributes: attributes,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/sticky_io_restful_api_v2025731/models/add_product_attributes_request.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['auto_create_variants'] = 'auto_create_variants'
  @_hash['attributes'] = 'attributes'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/add_product_attributes_request.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/sticky_io_restful_api_v2025731/models/add_product_attributes_request.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



87
88
89
90
91
# File 'lib/sticky_io_restful_api_v2025731/models/add_product_attributes_request.rb', line 87

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} auto_create_variants: #{@auto_create_variants.inspect}, attributes:"\
  " #{@attributes.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
84
# File 'lib/sticky_io_restful_api_v2025731/models/add_product_attributes_request.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} auto_create_variants: #{@auto_create_variants}, attributes: #{@attributes},"\
  " additional_properties: #{@additional_properties}>"
end