Class: StickyIoRestfulApiV2025731::AddProfileRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/add_profile_request.rb

Overview

AddProfileRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(malias:, currency:, fields:, additional_properties: nil) ⇒ AddProfileRequest

Returns a new instance of AddProfileRequest.



43
44
45
46
47
48
49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/add_profile_request.rb', line 43

def initialize(malias:, currency:, fields:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @malias = malias
  @currency = currency
  @fields = fields
  @additional_properties = additional_properties
end

Instance Attribute Details

#currencyInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/add_profile_request.rb', line 18

def currency
  @currency
end

#fieldsFields

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/add_profile_request.rb', line 22

def fields
  @fields
end

#maliasString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/add_profile_request.rb', line 14

def malias
  @malias
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/sticky_io_restful_api_v2025731/models/add_profile_request.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  malias = hash.key?('alias') ? hash['alias'] : nil
  currency = hash.key?('currency') ? hash['currency'] : nil
  fields = Fields.from_hash(hash['fields']) if hash['fields']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AddProfileRequest.new(malias: malias,
                        currency: currency,
                        fields: fields,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/sticky_io_restful_api_v2025731/models/add_profile_request.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['malias'] = 'alias'
  @_hash['currency'] = 'currency'
  @_hash['fields'] = 'fields'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/sticky_io_restful_api_v2025731/models/add_profile_request.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/add_profile_request.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



84
85
86
87
88
# File 'lib/sticky_io_restful_api_v2025731/models/add_profile_request.rb', line 84

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} malias: #{@malias.inspect}, currency: #{@currency.inspect}, fields:"\
  " #{@fields.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



77
78
79
80
81
# File 'lib/sticky_io_restful_api_v2025731/models/add_profile_request.rb', line 77

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} malias: #{@malias}, currency: #{@currency}, fields: #{@fields},"\
  " additional_properties: #{@additional_properties}>"
end