Class: StickyIoRestfulApiV2025731::AddVolumeDiscountRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::AddVolumeDiscountRequest
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/add_volume_discount_request.rb
Overview
AddVolumeDiscountRequest Model.
Instance Attribute Summary collapse
-
#apply_to_type_id ⇒ Integer
TODO: Write general description for this method.
-
#description ⇒ String
TODO: Write general description for this method.
-
#is_exclude_non_recurring ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#products ⇒ Array[Integer]
TODO: Write general description for this method.
-
#quantities ⇒ Array[QuantityAddVolumeDiscountRequest]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name:, description:, quantities:, products:, is_exclude_non_recurring:, apply_to_type_id:, additional_properties: nil) ⇒ AddVolumeDiscountRequest
constructor
A new instance of AddVolumeDiscountRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name:, description:, quantities:, products:, is_exclude_non_recurring:, apply_to_type_id:, additional_properties: nil) ⇒ AddVolumeDiscountRequest
Returns a new instance of AddVolumeDiscountRequest.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_volume_discount_request.rb', line 58 def initialize(name:, description:, quantities:, products:, is_exclude_non_recurring:, apply_to_type_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name @description = description @quantities = quantities @products = products @is_exclude_non_recurring = is_exclude_non_recurring @apply_to_type_id = apply_to_type_id @additional_properties = additional_properties end |
Instance Attribute Details
#apply_to_type_id ⇒ Integer
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_volume_discount_request.rb', line 34 def apply_to_type_id @apply_to_type_id end |
#description ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_volume_discount_request.rb', line 18 def description @description end |
#is_exclude_non_recurring ⇒ TrueClass | FalseClass
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_volume_discount_request.rb', line 30 def is_exclude_non_recurring @is_exclude_non_recurring end |
#name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_volume_discount_request.rb', line 14 def name @name end |
#products ⇒ Array[Integer]
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_volume_discount_request.rb', line 26 def products @products end |
#quantities ⇒ Array[QuantityAddVolumeDiscountRequest]
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_volume_discount_request.rb', line 22 def quantities @quantities end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_volume_discount_request.rb', line 74 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil description = hash.key?('description') ? hash['description'] : nil # Parameter is an array, so we need to iterate through it quantities = nil unless hash['quantities'].nil? quantities = [] hash['quantities'].each do |structure| quantities << (QuantityAddVolumeDiscountRequest.from_hash(structure) if structure) end end quantities = nil unless hash.key?('quantities') products = hash.key?('products') ? hash['products'] : nil is_exclude_non_recurring = hash.key?('is_exclude_non_recurring') ? hash['is_exclude_non_recurring'] : nil apply_to_type_id = hash.key?('apply_to_type_id') ? hash['apply_to_type_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AddVolumeDiscountRequest.new(name: name, description: description, quantities: quantities, products: products, is_exclude_non_recurring: is_exclude_non_recurring, apply_to_type_id: apply_to_type_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_volume_discount_request.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['description'] = 'description' @_hash['quantities'] = 'quantities' @_hash['products'] = 'products' @_hash['is_exclude_non_recurring'] = 'is_exclude_non_recurring' @_hash['apply_to_type_id'] = 'apply_to_type_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_volume_discount_request.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_volume_discount_request.rb', line 49 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
122 123 124 125 126 127 128 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_volume_discount_request.rb', line 122 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, description: #{@description.inspect}, quantities:"\ " #{@quantities.inspect}, products: #{@products.inspect}, is_exclude_non_recurring:"\ " #{@is_exclude_non_recurring.inspect}, apply_to_type_id: #{@apply_to_type_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
114 115 116 117 118 119 |
# File 'lib/sticky_io_restful_api_v2025731/models/add_volume_discount_request.rb', line 114 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, description: #{@description}, quantities: #{@quantities},"\ " products: #{@products}, is_exclude_non_recurring: #{@is_exclude_non_recurring},"\ " apply_to_type_id: #{@apply_to_type_id}, additional_properties: #{@additional_properties}>" end |