Class: StickyIoRestfulApiV2025731::AlternativePayment

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/alternative_payment.rb

Overview

AlternativePayment Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(provider:, payment_method:, additional_properties: nil) ⇒ AlternativePayment

Returns a new instance of AlternativePayment.



38
39
40
41
42
43
44
45
# File 'lib/sticky_io_restful_api_v2025731/models/alternative_payment.rb', line 38

def initialize(provider:, payment_method:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @provider = provider
  @payment_method = payment_method
  @additional_properties = additional_properties
end

Instance Attribute Details

#payment_methodString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/alternative_payment.rb', line 18

def payment_method
  @payment_method
end

#providerProvider

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/alternative_payment.rb', line 14

def provider
  @provider
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/sticky_io_restful_api_v2025731/models/alternative_payment.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  provider = Provider.from_hash(hash['provider']) if hash['provider']
  payment_method =
    hash.key?('payment_method') ? hash['payment_method'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AlternativePayment.new(provider: provider,
                         payment_method: payment_method,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/sticky_io_restful_api_v2025731/models/alternative_payment.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['provider'] = 'provider'
  @_hash['payment_method'] = 'payment_method'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/alternative_payment.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/sticky_io_restful_api_v2025731/models/alternative_payment.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



77
78
79
80
81
# File 'lib/sticky_io_restful_api_v2025731/models/alternative_payment.rb', line 77

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} provider: #{@provider.inspect}, payment_method: #{@payment_method.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
74
# File 'lib/sticky_io_restful_api_v2025731/models/alternative_payment.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} provider: #{@provider}, payment_method: #{@payment_method},"\
  " additional_properties: #{@additional_properties}>"
end