Class: StickyIoRestfulApiV2025731::BillingModelData5
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::BillingModelData5
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb
Overview
BillingModelData5 Model.
Instance Attribute Summary collapse
-
#buffer_days ⇒ Integer
TODO: Write general description for this method.
-
#created_at ⇒ CreatedAt
TODO: Write general description for this method.
-
#creator ⇒ Creator
TODO: Write general description for this method.
-
#discount ⇒ String
TODO: Write general description for this method.
-
#expire_cycles ⇒ Integer
TODO: Write general description for this method.
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#type ⇒ TypeBillingModel
TODO: Write general description for this method.
-
#updated_at ⇒ Object
TODO: Write general description for this method.
-
#updator ⇒ Object
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(id:, name:, expire_cycles:, buffer_days:, created_at:, updated_at:, type:, creator:, updator:, discount:, additional_properties: nil) ⇒ BillingModelData5
constructor
A new instance of BillingModelData5.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, name:, expire_cycles:, buffer_days:, created_at:, updated_at:, type:, creator:, updator:, discount:, additional_properties: nil) ⇒ BillingModelData5
Returns a new instance of BillingModelData5.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb', line 80 def initialize(id:, name:, expire_cycles:, buffer_days:, created_at:, updated_at:, type:, creator:, updator:, discount:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @name = name @expire_cycles = expire_cycles @buffer_days = buffer_days @created_at = created_at @updated_at = updated_at @type = type @creator = creator @updator = updator @discount = discount @additional_properties = additional_properties end |
Instance Attribute Details
#buffer_days ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb', line 26 def buffer_days @buffer_days end |
#created_at ⇒ CreatedAt
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb', line 30 def created_at @created_at end |
#creator ⇒ Creator
TODO: Write general description for this method
42 43 44 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb', line 42 def creator @creator end |
#discount ⇒ String
TODO: Write general description for this method
50 51 52 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb', line 50 def discount @discount end |
#expire_cycles ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb', line 22 def expire_cycles @expire_cycles end |
#id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb', line 14 def id @id end |
#name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb', line 18 def name @name end |
#type ⇒ TypeBillingModel
TODO: Write general description for this method
38 39 40 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb', line 38 def type @type end |
#updated_at ⇒ Object
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb', line 34 def updated_at @updated_at end |
#updator ⇒ Object
TODO: Write general description for this method
46 47 48 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb', line 46 def updator @updator end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb', line 100 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil name = hash.key?('name') ? hash['name'] : nil expire_cycles = hash.key?('expire_cycles') ? hash['expire_cycles'] : nil buffer_days = hash.key?('buffer_days') ? hash['buffer_days'] : nil created_at = CreatedAt.from_hash(hash['created_at']) if hash['created_at'] updated_at = hash.key?('updated_at') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:BillingModelData5UpdatedAt), hash['updated_at'] ) : nil type = TypeBillingModel.from_hash(hash['type']) if hash['type'] creator = Creator.from_hash(hash['creator']) if hash['creator'] updator = hash.key?('updator') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:BillingModelData5Updator), hash['updator'] ) : nil discount = hash.key?('discount') ? hash['discount'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BillingModelData5.new(id: id, name: name, expire_cycles: expire_cycles, buffer_days: buffer_days, created_at: created_at, updated_at: updated_at, type: type, creator: creator, updator: updator, discount: discount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb', line 53 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['name'] = 'name' @_hash['expire_cycles'] = 'expire_cycles' @_hash['buffer_days'] = 'buffer_days' @_hash['created_at'] = 'created_at' @_hash['updated_at'] = 'updated_at' @_hash['type'] = 'type' @_hash['creator'] = 'creator' @_hash['updator'] = 'updator' @_hash['discount'] = 'discount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
74 75 76 77 78 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb', line 74 def self.nullables %w[ discount ] end |
.optionals ⇒ Object
An array for optional fields
69 70 71 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb', line 69 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb', line 142 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.id, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.name, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.expire_cycles, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.buffer_days, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.created_at, ->(val) { CreatedAt.validate(val) }, is_model_hash: true) and UnionTypeLookUp.get(:BillingModelData5UpdatedAt) .validate(value.updated_at) and APIHelper.valid_type?(value.type, ->(val) { TypeBillingModel.validate(val) }, is_model_hash: true) and APIHelper.valid_type?(value.creator, ->(val) { Creator.validate(val) }, is_model_hash: true) and UnionTypeLookUp.get(:BillingModelData5Updator) .validate(value.updator) and APIHelper.valid_type?(value.discount, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['id'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['name'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['expire_cycles'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['buffer_days'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['created_at'], ->(val) { CreatedAt.validate(val) }, is_model_hash: true) and UnionTypeLookUp.get(:BillingModelData5UpdatedAt) .validate(value['updated_at']) and APIHelper.valid_type?(value['type'], ->(val) { TypeBillingModel.validate(val) }, is_model_hash: true) and APIHelper.valid_type?(value['creator'], ->(val) { Creator.validate(val) }, is_model_hash: true) and UnionTypeLookUp.get(:BillingModelData5Updator) .validate(value['updator']) and APIHelper.valid_type?(value['discount'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
210 211 212 213 214 215 216 217 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb', line 210 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, expire_cycles:"\ " #{@expire_cycles.inspect}, buffer_days: #{@buffer_days.inspect}, created_at:"\ " #{@created_at.inspect}, updated_at: #{@updated_at.inspect}, type: #{@type.inspect},"\ " creator: #{@creator.inspect}, updator: #{@updator.inspect}, discount:"\ " #{@discount.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
201 202 203 204 205 206 207 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data5.rb', line 201 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, name: #{@name}, expire_cycles: #{@expire_cycles}, buffer_days:"\ " #{@buffer_days}, created_at: #{@created_at}, updated_at: #{@updated_at}, type: #{@type},"\ " creator: #{@creator}, updator: #{@updator}, discount: #{@discount}, additional_properties:"\ " #{@additional_properties}>" end |