Class: StickyIoRestfulApiV2025731::BillingModelOffer

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb

Overview

BillingModelOffer Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, name:, expire_cycles:, buffer_days:, created_at:, updated_at:, type:, creator:, updator:, discount:, additional_properties: nil) ⇒ BillingModelOffer

Returns a new instance of BillingModelOffer.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb', line 80

def initialize(id:, name:, expire_cycles:, buffer_days:, created_at:,
               updated_at:, type:, creator:, updator:, discount:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @name = name
  @expire_cycles = expire_cycles
  @buffer_days = buffer_days
  @created_at = created_at
  @updated_at = updated_at
  @type = type
  @creator = creator
  @updator = updator
  @discount = discount
  @additional_properties = additional_properties
end

Instance Attribute Details

#buffer_daysInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb', line 26

def buffer_days
  @buffer_days
end

#created_atCreatedAt

TODO: Write general description for this method

Returns:



30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb', line 30

def created_at
  @created_at
end

#creatorCreator

TODO: Write general description for this method

Returns:



42
43
44
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb', line 42

def creator
  @creator
end

#discountDiscount

TODO: Write general description for this method

Returns:



50
51
52
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb', line 50

def discount
  @discount
end

#expire_cyclesInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb', line 22

def expire_cycles
  @expire_cycles
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb', line 14

def id
  @id
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb', line 18

def name
  @name
end

#typeTypeBillingModel

TODO: Write general description for this method

Returns:



38
39
40
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb', line 38

def type
  @type
end

#updated_atObject

TODO: Write general description for this method

Returns:

  • (Object)


34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb', line 34

def updated_at
  @updated_at
end

#updatorObject

TODO: Write general description for this method

Returns:

  • (Object)


46
47
48
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb', line 46

def updator
  @updator
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb', line 100

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  name = hash.key?('name') ? hash['name'] : nil
  expire_cycles = hash.key?('expire_cycles') ? hash['expire_cycles'] : nil
  buffer_days = hash.key?('buffer_days') ? hash['buffer_days'] : nil
  created_at = CreatedAt.from_hash(hash['created_at']) if hash['created_at']
  updated_at = hash.key?('updated_at') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:BillingModelOfferUpdatedAt), hash['updated_at']
  ) : nil
  type = TypeBillingModel.from_hash(hash['type']) if hash['type']
  creator = Creator.from_hash(hash['creator']) if hash['creator']
  updator = hash.key?('updator') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:BillingModelOfferUpdator), hash['updator']
  ) : nil
  discount = Discount.from_hash(hash['discount']) if hash['discount']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BillingModelOffer.new(id: id,
                        name: name,
                        expire_cycles: expire_cycles,
                        buffer_days: buffer_days,
                        created_at: created_at,
                        updated_at: updated_at,
                        type: type,
                        creator: creator,
                        updator: updator,
                        discount: discount,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb', line 53

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['name'] = 'name'
  @_hash['expire_cycles'] = 'expire_cycles'
  @_hash['buffer_days'] = 'buffer_days'
  @_hash['created_at'] = 'created_at'
  @_hash['updated_at'] = 'updated_at'
  @_hash['type'] = 'type'
  @_hash['creator'] = 'creator'
  @_hash['updator'] = 'updator'
  @_hash['discount'] = 'discount'
  @_hash
end

.nullablesObject

An array for nullable fields



74
75
76
77
78
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb', line 74

def self.nullables
  %w[
    discount
  ]
end

.optionalsObject

An array for optional fields



69
70
71
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb', line 69

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb', line 142

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.id,
                            ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.name,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.expire_cycles,
                              ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.buffer_days,
                              ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.created_at,
                              ->(val) { CreatedAt.validate(val) },
                              is_model_hash: true) and
        UnionTypeLookUp.get(:BillingModelOfferUpdatedAt)
                       .validate(value.updated_at) and
        APIHelper.valid_type?(value.type,
                              ->(val) { TypeBillingModel.validate(val) },
                              is_model_hash: true) and
        APIHelper.valid_type?(value.creator,
                              ->(val) { Creator.validate(val) },
                              is_model_hash: true) and
        UnionTypeLookUp.get(:BillingModelOfferUpdator)
                       .validate(value.updator) and
        APIHelper.valid_type?(value.discount,
                              ->(val) { Discount.validate(val) },
                              is_model_hash: true)
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['id'],
                          ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['name'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['expire_cycles'],
                            ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['buffer_days'],
                            ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['created_at'],
                            ->(val) { CreatedAt.validate(val) },
                            is_model_hash: true) and
      UnionTypeLookUp.get(:BillingModelOfferUpdatedAt)
                     .validate(value['updated_at']) and
      APIHelper.valid_type?(value['type'],
                            ->(val) { TypeBillingModel.validate(val) },
                            is_model_hash: true) and
      APIHelper.valid_type?(value['creator'],
                            ->(val) { Creator.validate(val) },
                            is_model_hash: true) and
      UnionTypeLookUp.get(:BillingModelOfferUpdator)
                     .validate(value['updator']) and
      APIHelper.valid_type?(value['discount'],
                            ->(val) { Discount.validate(val) },
                            is_model_hash: true)
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



212
213
214
215
216
217
218
219
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb', line 212

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, expire_cycles:"\
  " #{@expire_cycles.inspect}, buffer_days: #{@buffer_days.inspect}, created_at:"\
  " #{@created_at.inspect}, updated_at: #{@updated_at.inspect}, type: #{@type.inspect},"\
  " creator: #{@creator.inspect}, updator: #{@updator.inspect}, discount:"\
  " #{@discount.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



203
204
205
206
207
208
209
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_offer.rb', line 203

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, name: #{@name}, expire_cycles: #{@expire_cycles}, buffer_days:"\
  " #{@buffer_days}, created_at: #{@created_at}, updated_at: #{@updated_at}, type: #{@type},"\
  " creator: #{@creator}, updator: #{@updator}, discount: #{@discount}, additional_properties:"\
  " #{@additional_properties}>"
end