Class: StickyIoRestfulApiV2025731::ChangeRecurringProductTooManyChildrenException

Inherits:
APIException
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/exceptions/change_recurring_product_too_many_children_exception.rb

Overview

Change Recurring Product Too Many Children class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(reason, response) ⇒ ChangeRecurringProductTooManyChildrenException

The constructor.

Parameters:

  • reason (String)

    The reason for raising an exception.

  • response (HttpResponse)

    The HttpReponse of the API call.



31
32
33
34
35
# File 'lib/sticky_io_restful_api_v2025731/exceptions/change_recurring_product_too_many_children_exception.rb', line 31

def initialize(reason, response)
  super(reason, response)
  hash = APIHelper.json_deserialize(@response.raw_body)
  unbox(hash)
end

Instance Attribute Details

#codeInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/exceptions/change_recurring_product_too_many_children_exception.rb', line 18

def code
  @code
end

#dataDataChangeRecurringProductTooManyChildren

TODO: Write general description for this method



26
27
28
# File 'lib/sticky_io_restful_api_v2025731/exceptions/change_recurring_product_too_many_children_exception.rb', line 26

def data
  @data
end

#messageString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/exceptions/change_recurring_product_too_many_children_exception.rb', line 22

def message
  @message
end

#statusString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/exceptions/change_recurring_product_too_many_children_exception.rb', line 14

def status
  @status
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



56
57
58
59
60
# File 'lib/sticky_io_restful_api_v2025731/exceptions/change_recurring_product_too_many_children_exception.rb', line 56

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status.inspect}, code: #{@code.inspect}, message:"\
  " #{@message.inspect}, data: #{@data.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



50
51
52
53
# File 'lib/sticky_io_restful_api_v2025731/exceptions/change_recurring_product_too_many_children_exception.rb', line 50

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status}, code: #{@code}, message: #{@message}, data: #{@data}>"
end

#unbox(hash) ⇒ Object

Populates this object by extracting properties from a hash. response body.

Parameters:

  • hash (Hash)

    The deserialized response sent by the server in the



40
41
42
43
44
45
46
47
# File 'lib/sticky_io_restful_api_v2025731/exceptions/change_recurring_product_too_many_children_exception.rb', line 40

def unbox(hash)
  return nil unless hash

  @status = hash.key?('status') ? hash['status'] : nil
  @code = hash.key?('code') ? hash['code'] : nil
  @message = hash.key?('message') ? hash['message'] : nil
  @data = DataChangeRecurringProductTooManyChildren.from_hash(hash['data']) if hash['data']
end