Class: StickyIoRestfulApiV2025731::ChildOneOf0

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/child_one_of0.rb

Overview

ChildOneOf0 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(quantity: SKIP, product_id: SKIP, name: SKIP, additional_properties: nil) ⇒ ChildOneOf0

Returns a new instance of ChildOneOf0.



47
48
49
50
51
52
53
54
55
56
# File 'lib/sticky_io_restful_api_v2025731/models/child_one_of0.rb', line 47

def initialize(quantity: SKIP, product_id: SKIP, name: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @quantity = quantity unless quantity == SKIP
  @product_id = product_id unless product_id == SKIP
  @name = name unless name == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#nameString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/child_one_of0.rb', line 22

def name
  @name
end

#product_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/child_one_of0.rb', line 18

def product_id
  @product_id
end

#quantityInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/child_one_of0.rb', line 14

def quantity
  @quantity
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/sticky_io_restful_api_v2025731/models/child_one_of0.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  quantity = hash.key?('quantity') ? hash['quantity'] : SKIP
  product_id = hash.key?('product_id') ? hash['product_id'] : SKIP
  name = hash.key?('name') ? hash['name'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ChildOneOf0.new(quantity: quantity,
                  product_id: product_id,
                  name: name,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/sticky_io_restful_api_v2025731/models/child_one_of0.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['quantity'] = 'quantity'
  @_hash['product_id'] = 'product_id'
  @_hash['name'] = 'name'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/sticky_io_restful_api_v2025731/models/child_one_of0.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/sticky_io_restful_api_v2025731/models/child_one_of0.rb', line 34

def self.optionals
  %w[
    quantity
    product_id
    name
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (ChildOneOf0 | Hash)

    value against the validation is performed.



83
84
85
86
87
88
89
# File 'lib/sticky_io_restful_api_v2025731/models/child_one_of0.rb', line 83

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
# File 'lib/sticky_io_restful_api_v2025731/models/child_one_of0.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} quantity: #{@quantity.inspect}, product_id: #{@product_id.inspect}, name:"\
  " #{@name.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/sticky_io_restful_api_v2025731/models/child_one_of0.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} quantity: #{@quantity}, product_id: #{@product_id}, name: #{@name},"\
  " additional_properties: #{@additional_properties}>"
end