Class: StickyIoRestfulApiV2025731::CreateBillingModelRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/create_billing_model_request.rb

Overview

CreateBillingModelRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name:, type_id:, frequency_type_id:, frequency:, additional_properties: nil) ⇒ CreateBillingModelRequest

Returns a new instance of CreateBillingModelRequest.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/sticky_io_restful_api_v2025731/models/create_billing_model_request.rb', line 48

def initialize(name:, type_id:, frequency_type_id:, frequency:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name
  @type_id = type_id
  @frequency_type_id = frequency_type_id
  @frequency = frequency
  @additional_properties = additional_properties
end

Instance Attribute Details

#frequencyInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/create_billing_model_request.rb', line 26

def frequency
  @frequency
end

#frequency_type_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/create_billing_model_request.rb', line 22

def frequency_type_id
  @frequency_type_id
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/create_billing_model_request.rb', line 14

def name
  @name
end

#type_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/create_billing_model_request.rb', line 18

def type_id
  @type_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/sticky_io_restful_api_v2025731/models/create_billing_model_request.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : nil
  type_id = hash.key?('type_id') ? hash['type_id'] : nil
  frequency_type_id =
    hash.key?('frequency_type_id') ? hash['frequency_type_id'] : nil
  frequency = hash.key?('frequency') ? hash['frequency'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreateBillingModelRequest.new(name: name,
                                type_id: type_id,
                                frequency_type_id: frequency_type_id,
                                frequency: frequency,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/create_billing_model_request.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['type_id'] = 'type_id'
  @_hash['frequency_type_id'] = 'frequency_type_id'
  @_hash['frequency'] = 'frequency'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/sticky_io_restful_api_v2025731/models/create_billing_model_request.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/sticky_io_restful_api_v2025731/models/create_billing_model_request.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



95
96
97
98
99
100
# File 'lib/sticky_io_restful_api_v2025731/models/create_billing_model_request.rb', line 95

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, type_id: #{@type_id.inspect}, frequency_type_id:"\
  " #{@frequency_type_id.inspect}, frequency: #{@frequency.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
91
92
# File 'lib/sticky_io_restful_api_v2025731/models/create_billing_model_request.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, type_id: #{@type_id}, frequency_type_id:"\
  " #{@frequency_type_id}, frequency: #{@frequency}, additional_properties:"\
  " #{@additional_properties}>"
end