Class: StickyIoRestfulApiV2025731::CreateOfferRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/create_offer_request.rb

Overview

CreateOfferRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name:, billing_models:, products:, recurring:, is_trial:, trial:, additional_properties: nil) ⇒ CreateOfferRequest

Returns a new instance of CreateOfferRequest.



58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/sticky_io_restful_api_v2025731/models/create_offer_request.rb', line 58

def initialize(name:, billing_models:, products:, recurring:, is_trial:,
               trial:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name
  @billing_models = billing_models
  @products = products
  @recurring = recurring
  @is_trial = is_trial
  @trial = trial
  @additional_properties = additional_properties
end

Instance Attribute Details

#billing_modelsArray[BillingModelCreateOfferRequest]

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/create_offer_request.rb', line 18

def billing_models
  @billing_models
end

#is_trialInteger

TODO: Write general description for this method

Returns:

  • (Integer)


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/create_offer_request.rb', line 30

def is_trial
  @is_trial
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/create_offer_request.rb', line 14

def name
  @name
end

#productsArray[ProductCreateOfferRequest]

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/create_offer_request.rb', line 22

def products
  @products
end

#recurringRecurring

TODO: Write general description for this method

Returns:



26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/create_offer_request.rb', line 26

def recurring
  @recurring
end

#trialTrialCreateOfferRequest

TODO: Write general description for this method



34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/create_offer_request.rb', line 34

def trial
  @trial
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/sticky_io_restful_api_v2025731/models/create_offer_request.rb', line 73

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : nil
  # Parameter is an array, so we need to iterate through it
  billing_models = nil
  unless hash['billing_models'].nil?
    billing_models = []
    hash['billing_models'].each do |structure|
      billing_models << (BillingModelCreateOfferRequest.from_hash(structure) if structure)
    end
  end

  billing_models = nil unless hash.key?('billing_models')
  # Parameter is an array, so we need to iterate through it
  products = nil
  unless hash['products'].nil?
    products = []
    hash['products'].each do |structure|
      products << (ProductCreateOfferRequest.from_hash(structure) if structure)
    end
  end

  products = nil unless hash.key?('products')
  recurring = Recurring.from_hash(hash['recurring']) if hash['recurring']
  is_trial = hash.key?('is_trial') ? hash['is_trial'] : nil
  trial = TrialCreateOfferRequest.from_hash(hash['trial']) if hash['trial']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreateOfferRequest.new(name: name,
                         billing_models: billing_models,
                         products: products,
                         recurring: recurring,
                         is_trial: is_trial,
                         trial: trial,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/sticky_io_restful_api_v2025731/models/create_offer_request.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['billing_models'] = 'billing_models'
  @_hash['products'] = 'products'
  @_hash['recurring'] = 'recurring'
  @_hash['is_trial'] = 'is_trial'
  @_hash['trial'] = 'trial'
  @_hash
end

.nullablesObject

An array for nullable fields



54
55
56
# File 'lib/sticky_io_restful_api_v2025731/models/create_offer_request.rb', line 54

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/create_offer_request.rb', line 49

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



128
129
130
131
132
133
134
# File 'lib/sticky_io_restful_api_v2025731/models/create_offer_request.rb', line 128

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, billing_models: #{@billing_models.inspect},"\
  " products: #{@products.inspect}, recurring: #{@recurring.inspect}, is_trial:"\
  " #{@is_trial.inspect}, trial: #{@trial.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



120
121
122
123
124
125
# File 'lib/sticky_io_restful_api_v2025731/models/create_offer_request.rb', line 120

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, billing_models: #{@billing_models}, products: #{@products},"\
  " recurring: #{@recurring}, is_trial: #{@is_trial}, trial: #{@trial}, additional_properties:"\
  " #{@additional_properties}>"
end