Class: StickyIoRestfulApiV2025731::CreateSubscriptionOverrideRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::CreateSubscriptionOverrideRequest
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/create_subscription_override_request.rb
Overview
CreateSubscriptionOverrideRequest Model.
Instance Attribute Summary collapse
-
#address_id ⇒ Integer
TODO: Write general description for this method.
-
#contact_payment_source_id ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(address_id:, contact_payment_source_id:, additional_properties: nil) ⇒ CreateSubscriptionOverrideRequest
constructor
A new instance of CreateSubscriptionOverrideRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(address_id:, contact_payment_source_id:, additional_properties: nil) ⇒ CreateSubscriptionOverrideRequest
Returns a new instance of CreateSubscriptionOverrideRequest.
38 39 40 41 42 43 44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_subscription_override_request.rb', line 38 def initialize(address_id:, contact_payment_source_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @address_id = address_id @contact_payment_source_id = contact_payment_source_id @additional_properties = additional_properties end |
Instance Attribute Details
#address_id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_subscription_override_request.rb', line 14 def address_id @address_id end |
#contact_payment_source_id ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_subscription_override_request.rb', line 18 def contact_payment_source_id @contact_payment_source_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_subscription_override_request.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. address_id = hash.key?('address_id') ? hash['address_id'] : nil contact_payment_source_id = hash.key?('contact_payment_source_id') ? hash['contact_payment_source_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreateSubscriptionOverrideRequest.new(address_id: address_id, contact_payment_source_id: contact_payment_source_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_subscription_override_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['address_id'] = 'address_id' @_hash['contact_payment_source_id'] = 'contact_payment_source_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_subscription_override_request.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_subscription_override_request.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_subscription_override_request.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} address_id: #{@address_id.inspect}, contact_payment_source_id:"\ " #{@contact_payment_source_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_subscription_override_request.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} address_id: #{@address_id}, contact_payment_source_id:"\ " #{@contact_payment_source_id}, additional_properties: #{@additional_properties}>" end |