Class: StickyIoRestfulApiV2025731::CreateUpdateLineItemCustomOptionsRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::CreateUpdateLineItemCustomOptionsRequest
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/create_update_line_item_custom_options_request.rb
Overview
CreateUpdateLineItemCustomOptionsRequest Model.
Instance Attribute Summary collapse
-
#options ⇒ Array[OptionCreateUpdateLineItemCustomOptionsRequest]
TODO: Write general description for this method.
-
#order_id ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(order_id:, options:, additional_properties: nil) ⇒ CreateUpdateLineItemCustomOptionsRequest
constructor
A new instance of CreateUpdateLineItemCustomOptionsRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(order_id:, options:, additional_properties: nil) ⇒ CreateUpdateLineItemCustomOptionsRequest
Returns a new instance of CreateUpdateLineItemCustomOptionsRequest.
38 39 40 41 42 43 44 45 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_update_line_item_custom_options_request.rb', line 38 def initialize(order_id:, options:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @order_id = order_id @options = @additional_properties = additional_properties end |
Instance Attribute Details
#options ⇒ Array[OptionCreateUpdateLineItemCustomOptionsRequest]
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_update_line_item_custom_options_request.rb', line 18 def @options end |
#order_id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_update_line_item_custom_options_request.rb', line 14 def order_id @order_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_update_line_item_custom_options_request.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. order_id = hash.key?('order_id') ? hash['order_id'] : nil # Parameter is an array, so we need to iterate through it = nil unless hash['options'].nil? = [] hash['options'].each do |structure| << (OptionCreateUpdateLineItemCustomOptionsRequest.from_hash(structure) if structure) end end = nil unless hash.key?('options') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreateUpdateLineItemCustomOptionsRequest.new(order_id: order_id, options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_update_line_item_custom_options_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['order_id'] = 'order_id' @_hash['options'] = 'options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_update_line_item_custom_options_request.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_update_line_item_custom_options_request.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_update_line_item_custom_options_request.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} order_id: #{@order_id.inspect}, options: #{@options.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_update_line_item_custom_options_request.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} order_id: #{@order_id}, options: #{@options}, additional_properties:"\ " #{@additional_properties}>" end |