Class: StickyIoRestfulApiV2025731::CustomField

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/custom_field.rb

Overview

CustomField Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id: SKIP, field_type_id: SKIP, name: SKIP, token_key: SKIP, is_multi: SKIP, type_id: SKIP, values: SKIP, additional_properties: nil) ⇒ CustomField

Returns a new instance of CustomField.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field.rb', line 71

def initialize(id: SKIP, field_type_id: SKIP, name: SKIP, token_key: SKIP,
               is_multi: SKIP, type_id: SKIP, values: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id unless id == SKIP
  @field_type_id = field_type_id unless field_type_id == SKIP
  @name = name unless name == SKIP
  @token_key = token_key unless token_key == SKIP
  @is_multi = is_multi unless is_multi == SKIP
  @type_id = type_id unless type_id == SKIP
  @values = values unless values == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#field_type_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field.rb', line 18

def field_type_id
  @field_type_id
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field.rb', line 14

def id
  @id
end

#is_multiInteger

TODO: Write general description for this method

Returns:

  • (Integer)


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field.rb', line 30

def is_multi
  @is_multi
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field.rb', line 22

def name
  @name
end

#token_keyString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field.rb', line 26

def token_key
  @token_key
end

#type_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field.rb', line 34

def type_id
  @type_id
end

#valuesArray[Value]

TODO: Write general description for this method

Returns:



38
39
40
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field.rb', line 38

def values
  @values
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field.rb', line 88

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : SKIP
  field_type_id = hash.key?('field_type_id') ? hash['field_type_id'] : SKIP
  name = hash.key?('name') ? hash['name'] : SKIP
  token_key = hash.key?('token_key') ? hash['token_key'] : SKIP
  is_multi = hash.key?('is_multi') ? hash['is_multi'] : SKIP
  type_id = hash.key?('type_id') ? hash['type_id'] : SKIP
  # Parameter is an array, so we need to iterate through it
  values = nil
  unless hash['values'].nil?
    values = []
    hash['values'].each do |structure|
      values << (Value.from_hash(structure) if structure)
    end
  end

  values = SKIP unless hash.key?('values')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CustomField.new(id: id,
                  field_type_id: field_type_id,
                  name: name,
                  token_key: token_key,
                  is_multi: is_multi,
                  type_id: type_id,
                  values: values,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['field_type_id'] = 'field_type_id'
  @_hash['name'] = 'name'
  @_hash['token_key'] = 'token_key'
  @_hash['is_multi'] = 'is_multi'
  @_hash['type_id'] = 'type_id'
  @_hash['values'] = 'values'
  @_hash
end

.nullablesObject

An array for nullable fields



67
68
69
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field.rb', line 67

def self.nullables
  []
end

.optionalsObject

An array for optional fields



54
55
56
57
58
59
60
61
62
63
64
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field.rb', line 54

def self.optionals
  %w[
    id
    field_type_id
    name
    token_key
    is_multi
    type_id
    values
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (CustomField | Hash)

    value against the validation is performed.



129
130
131
132
133
134
135
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field.rb', line 129

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



146
147
148
149
150
151
152
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field.rb', line 146

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, field_type_id: #{@field_type_id.inspect}, name:"\
  " #{@name.inspect}, token_key: #{@token_key.inspect}, is_multi: #{@is_multi.inspect},"\
  " type_id: #{@type_id.inspect}, values: #{@values.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



138
139
140
141
142
143
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field.rb', line 138

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, field_type_id: #{@field_type_id}, name: #{@name}, token_key:"\
  " #{@token_key}, is_multi: #{@is_multi}, type_id: #{@type_id}, values: #{@values},"\
  " additional_properties: #{@additional_properties}>"
end