Class: StickyIoRestfulApiV2025731::CustomFieldOneOf1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/custom_field_one_of1.rb

Overview

CustomFieldOneOf1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, field_type_id:, name:, token_key:, is_multi:, type_id:, values:, additional_properties: nil) ⇒ CustomFieldOneOf1

Returns a new instance of CustomFieldOneOf1.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field_one_of1.rb', line 63

def initialize(id:, field_type_id:, name:, token_key:, is_multi:, type_id:,
               values:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @field_type_id = field_type_id
  @name = name
  @token_key = token_key
  @is_multi = is_multi
  @type_id = type_id
  @values = values
  @additional_properties = additional_properties
end

Instance Attribute Details

#field_type_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field_one_of1.rb', line 18

def field_type_id
  @field_type_id
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field_one_of1.rb', line 14

def id
  @id
end

#is_multiInteger

TODO: Write general description for this method

Returns:

  • (Integer)


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field_one_of1.rb', line 30

def is_multi
  @is_multi
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field_one_of1.rb', line 22

def name
  @name
end

#token_keyString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field_one_of1.rb', line 26

def token_key
  @token_key
end

#type_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field_one_of1.rb', line 34

def type_id
  @type_id
end

#valuesArray[Value]

TODO: Write general description for this method

Returns:



38
39
40
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field_one_of1.rb', line 38

def values
  @values
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field_one_of1.rb', line 79

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  field_type_id = hash.key?('field_type_id') ? hash['field_type_id'] : nil
  name = hash.key?('name') ? hash['name'] : nil
  token_key = hash.key?('token_key') ? hash['token_key'] : nil
  is_multi = hash.key?('is_multi') ? hash['is_multi'] : nil
  type_id = hash.key?('type_id') ? hash['type_id'] : nil
  # Parameter is an array, so we need to iterate through it
  values = nil
  unless hash['values'].nil?
    values = []
    hash['values'].each do |structure|
      values << (Value.from_hash(structure) if structure)
    end
  end

  values = nil unless hash.key?('values')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CustomFieldOneOf1.new(id: id,
                        field_type_id: field_type_id,
                        name: name,
                        token_key: token_key,
                        is_multi: is_multi,
                        type_id: type_id,
                        values: values,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field_one_of1.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['field_type_id'] = 'field_type_id'
  @_hash['name'] = 'name'
  @_hash['token_key'] = 'token_key'
  @_hash['is_multi'] = 'is_multi'
  @_hash['type_id'] = 'type_id'
  @_hash['values'] = 'values'
  @_hash
end

.nullablesObject

An array for nullable fields



59
60
61
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field_one_of1.rb', line 59

def self.nullables
  []
end

.optionalsObject

An array for optional fields



54
55
56
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field_one_of1.rb', line 54

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field_one_of1.rb', line 120

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.id,
                            ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.field_type_id,
                              ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.name,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.token_key,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.is_multi,
                              ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.type_id,
                              ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.values,
                              ->(val) { Value.validate(val) },
                              is_model_hash: true,
                              is_inner_model_hash: true)
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['id'],
                          ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['field_type_id'],
                            ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['name'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['token_key'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['is_multi'],
                            ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['type_id'],
                            ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['values'],
                            ->(val) { Value.validate(val) },
                            is_model_hash: true,
                            is_inner_model_hash: true)
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



173
174
175
176
177
178
179
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field_one_of1.rb', line 173

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, field_type_id: #{@field_type_id.inspect}, name:"\
  " #{@name.inspect}, token_key: #{@token_key.inspect}, is_multi: #{@is_multi.inspect},"\
  " type_id: #{@type_id.inspect}, values: #{@values.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



165
166
167
168
169
170
# File 'lib/sticky_io_restful_api_v2025731/models/custom_field_one_of1.rb', line 165

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, field_type_id: #{@field_type_id}, name: #{@name}, token_key:"\
  " #{@token_key}, is_multi: #{@is_multi}, type_id: #{@type_id}, values: #{@values},"\
  " additional_properties: #{@additional_properties}>"
end