Class: StickyIoRestfulApiV2025731::DataBillSubscriptionNowApproved
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::DataBillSubscriptionNowApproved
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_approved.rb
Overview
DataBillSubscriptionNowApproved Model.
Instance Attribute Summary collapse
-
#auth_id ⇒ String
TODO: Write general description for this method.
-
#error_found ⇒ Integer
TODO: Write general description for this method.
-
#order_id ⇒ Integer
TODO: Write general description for this method.
-
#response_code ⇒ Integer
TODO: Write general description for this method.
-
#response_message ⇒ String
TODO: Write general description for this method.
-
#transaction_id ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(error_found:, transaction_id:, auth_id:, response_code:, response_message:, order_id:, additional_properties: nil) ⇒ DataBillSubscriptionNowApproved
constructor
A new instance of DataBillSubscriptionNowApproved.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(error_found:, transaction_id:, auth_id:, response_code:, response_message:, order_id:, additional_properties: nil) ⇒ DataBillSubscriptionNowApproved
Returns a new instance of DataBillSubscriptionNowApproved.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_approved.rb', line 58 def initialize(error_found:, transaction_id:, auth_id:, response_code:, response_message:, order_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @error_found = error_found @transaction_id = transaction_id @auth_id = auth_id @response_code = response_code @response_message = @order_id = order_id @additional_properties = additional_properties end |
Instance Attribute Details
#auth_id ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_approved.rb', line 22 def auth_id @auth_id end |
#error_found ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_approved.rb', line 14 def error_found @error_found end |
#order_id ⇒ Integer
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_approved.rb', line 34 def order_id @order_id end |
#response_code ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_approved.rb', line 26 def response_code @response_code end |
#response_message ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_approved.rb', line 30 def @response_message end |
#transaction_id ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_approved.rb', line 18 def transaction_id @transaction_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_approved.rb', line 73 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. error_found = hash.key?('errorFound') ? hash['errorFound'] : nil transaction_id = hash.key?('transactionID') ? hash['transactionID'] : nil auth_id = hash.key?('authId') ? hash['authId'] : nil response_code = hash.key?('responseCode') ? hash['responseCode'] : nil = hash.key?('responseMessage') ? hash['responseMessage'] : nil order_id = hash.key?('orderId') ? hash['orderId'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DataBillSubscriptionNowApproved.new(error_found: error_found, transaction_id: transaction_id, auth_id: auth_id, response_code: response_code, response_message: , order_id: order_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_approved.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['error_found'] = 'errorFound' @_hash['transaction_id'] = 'transactionID' @_hash['auth_id'] = 'authId' @_hash['response_code'] = 'responseCode' @_hash['response_message'] = 'responseMessage' @_hash['order_id'] = 'orderId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_approved.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_approved.rb', line 49 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
111 112 113 114 115 116 117 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_approved.rb', line 111 def inspect class_name = self.class.name.split('::').last "<#{class_name} error_found: #{@error_found.inspect}, transaction_id:"\ " #{@transaction_id.inspect}, auth_id: #{@auth_id.inspect}, response_code:"\ " #{@response_code.inspect}, response_message: #{@response_message.inspect}, order_id:"\ " #{@order_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
103 104 105 106 107 108 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_approved.rb', line 103 def to_s class_name = self.class.name.split('::').last "<#{class_name} error_found: #{@error_found}, transaction_id: #{@transaction_id}, auth_id:"\ " #{@auth_id}, response_code: #{@response_code}, response_message: #{@response_message},"\ " order_id: #{@order_id}, additional_properties: #{@additional_properties}>" end |