Class: StickyIoRestfulApiV2025731::DataBillSubscriptionNowDecline

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_decline.rb

Overview

DataBillSubscriptionNowDecline Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(error_found:, decline_reason:, response_code:, response_message:, order_id:, additional_properties: nil) ⇒ DataBillSubscriptionNowDecline

Returns a new instance of DataBillSubscriptionNowDecline.



53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_decline.rb', line 53

def initialize(error_found:, decline_reason:, response_code:,
               response_message:, order_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @error_found = error_found
  @decline_reason = decline_reason
  @response_code = response_code
  @response_message = response_message
  @order_id = order_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#decline_reasonString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_decline.rb', line 18

def decline_reason
  @decline_reason
end

#error_foundInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_decline.rb', line 14

def error_found
  @error_found
end

#order_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_decline.rb', line 30

def order_id
  @order_id
end

#response_codeInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_decline.rb', line 22

def response_code
  @response_code
end

#response_messageString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_decline.rb', line 26

def response_message
  @response_message
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_decline.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  error_found = hash.key?('errorFound') ? hash['errorFound'] : nil
  decline_reason = hash.key?('declineReason') ? hash['declineReason'] : nil
  response_code = hash.key?('responseCode') ? hash['responseCode'] : nil
  response_message =
    hash.key?('responseMessage') ? hash['responseMessage'] : nil
  order_id = hash.key?('orderId') ? hash['orderId'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DataBillSubscriptionNowDecline.new(error_found: error_found,
                                     decline_reason: decline_reason,
                                     response_code: response_code,
                                     response_message: response_message,
                                     order_id: order_id,
                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_decline.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['error_found'] = 'errorFound'
  @_hash['decline_reason'] = 'declineReason'
  @_hash['response_code'] = 'responseCode'
  @_hash['response_message'] = 'responseMessage'
  @_hash['order_id'] = 'orderId'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_decline.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_decline.rb', line 44

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



103
104
105
106
107
108
109
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_decline.rb', line 103

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} error_found: #{@error_found.inspect}, decline_reason:"\
  " #{@decline_reason.inspect}, response_code: #{@response_code.inspect}, response_message:"\
  " #{@response_message.inspect}, order_id: #{@order_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



95
96
97
98
99
100
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_subscription_now_decline.rb', line 95

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} error_found: #{@error_found}, decline_reason: #{@decline_reason},"\
  " response_code: #{@response_code}, response_message: #{@response_message}, order_id:"\
  " #{@order_id}, additional_properties: #{@additional_properties}>"
end