Class: StickyIoRestfulApiV2025731::DataCreateAddress

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/data_create_address.rb

Overview

DataCreateAddress Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, email:, origin_id:, is_member:, created_at:, custom_fields:, addresses:, additional_properties: nil) ⇒ DataCreateAddress

Returns a new instance of DataCreateAddress.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/sticky_io_restful_api_v2025731/models/data_create_address.rb', line 63

def initialize(id:, email:, origin_id:, is_member:, created_at:,
               custom_fields:, addresses:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @email = email
  @origin_id = origin_id
  @is_member = is_member
  @created_at = created_at
  @custom_fields = custom_fields
  @addresses = addresses
  @additional_properties = additional_properties
end

Instance Attribute Details

#addressesArray[Address]

TODO: Write general description for this method

Returns:



38
39
40
# File 'lib/sticky_io_restful_api_v2025731/models/data_create_address.rb', line 38

def addresses
  @addresses
end

#created_atString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/data_create_address.rb', line 30

def created_at
  @created_at
end

#custom_fieldsArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/data_create_address.rb', line 34

def custom_fields
  @custom_fields
end

#emailString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/data_create_address.rb', line 18

def email
  @email
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/data_create_address.rb', line 14

def id
  @id
end

#is_memberInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/data_create_address.rb', line 26

def is_member
  @is_member
end

#origin_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/data_create_address.rb', line 22

def origin_id
  @origin_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/sticky_io_restful_api_v2025731/models/data_create_address.rb', line 79

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  email = hash.key?('email') ? hash['email'] : nil
  origin_id = hash.key?('origin_id') ? hash['origin_id'] : nil
  is_member = hash.key?('is_member') ? hash['is_member'] : nil
  created_at = hash.key?('created_at') ? hash['created_at'] : nil
  custom_fields = hash.key?('custom_fields') ? hash['custom_fields'] : nil
  # Parameter is an array, so we need to iterate through it
  addresses = nil
  unless hash['addresses'].nil?
    addresses = []
    hash['addresses'].each do |structure|
      addresses << (Address.from_hash(structure) if structure)
    end
  end

  addresses = nil unless hash.key?('addresses')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DataCreateAddress.new(id: id,
                        email: email,
                        origin_id: origin_id,
                        is_member: is_member,
                        created_at: created_at,
                        custom_fields: custom_fields,
                        addresses: addresses,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/data_create_address.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['email'] = 'email'
  @_hash['origin_id'] = 'origin_id'
  @_hash['is_member'] = 'is_member'
  @_hash['created_at'] = 'created_at'
  @_hash['custom_fields'] = 'custom_fields'
  @_hash['addresses'] = 'addresses'
  @_hash
end

.nullablesObject

An array for nullable fields



59
60
61
# File 'lib/sticky_io_restful_api_v2025731/models/data_create_address.rb', line 59

def self.nullables
  []
end

.optionalsObject

An array for optional fields



54
55
56
# File 'lib/sticky_io_restful_api_v2025731/models/data_create_address.rb', line 54

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



127
128
129
130
131
132
133
# File 'lib/sticky_io_restful_api_v2025731/models/data_create_address.rb', line 127

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, email: #{@email.inspect}, origin_id:"\
  " #{@origin_id.inspect}, is_member: #{@is_member.inspect}, created_at:"\
  " #{@created_at.inspect}, custom_fields: #{@custom_fields.inspect}, addresses:"\
  " #{@addresses.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



119
120
121
122
123
124
# File 'lib/sticky_io_restful_api_v2025731/models/data_create_address.rb', line 119

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, email: #{@email}, origin_id: #{@origin_id}, is_member:"\
  " #{@is_member}, created_at: #{@created_at}, custom_fields: #{@custom_fields}, addresses:"\
  " #{@addresses}, additional_properties: #{@additional_properties}>"
end