Class: StickyIoRestfulApiV2025731::DataGetAssignedProductLicenseKeys

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/data_get_assigned_product_license_keys.rb

Overview

DataGetAssignedProductLicenseKeys Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, key:, product_id:, status_id:, held_at:, created_at:, status_name:, additional_properties: nil) ⇒ DataGetAssignedProductLicenseKeys

Returns a new instance of DataGetAssignedProductLicenseKeys.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_assigned_product_license_keys.rb', line 63

def initialize(id:, key:, product_id:, status_id:, held_at:, created_at:,
               status_name:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @key = key
  @product_id = product_id
  @status_id = status_id
  @held_at = held_at
  @created_at = created_at
  @status_name = status_name
  @additional_properties = additional_properties
end

Instance Attribute Details

#created_atString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_assigned_product_license_keys.rb', line 34

def created_at
  @created_at
end

#held_atString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_assigned_product_license_keys.rb', line 30

def held_at
  @held_at
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_assigned_product_license_keys.rb', line 14

def id
  @id
end

#keyString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_assigned_product_license_keys.rb', line 18

def key
  @key
end

#product_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_assigned_product_license_keys.rb', line 22

def product_id
  @product_id
end

#status_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_assigned_product_license_keys.rb', line 26

def status_id
  @status_id
end

#status_nameString

TODO: Write general description for this method

Returns:

  • (String)


38
39
40
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_assigned_product_license_keys.rb', line 38

def status_name
  @status_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_assigned_product_license_keys.rb', line 79

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  key = hash.key?('key') ? hash['key'] : nil
  product_id = hash.key?('product_id') ? hash['product_id'] : nil
  status_id = hash.key?('status_id') ? hash['status_id'] : nil
  held_at = hash.key?('held_at') ? hash['held_at'] : nil
  created_at = hash.key?('created_at') ? hash['created_at'] : nil
  status_name = hash.key?('status_name') ? hash['status_name'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DataGetAssignedProductLicenseKeys.new(id: id,
                                        key: key,
                                        product_id: product_id,
                                        status_id: status_id,
                                        held_at: held_at,
                                        created_at: created_at,
                                        status_name: status_name,
                                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_assigned_product_license_keys.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['key'] = 'key'
  @_hash['product_id'] = 'product_id'
  @_hash['status_id'] = 'status_id'
  @_hash['held_at'] = 'held_at'
  @_hash['created_at'] = 'created_at'
  @_hash['status_name'] = 'status_name'
  @_hash
end

.nullablesObject

An array for nullable fields



59
60
61
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_assigned_product_license_keys.rb', line 59

def self.nullables
  []
end

.optionalsObject

An array for optional fields



54
55
56
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_assigned_product_license_keys.rb', line 54

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



118
119
120
121
122
123
124
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_assigned_product_license_keys.rb', line 118

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, key: #{@key.inspect}, product_id:"\
  " #{@product_id.inspect}, status_id: #{@status_id.inspect}, held_at: #{@held_at.inspect},"\
  " created_at: #{@created_at.inspect}, status_name: #{@status_name.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



110
111
112
113
114
115
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_assigned_product_license_keys.rb', line 110

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, key: #{@key}, product_id: #{@product_id}, status_id:"\
  " #{@status_id}, held_at: #{@held_at}, created_at: #{@created_at}, status_name:"\
  " #{@status_name}, additional_properties: #{@additional_properties}>"
end