Class: StickyIoRestfulApiV2025731::DataGetAvailableBillingModels

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/data_get_available_billing_models.rb

Overview

DataGetAvailableBillingModels Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, name:, buffer_days:, created_at:, updated_at:, is_preserve_quantity:, type:, creator:, updator:, additional_properties: nil) ⇒ DataGetAvailableBillingModels

Returns a new instance of DataGetAvailableBillingModels.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_available_billing_models.rb', line 73

def initialize(id:, name:, buffer_days:, created_at:, updated_at:,
               is_preserve_quantity:, type:, creator:, updator:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @name = name
  @buffer_days = buffer_days
  @created_at = created_at
  @updated_at = updated_at
  @is_preserve_quantity = is_preserve_quantity
  @type = type
  @creator = creator
  @updator = updator
  @additional_properties = additional_properties
end

Instance Attribute Details

#buffer_daysInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_available_billing_models.rb', line 22

def buffer_days
  @buffer_days
end

#created_atCreatedAt

TODO: Write general description for this method

Returns:



26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_available_billing_models.rb', line 26

def created_at
  @created_at
end

#creatorCreator

TODO: Write general description for this method

Returns:



42
43
44
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_available_billing_models.rb', line 42

def creator
  @creator
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_available_billing_models.rb', line 14

def id
  @id
end

#is_preserve_quantityInteger

TODO: Write general description for this method

Returns:

  • (Integer)


34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_available_billing_models.rb', line 34

def is_preserve_quantity
  @is_preserve_quantity
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_available_billing_models.rb', line 18

def name
  @name
end

#typeTypeData

TODO: Write general description for this method

Returns:



38
39
40
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_available_billing_models.rb', line 38

def type
  @type
end

#updated_atObject

TODO: Write general description for this method

Returns:

  • (Object)


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_available_billing_models.rb', line 30

def updated_at
  @updated_at
end

#updatorObject

TODO: Write general description for this method

Returns:

  • (Object)


46
47
48
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_available_billing_models.rb', line 46

def updator
  @updator
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_available_billing_models.rb', line 92

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  name = hash.key?('name') ? hash['name'] : nil
  buffer_days = hash.key?('buffer_days') ? hash['buffer_days'] : nil
  created_at = CreatedAt.from_hash(hash['created_at']) if hash['created_at']
  updated_at = hash.key?('updated_at') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:DataGetAvailableBillingModelsUpdatedAt), hash['updated_at']
  ) : nil
  is_preserve_quantity =
    hash.key?('is_preserve_quantity') ? hash['is_preserve_quantity'] : nil
  type = TypeData.from_hash(hash['type']) if hash['type']
  creator = Creator.from_hash(hash['creator']) if hash['creator']
  updator = hash.key?('updator') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:DataGetAvailableBillingModelsUpdator), hash['updator']
  ) : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DataGetAvailableBillingModels.new(id: id,
                                    name: name,
                                    buffer_days: buffer_days,
                                    created_at: created_at,
                                    updated_at: updated_at,
                                    is_preserve_quantity: is_preserve_quantity,
                                    type: type,
                                    creator: creator,
                                    updator: updator,
                                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_available_billing_models.rb', line 49

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['name'] = 'name'
  @_hash['buffer_days'] = 'buffer_days'
  @_hash['created_at'] = 'created_at'
  @_hash['updated_at'] = 'updated_at'
  @_hash['is_preserve_quantity'] = 'is_preserve_quantity'
  @_hash['type'] = 'type'
  @_hash['creator'] = 'creator'
  @_hash['updator'] = 'updator'
  @_hash
end

.nullablesObject

An array for nullable fields



69
70
71
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_available_billing_models.rb', line 69

def self.nullables
  []
end

.optionalsObject

An array for optional fields



64
65
66
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_available_billing_models.rb', line 64

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_available_billing_models.rb', line 133

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.id,
                            ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.name,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.buffer_days,
                              ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.created_at,
                              ->(val) { CreatedAt.validate(val) },
                              is_model_hash: true) and
        UnionTypeLookUp.get(:DataGetAvailableBillingModelsUpdatedAt)
                       .validate(value.updated_at) and
        APIHelper.valid_type?(value.is_preserve_quantity,
                              ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.type,
                              ->(val) { TypeData.validate(val) },
                              is_model_hash: true) and
        APIHelper.valid_type?(value.creator,
                              ->(val) { Creator.validate(val) },
                              is_model_hash: true) and
        UnionTypeLookUp.get(:DataGetAvailableBillingModelsUpdator)
                       .validate(value.updator)
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['id'],
                          ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['name'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['buffer_days'],
                            ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['created_at'],
                            ->(val) { CreatedAt.validate(val) },
                            is_model_hash: true) and
      UnionTypeLookUp.get(:DataGetAvailableBillingModelsUpdatedAt)
                     .validate(value['updated_at']) and
      APIHelper.valid_type?(value['is_preserve_quantity'],
                            ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['type'],
                            ->(val) { TypeData.validate(val) },
                            is_model_hash: true) and
      APIHelper.valid_type?(value['creator'],
                            ->(val) { Creator.validate(val) },
                            is_model_hash: true) and
      UnionTypeLookUp.get(:DataGetAvailableBillingModelsUpdator)
                     .validate(value['updator'])
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



197
198
199
200
201
202
203
204
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_available_billing_models.rb', line 197

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, buffer_days:"\
  " #{@buffer_days.inspect}, created_at: #{@created_at.inspect}, updated_at:"\
  " #{@updated_at.inspect}, is_preserve_quantity: #{@is_preserve_quantity.inspect}, type:"\
  " #{@type.inspect}, creator: #{@creator.inspect}, updator: #{@updator.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



188
189
190
191
192
193
194
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_available_billing_models.rb', line 188

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, name: #{@name}, buffer_days: #{@buffer_days}, created_at:"\
  " #{@created_at}, updated_at: #{@updated_at}, is_preserve_quantity:"\
  " #{@is_preserve_quantity}, type: #{@type}, creator: #{@creator}, updator: #{@updator},"\
  " additional_properties: #{@additional_properties}>"
end