Class: StickyIoRestfulApiV2025731::DataGetBillingModel

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb

Overview

DataGetBillingModel Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, name:, expire_cycles:, buffer_days:, created_at:, updated_at:, is_archived:, is_preserve_quantity:, is_default:, week:, day:, days:, date:, dates:, description:, type:, creator:, updator:, additional_properties: nil) ⇒ DataGetBillingModel

Returns a new instance of DataGetBillingModel.



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 120

def initialize(id:, name:, expire_cycles:, buffer_days:, created_at:,
               updated_at:, is_archived:, is_preserve_quantity:,
               is_default:, week:, day:, days:, date:, dates:, description:,
               type:, creator:, updator:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @name = name
  @expire_cycles = expire_cycles
  @buffer_days = buffer_days
  @created_at = created_at
  @updated_at = updated_at
  @is_archived = is_archived
  @is_preserve_quantity = is_preserve_quantity
  @is_default = is_default
  @week = week
  @day = day
  @days = days
  @date = date
  @dates = dates
  @description = description
  @type = type
  @creator = creator
  @updator = updator
  @additional_properties = additional_properties
end

Instance Attribute Details

#buffer_daysInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 26

def buffer_days
  @buffer_days
end

#created_atCreatedAt

TODO: Write general description for this method

Returns:



30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 30

def created_at
  @created_at
end

#creatorCreator

TODO: Write general description for this method

Returns:



78
79
80
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 78

def creator
  @creator
end

#dateInteger

TODO: Write general description for this method

Returns:

  • (Integer)


62
63
64
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 62

def date
  @date
end

#datesArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


66
67
68
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 66

def dates
  @dates
end

#dayInteger

TODO: Write general description for this method

Returns:

  • (Integer)


54
55
56
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 54

def day
  @day
end

#daysInteger

TODO: Write general description for this method

Returns:

  • (Integer)


58
59
60
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 58

def days
  @days
end

#descriptionString

TODO: Write general description for this method

Returns:

  • (String)


70
71
72
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 70

def description
  @description
end

#expire_cyclesInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 22

def expire_cycles
  @expire_cycles
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 14

def id
  @id
end

#is_archivedInteger

TODO: Write general description for this method

Returns:

  • (Integer)


38
39
40
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 38

def is_archived
  @is_archived
end

#is_defaultString

TODO: Write general description for this method

Returns:

  • (String)


46
47
48
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 46

def is_default
  @is_default
end

#is_preserve_quantityInteger

TODO: Write general description for this method

Returns:

  • (Integer)


42
43
44
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 42

def is_preserve_quantity
  @is_preserve_quantity
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 18

def name
  @name
end

#typeTypeData

TODO: Write general description for this method

Returns:



74
75
76
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 74

def type
  @type
end

#updated_atUpdatedAtData

TODO: Write general description for this method

Returns:



34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 34

def updated_at
  @updated_at
end

#updatorUpdatorData

TODO: Write general description for this method

Returns:



82
83
84
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 82

def updator
  @updator
end

#weekInteger

TODO: Write general description for this method

Returns:

  • (Integer)


50
51
52
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 50

def week
  @week
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 149

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  name = hash.key?('name') ? hash['name'] : nil
  expire_cycles = hash.key?('expire_cycles') ? hash['expire_cycles'] : nil
  buffer_days = hash.key?('buffer_days') ? hash['buffer_days'] : nil
  created_at = CreatedAt.from_hash(hash['created_at']) if hash['created_at']
  updated_at = UpdatedAtData.from_hash(hash['updated_at']) if hash['updated_at']
  is_archived = hash.key?('is_archived') ? hash['is_archived'] : nil
  is_preserve_quantity =
    hash.key?('is_preserve_quantity') ? hash['is_preserve_quantity'] : nil
  is_default = hash.key?('is_default') ? hash['is_default'] : nil
  week = hash.key?('week') ? hash['week'] : nil
  day = hash.key?('day') ? hash['day'] : nil
  days = hash.key?('days') ? hash['days'] : nil
  date = hash.key?('date') ? hash['date'] : nil
  dates = hash.key?('dates') ? hash['dates'] : nil
  description = hash.key?('description') ? hash['description'] : nil
  type = TypeData.from_hash(hash['type']) if hash['type']
  creator = Creator.from_hash(hash['creator']) if hash['creator']
  updator = UpdatorData.from_hash(hash['updator']) if hash['updator']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DataGetBillingModel.new(id: id,
                          name: name,
                          expire_cycles: expire_cycles,
                          buffer_days: buffer_days,
                          created_at: created_at,
                          updated_at: updated_at,
                          is_archived: is_archived,
                          is_preserve_quantity: is_preserve_quantity,
                          is_default: is_default,
                          week: week,
                          day: day,
                          days: days,
                          date: date,
                          dates: dates,
                          description: description,
                          type: type,
                          creator: creator,
                          updator: updator,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 85

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['name'] = 'name'
  @_hash['expire_cycles'] = 'expire_cycles'
  @_hash['buffer_days'] = 'buffer_days'
  @_hash['created_at'] = 'created_at'
  @_hash['updated_at'] = 'updated_at'
  @_hash['is_archived'] = 'is_archived'
  @_hash['is_preserve_quantity'] = 'is_preserve_quantity'
  @_hash['is_default'] = 'is_default'
  @_hash['week'] = 'week'
  @_hash['day'] = 'day'
  @_hash['days'] = 'days'
  @_hash['date'] = 'date'
  @_hash['dates'] = 'dates'
  @_hash['description'] = 'description'
  @_hash['type'] = 'type'
  @_hash['creator'] = 'creator'
  @_hash['updator'] = 'updator'
  @_hash
end

.nullablesObject

An array for nullable fields



114
115
116
117
118
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 114

def self.nullables
  %w[
    is_default
  ]
end

.optionalsObject

An array for optional fields



109
110
111
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 109

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



214
215
216
217
218
219
220
221
222
223
224
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 214

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, expire_cycles:"\
  " #{@expire_cycles.inspect}, buffer_days: #{@buffer_days.inspect}, created_at:"\
  " #{@created_at.inspect}, updated_at: #{@updated_at.inspect}, is_archived:"\
  " #{@is_archived.inspect}, is_preserve_quantity: #{@is_preserve_quantity.inspect},"\
  " is_default: #{@is_default.inspect}, week: #{@week.inspect}, day: #{@day.inspect}, days:"\
  " #{@days.inspect}, date: #{@date.inspect}, dates: #{@dates.inspect}, description:"\
  " #{@description.inspect}, type: #{@type.inspect}, creator: #{@creator.inspect}, updator:"\
  " #{@updator.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



203
204
205
206
207
208
209
210
211
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_billing_model.rb', line 203

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, name: #{@name}, expire_cycles: #{@expire_cycles}, buffer_days:"\
  " #{@buffer_days}, created_at: #{@created_at}, updated_at: #{@updated_at}, is_archived:"\
  " #{@is_archived}, is_preserve_quantity: #{@is_preserve_quantity}, is_default:"\
  " #{@is_default}, week: #{@week}, day: #{@day}, days: #{@days}, date: #{@date}, dates:"\
  " #{@dates}, description: #{@description}, type: #{@type}, creator: #{@creator}, updator:"\
  " #{@updator}, additional_properties: #{@additional_properties}>"
end