Class: StickyIoRestfulApiV2025731::DataGetCancellationNoteTemplates
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::DataGetCancellationNoteTemplates
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/data_get_cancellation_note_templates.rb
Overview
DataGetCancellationNoteTemplates Model.
Instance Attribute Summary collapse
-
#campaigns ⇒ Array[String]
TODO: Write general description for this method.
-
#content ⇒ String
TODO: Write general description for this method.
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#is_editable ⇒ Integer
TODO: Write general description for this method.
-
#is_global ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id:, name:, is_global:, is_editable:, campaigns:, content:, additional_properties: nil) ⇒ DataGetCancellationNoteTemplates
constructor
A new instance of DataGetCancellationNoteTemplates.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, name:, is_global:, is_editable:, campaigns:, content:, additional_properties: nil) ⇒ DataGetCancellationNoteTemplates
Returns a new instance of DataGetCancellationNoteTemplates.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_cancellation_note_templates.rb', line 58 def initialize(id:, name:, is_global:, is_editable:, campaigns:, content:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @name = name @is_global = is_global @is_editable = is_editable @campaigns = campaigns @content = content @additional_properties = additional_properties end |
Instance Attribute Details
#campaigns ⇒ Array[String]
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_cancellation_note_templates.rb', line 30 def campaigns @campaigns end |
#content ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_cancellation_note_templates.rb', line 34 def content @content end |
#id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_cancellation_note_templates.rb', line 14 def id @id end |
#is_editable ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_cancellation_note_templates.rb', line 26 def is_editable @is_editable end |
#is_global ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_cancellation_note_templates.rb', line 22 def is_global @is_global end |
#name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_cancellation_note_templates.rb', line 18 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_cancellation_note_templates.rb', line 73 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil name = hash.key?('name') ? hash['name'] : nil is_global = hash.key?('is_global') ? hash['is_global'] : nil is_editable = hash.key?('is_editable') ? hash['is_editable'] : nil campaigns = hash.key?('campaigns') ? hash['campaigns'] : nil content = hash.key?('content') ? hash['content'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DataGetCancellationNoteTemplates.new(id: id, name: name, is_global: is_global, is_editable: is_editable, campaigns: campaigns, content: content, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_cancellation_note_templates.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['name'] = 'name' @_hash['is_global'] = 'is_global' @_hash['is_editable'] = 'is_editable' @_hash['campaigns'] = 'campaigns' @_hash['content'] = 'content' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_cancellation_note_templates.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_cancellation_note_templates.rb', line 49 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
110 111 112 113 114 115 116 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_cancellation_note_templates.rb', line 110 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, is_global:"\ " #{@is_global.inspect}, is_editable: #{@is_editable.inspect}, campaigns:"\ " #{@campaigns.inspect}, content: #{@content.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
102 103 104 105 106 107 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_cancellation_note_templates.rb', line 102 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, name: #{@name}, is_global: #{@is_global}, is_editable:"\ " #{@is_editable}, campaigns: #{@campaigns}, content: #{@content}, additional_properties:"\ " #{@additional_properties}>" end |