Class: StickyIoRestfulApiV2025731::DataGetHistoryNotes
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::DataGetHistoryNotes
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/data_get_history_notes.rb
Overview
DataGetHistoryNotes Model.
Instance Attribute Summary collapse
-
#author ⇒ Author
TODO: Write general description for this method.
-
#created_at ⇒ CreatedAt
TODO: Write general description for this method.
-
#message ⇒ String
TODO: Write general description for this method.
-
#order_id ⇒ Integer
TODO: Write general description for this method.
-
#type_name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(order_id:, message:, created_at:, author:, type_name:, additional_properties: nil) ⇒ DataGetHistoryNotes
constructor
A new instance of DataGetHistoryNotes.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(order_id:, message:, created_at:, author:, type_name:, additional_properties: nil) ⇒ DataGetHistoryNotes
Returns a new instance of DataGetHistoryNotes.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_history_notes.rb', line 53 def initialize(order_id:, message:, created_at:, author:, type_name:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @order_id = order_id @message = @created_at = created_at @author = @type_name = type_name @additional_properties = additional_properties end |
Instance Attribute Details
#author ⇒ Author
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_history_notes.rb', line 26 def @author end |
#created_at ⇒ CreatedAt
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_history_notes.rb', line 22 def created_at @created_at end |
#message ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_history_notes.rb', line 18 def @message end |
#order_id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_history_notes.rb', line 14 def order_id @order_id end |
#type_name ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_history_notes.rb', line 30 def type_name @type_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_history_notes.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. order_id = hash.key?('order_id') ? hash['order_id'] : nil = hash.key?('message') ? hash['message'] : nil created_at = CreatedAt.from_hash(hash['created_at']) if hash['created_at'] = Author.from_hash(hash['author']) if hash['author'] type_name = hash.key?('type_name') ? hash['type_name'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DataGetHistoryNotes.new(order_id: order_id, message: , created_at: created_at, author: , type_name: type_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_history_notes.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['order_id'] = 'order_id' @_hash['message'] = 'message' @_hash['created_at'] = 'created_at' @_hash['author'] = 'author' @_hash['type_name'] = 'type_name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_history_notes.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_history_notes.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
102 103 104 105 106 107 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_history_notes.rb', line 102 def inspect class_name = self.class.name.split('::').last "<#{class_name} order_id: #{@order_id.inspect}, message: #{@message.inspect}, created_at:"\ " #{@created_at.inspect}, author: #{@author.inspect}, type_name: #{@type_name.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 99 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_history_notes.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} order_id: #{@order_id}, message: #{@message}, created_at: #{@created_at},"\ " author: #{@author}, type_name: #{@type_name}, additional_properties:"\ " #{@additional_properties}>" end |