Class: StickyIoRestfulApiV2025731::DataGetPaymentMethods

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/data_get_payment_methods.rb

Overview

DataGetPaymentMethods Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, name:, description:, is_cc_brand:, additional_properties: nil) ⇒ DataGetPaymentMethods

Returns a new instance of DataGetPaymentMethods.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_payment_methods.rb', line 48

def initialize(id:, name:, description:, is_cc_brand:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @name = name
  @description = description
  @is_cc_brand = is_cc_brand
  @additional_properties = additional_properties
end

Instance Attribute Details

#descriptionString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_payment_methods.rb', line 22

def description
  @description
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_payment_methods.rb', line 14

def id
  @id
end

#is_cc_brandInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_payment_methods.rb', line 26

def is_cc_brand
  @is_cc_brand
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_payment_methods.rb', line 18

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_payment_methods.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  name = hash.key?('name') ? hash['name'] : nil
  description = hash.key?('description') ? hash['description'] : nil
  is_cc_brand = hash.key?('is_cc_brand') ? hash['is_cc_brand'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DataGetPaymentMethods.new(id: id,
                            name: name,
                            description: description,
                            is_cc_brand: is_cc_brand,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_payment_methods.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['name'] = 'name'
  @_hash['description'] = 'description'
  @_hash['is_cc_brand'] = 'is_cc_brand'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_payment_methods.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_payment_methods.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



93
94
95
96
97
98
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_payment_methods.rb', line 93

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, description:"\
  " #{@description.inspect}, is_cc_brand: #{@is_cc_brand.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



86
87
88
89
90
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_payment_methods.rb', line 86

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, name: #{@name}, description: #{@description}, is_cc_brand:"\
  " #{@is_cc_brand}, additional_properties: #{@additional_properties}>"
end