Class: StickyIoRestfulApiV2025731::DataGetProductCustomFields

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/data_get_product_custom_fields.rb

Overview

DataGetProductCustomFields Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, field_type_id:, name:, token_key:, is_multi:, options:, type_id:, additional_properties: nil) ⇒ DataGetProductCustomFields

Returns a new instance of DataGetProductCustomFields.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_custom_fields.rb', line 63

def initialize(id:, field_type_id:, name:, token_key:, is_multi:, options:,
               type_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @field_type_id = field_type_id
  @name = name
  @token_key = token_key
  @is_multi = is_multi
  @options = options
  @type_id = type_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#field_type_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_custom_fields.rb', line 18

def field_type_id
  @field_type_id
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_custom_fields.rb', line 14

def id
  @id
end

#is_multiInteger

TODO: Write general description for this method

Returns:

  • (Integer)


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_custom_fields.rb', line 30

def is_multi
  @is_multi
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_custom_fields.rb', line 22

def name
  @name
end

#optionsArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_custom_fields.rb', line 34

def options
  @options
end

#token_keyString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_custom_fields.rb', line 26

def token_key
  @token_key
end

#type_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


38
39
40
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_custom_fields.rb', line 38

def type_id
  @type_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_custom_fields.rb', line 79

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  field_type_id = hash.key?('field_type_id') ? hash['field_type_id'] : nil
  name = hash.key?('name') ? hash['name'] : nil
  token_key = hash.key?('token_key') ? hash['token_key'] : nil
  is_multi = hash.key?('is_multi') ? hash['is_multi'] : nil
  options = hash.key?('options') ? hash['options'] : nil
  type_id = hash.key?('type_id') ? hash['type_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DataGetProductCustomFields.new(id: id,
                                 field_type_id: field_type_id,
                                 name: name,
                                 token_key: token_key,
                                 is_multi: is_multi,
                                 options: options,
                                 type_id: type_id,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_custom_fields.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['field_type_id'] = 'field_type_id'
  @_hash['name'] = 'name'
  @_hash['token_key'] = 'token_key'
  @_hash['is_multi'] = 'is_multi'
  @_hash['options'] = 'options'
  @_hash['type_id'] = 'type_id'
  @_hash
end

.nullablesObject

An array for nullable fields



59
60
61
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_custom_fields.rb', line 59

def self.nullables
  []
end

.optionalsObject

An array for optional fields



54
55
56
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_custom_fields.rb', line 54

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



118
119
120
121
122
123
124
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_custom_fields.rb', line 118

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, field_type_id: #{@field_type_id.inspect}, name:"\
  " #{@name.inspect}, token_key: #{@token_key.inspect}, is_multi: #{@is_multi.inspect},"\
  " options: #{@options.inspect}, type_id: #{@type_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



110
111
112
113
114
115
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_custom_fields.rb', line 110

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, field_type_id: #{@field_type_id}, name: #{@name}, token_key:"\
  " #{@token_key}, is_multi: #{@is_multi}, options: #{@options}, type_id: #{@type_id},"\
  " additional_properties: #{@additional_properties}>"
end