Class: StickyIoRestfulApiV2025731::DataGetProductVariants

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/data_get_product_variants.rb

Overview

DataGetProductVariants Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, price:, quantity:, weight:, sku_num:, attributes:, additional_properties: nil) ⇒ DataGetProductVariants

Returns a new instance of DataGetProductVariants.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_variants.rb', line 62

def initialize(id:, price:, quantity:, weight:, sku_num:, attributes:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @price = price
  @quantity = quantity
  @weight = weight
  @sku_num = sku_num
  @attributes = attributes
  @additional_properties = additional_properties
end

Instance Attribute Details

#attributesArray[AttributeData]

TODO: Write general description for this method

Returns:



34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_variants.rb', line 34

def attributes
  @attributes
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_variants.rb', line 14

def id
  @id
end

#priceString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_variants.rb', line 18

def price
  @price
end

#quantityObject

TODO: Write general description for this method

Returns:

  • (Object)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_variants.rb', line 22

def quantity
  @quantity
end

#sku_numString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_variants.rb', line 30

def sku_num
  @sku_num
end

#weightObject

TODO: Write general description for this method

Returns:

  • (Object)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_variants.rb', line 26

def weight
  @weight
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_variants.rb', line 77

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  price = hash.key?('price') ? hash['price'] : nil
  quantity = hash.key?('quantity') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:DataGetProductVariantsQuantity), hash['quantity']
  ) : nil
  weight = hash.key?('weight') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:DataGetProductVariantsWeight), hash['weight']
  ) : nil
  sku_num = hash.key?('sku_num') ? hash['sku_num'] : nil
  # Parameter is an array, so we need to iterate through it
  attributes = nil
  unless hash['attributes'].nil?
    attributes = []
    hash['attributes'].each do |structure|
      attributes << (AttributeData.from_hash(structure) if structure)
    end
  end

  attributes = nil unless hash.key?('attributes')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DataGetProductVariants.new(id: id,
                             price: price,
                             quantity: quantity,
                             weight: weight,
                             sku_num: sku_num,
                             attributes: attributes,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_variants.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['price'] = 'price'
  @_hash['quantity'] = 'quantity'
  @_hash['weight'] = 'weight'
  @_hash['sku_num'] = 'sku_num'
  @_hash['attributes'] = 'attributes'
  @_hash
end

.nullablesObject

An array for nullable fields



54
55
56
57
58
59
60
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_variants.rb', line 54

def self.nullables
  %w[
    price
    quantity
    weight
  ]
end

.optionalsObject

An array for optional fields



49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_variants.rb', line 49

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_variants.rb', line 120

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.id,
                            ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.price,
                              ->(val) { val.instance_of? String }) and
        UnionTypeLookUp.get(:DataGetProductVariantsQuantity)
                       .validate(value.quantity) and
        UnionTypeLookUp.get(:DataGetProductVariantsWeight)
                       .validate(value.weight) and
        APIHelper.valid_type?(value.sku_num,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.attributes,
                              ->(val) { AttributeData.validate(val) },
                              is_model_hash: true,
                              is_inner_model_hash: true)
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['id'],
                          ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['price'],
                            ->(val) { val.instance_of? String }) and
      UnionTypeLookUp.get(:DataGetProductVariantsQuantity)
                     .validate(value['quantity']) and
      UnionTypeLookUp.get(:DataGetProductVariantsWeight)
                     .validate(value['weight']) and
      APIHelper.valid_type?(value['sku_num'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['attributes'],
                            ->(val) { AttributeData.validate(val) },
                            is_model_hash: true,
                            is_inner_model_hash: true)
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



169
170
171
172
173
174
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_variants.rb', line 169

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, price: #{@price.inspect}, quantity:"\
  " #{@quantity.inspect}, weight: #{@weight.inspect}, sku_num: #{@sku_num.inspect},"\
  " attributes: #{@attributes.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



161
162
163
164
165
166
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_product_variants.rb', line 161

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, price: #{@price}, quantity: #{@quantity}, weight: #{@weight},"\
  " sku_num: #{@sku_num}, attributes: #{@attributes}, additional_properties:"\
  " #{@additional_properties}>"
end