Class: StickyIoRestfulApiV2025731::DataGetRefundNoteTemplates

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/data_get_refund_note_templates.rb

Overview

DataGetRefundNoteTemplates Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, name:, is_global:, is_editable:, campaigns:, content:, additional_properties: nil) ⇒ DataGetRefundNoteTemplates

Returns a new instance of DataGetRefundNoteTemplates.



58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_refund_note_templates.rb', line 58

def initialize(id:, name:, is_global:, is_editable:, campaigns:, content:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @name = name
  @is_global = is_global
  @is_editable = is_editable
  @campaigns = campaigns
  @content = content
  @additional_properties = additional_properties
end

Instance Attribute Details

#campaignsArray[Object]

TODO: Write general description for this method

Returns:

  • (Array[Object])


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_refund_note_templates.rb', line 30

def campaigns
  @campaigns
end

#contentString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_refund_note_templates.rb', line 34

def content
  @content
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_refund_note_templates.rb', line 14

def id
  @id
end

#is_editableInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_refund_note_templates.rb', line 26

def is_editable
  @is_editable
end

#is_globalInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_refund_note_templates.rb', line 22

def is_global
  @is_global
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_refund_note_templates.rb', line 18

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_refund_note_templates.rb', line 73

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  name = hash.key?('name') ? hash['name'] : nil
  is_global = hash.key?('is_global') ? hash['is_global'] : nil
  is_editable = hash.key?('is_editable') ? hash['is_editable'] : nil
  campaigns = hash.key?('campaigns') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:DataGetRefundNoteTemplatesCampaigns), hash['campaigns']
  ) : nil
  content = hash.key?('content') ? hash['content'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DataGetRefundNoteTemplates.new(id: id,
                                 name: name,
                                 is_global: is_global,
                                 is_editable: is_editable,
                                 campaigns: campaigns,
                                 content: content,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_refund_note_templates.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['name'] = 'name'
  @_hash['is_global'] = 'is_global'
  @_hash['is_editable'] = 'is_editable'
  @_hash['campaigns'] = 'campaigns'
  @_hash['content'] = 'content'
  @_hash
end

.nullablesObject

An array for nullable fields



54
55
56
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_refund_note_templates.rb', line 54

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_refund_note_templates.rb', line 49

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_refund_note_templates.rb', line 105

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.id,
                            ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.name,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.is_global,
                              ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.is_editable,
                              ->(val) { val.instance_of? Integer }) and
        UnionTypeLookUp.get(:DataGetRefundNoteTemplatesCampaigns)
                       .validate(value.campaigns) and
        APIHelper.valid_type?(value.content,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['id'],
                          ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['name'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['is_global'],
                            ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['is_editable'],
                            ->(val) { val.instance_of? Integer }) and
      UnionTypeLookUp.get(:DataGetRefundNoteTemplatesCampaigns)
                     .validate(value['campaigns']) and
      APIHelper.valid_type?(value['content'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



150
151
152
153
154
155
156
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_refund_note_templates.rb', line 150

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, is_global:"\
  " #{@is_global.inspect}, is_editable: #{@is_editable.inspect}, campaigns:"\
  " #{@campaigns.inspect}, content: #{@content.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



142
143
144
145
146
147
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_refund_note_templates.rb', line 142

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, name: #{@name}, is_global: #{@is_global}, is_editable:"\
  " #{@is_editable}, campaigns: #{@campaigns}, content: #{@content}, additional_properties:"\
  " #{@additional_properties}>"
end