Class: StickyIoRestfulApiV2025731::DataGetShippingMethod
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::DataGetShippingMethod
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb
Overview
DataGetShippingMethod Model.
Instance Attribute Summary collapse
-
#amount_recurring ⇒ String
TODO: Write general description for this method.
-
#amount_trial ⇒ String
TODO: Write general description for this method.
-
#created_at ⇒ CreatedAt
TODO: Write general description for this method.
-
#description ⇒ String
TODO: Write general description for this method.
-
#freight_code ⇒ String
TODO: Write general description for this method.
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#service_code ⇒ String
TODO: Write general description for this method.
-
#threshold_amount ⇒ String
TODO: Write general description for this method.
-
#threshold_charge_amount ⇒ String
TODO: Write general description for this method.
-
#type ⇒ TypeData1
TODO: Write general description for this method.
-
#updated_at ⇒ UpdatedAtData
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(freight_code:, threshold_amount:, threshold_charge_amount:, id:, name:, description:, amount_trial:, amount_recurring:, type:, service_code:, created_at:, updated_at:, additional_properties: nil) ⇒ DataGetShippingMethod
constructor
A new instance of DataGetShippingMethod.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(freight_code:, threshold_amount:, threshold_charge_amount:, id:, name:, description:, amount_trial:, amount_recurring:, type:, service_code:, created_at:, updated_at:, additional_properties: nil) ⇒ DataGetShippingMethod
Returns a new instance of DataGetShippingMethod.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 88 def initialize(freight_code:, threshold_amount:, threshold_charge_amount:, id:, name:, description:, amount_trial:, amount_recurring:, type:, service_code:, created_at:, updated_at:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @freight_code = freight_code @threshold_amount = threshold_amount @threshold_charge_amount = threshold_charge_amount @id = id @name = name @description = description @amount_trial = amount_trial @amount_recurring = amount_recurring @type = type @service_code = service_code @created_at = created_at @updated_at = updated_at @additional_properties = additional_properties end |
Instance Attribute Details
#amount_recurring ⇒ String
TODO: Write general description for this method
42 43 44 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 42 def amount_recurring @amount_recurring end |
#amount_trial ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 38 def amount_trial @amount_trial end |
#created_at ⇒ CreatedAt
TODO: Write general description for this method
54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 54 def created_at @created_at end |
#description ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 34 def description @description end |
#freight_code ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 14 def freight_code @freight_code end |
#id ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 26 def id @id end |
#name ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 30 def name @name end |
#service_code ⇒ String
TODO: Write general description for this method
50 51 52 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 50 def service_code @service_code end |
#threshold_amount ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 18 def threshold_amount @threshold_amount end |
#threshold_charge_amount ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 22 def threshold_charge_amount @threshold_charge_amount end |
#type ⇒ TypeData1
TODO: Write general description for this method
46 47 48 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 46 def type @type end |
#updated_at ⇒ UpdatedAtData
TODO: Write general description for this method
58 59 60 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 58 def updated_at @updated_at end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 111 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. freight_code = hash.key?('freight_code') ? hash['freight_code'] : nil threshold_amount = hash.key?('threshold_amount') ? hash['threshold_amount'] : nil threshold_charge_amount = hash.key?('threshold_charge_amount') ? hash['threshold_charge_amount'] : nil id = hash.key?('id') ? hash['id'] : nil name = hash.key?('name') ? hash['name'] : nil description = hash.key?('description') ? hash['description'] : nil amount_trial = hash.key?('amount_trial') ? hash['amount_trial'] : nil amount_recurring = hash.key?('amount_recurring') ? hash['amount_recurring'] : nil type = TypeData1.from_hash(hash['type']) if hash['type'] service_code = hash.key?('service_code') ? hash['service_code'] : nil created_at = CreatedAt.from_hash(hash['created_at']) if hash['created_at'] updated_at = UpdatedAtData.from_hash(hash['updated_at']) if hash['updated_at'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DataGetShippingMethod.new(freight_code: freight_code, threshold_amount: threshold_amount, threshold_charge_amount: threshold_charge_amount, id: id, name: name, description: description, amount_trial: amount_trial, amount_recurring: amount_recurring, type: type, service_code: service_code, created_at: created_at, updated_at: updated_at, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 61 def self.names @_hash = {} if @_hash.nil? @_hash['freight_code'] = 'freight_code' @_hash['threshold_amount'] = 'threshold_amount' @_hash['threshold_charge_amount'] = 'threshold_charge_amount' @_hash['id'] = 'id' @_hash['name'] = 'name' @_hash['description'] = 'description' @_hash['amount_trial'] = 'amount_trial' @_hash['amount_recurring'] = 'amount_recurring' @_hash['type'] = 'type' @_hash['service_code'] = 'service_code' @_hash['created_at'] = 'created_at' @_hash['updated_at'] = 'updated_at' @_hash end |
.nullables ⇒ Object
An array for nullable fields
84 85 86 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 84 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
79 80 81 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 79 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
166 167 168 169 170 171 172 173 174 175 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 166 def inspect class_name = self.class.name.split('::').last "<#{class_name} freight_code: #{@freight_code.inspect}, threshold_amount:"\ " #{@threshold_amount.inspect}, threshold_charge_amount:"\ " #{@threshold_charge_amount.inspect}, id: #{@id.inspect}, name: #{@name.inspect},"\ " description: #{@description.inspect}, amount_trial: #{@amount_trial.inspect},"\ " amount_recurring: #{@amount_recurring.inspect}, type: #{@type.inspect}, service_code:"\ " #{@service_code.inspect}, created_at: #{@created_at.inspect}, updated_at:"\ " #{@updated_at.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
155 156 157 158 159 160 161 162 163 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_shipping_method.rb', line 155 def to_s class_name = self.class.name.split('::').last "<#{class_name} freight_code: #{@freight_code}, threshold_amount: #{@threshold_amount},"\ " threshold_charge_amount: #{@threshold_charge_amount}, id: #{@id}, name: #{@name},"\ " description: #{@description}, amount_trial: #{@amount_trial}, amount_recurring:"\ " #{@amount_recurring}, type: #{@type}, service_code: #{@service_code}, created_at:"\ " #{@created_at}, updated_at: #{@updated_at}, additional_properties:"\ " #{@additional_properties}>" end |