Class: StickyIoRestfulApiV2025731::DataGetSingleCustomField
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::DataGetSingleCustomField
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/data_get_single_custom_field.rb
Overview
DataGetSingleCustomField Model.
Instance Attribute Summary collapse
-
#field_type_id ⇒ Integer
TODO: Write general description for this method.
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#is_multi ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#options ⇒ Array[Option]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id:, field_type_id:, name:, is_multi:, options:, additional_properties: nil) ⇒ DataGetSingleCustomField
constructor
A new instance of DataGetSingleCustomField.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, field_type_id:, name:, is_multi:, options:, additional_properties: nil) ⇒ DataGetSingleCustomField
Returns a new instance of DataGetSingleCustomField.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_single_custom_field.rb', line 53 def initialize(id:, field_type_id:, name:, is_multi:, options:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @field_type_id = field_type_id @name = name @is_multi = is_multi @options = @additional_properties = additional_properties end |
Instance Attribute Details
#field_type_id ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_single_custom_field.rb', line 18 def field_type_id @field_type_id end |
#id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_single_custom_field.rb', line 14 def id @id end |
#is_multi ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_single_custom_field.rb', line 26 def is_multi @is_multi end |
#name ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_single_custom_field.rb', line 22 def name @name end |
#options ⇒ Array[Option]
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_single_custom_field.rb', line 30 def @options end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_single_custom_field.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil field_type_id = hash.key?('field_type_id') ? hash['field_type_id'] : nil name = hash.key?('name') ? hash['name'] : nil is_multi = hash.key?('is_multi') ? hash['is_multi'] : nil # Parameter is an array, so we need to iterate through it = nil unless hash['options'].nil? = [] hash['options'].each do |structure| << (Option.from_hash(structure) if structure) end end = nil unless hash.key?('options') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DataGetSingleCustomField.new(id: id, field_type_id: field_type_id, name: name, is_multi: is_multi, options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_single_custom_field.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['field_type_id'] = 'field_type_id' @_hash['name'] = 'name' @_hash['is_multi'] = 'is_multi' @_hash['options'] = 'options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_single_custom_field.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_single_custom_field.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
110 111 112 113 114 115 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_single_custom_field.rb', line 110 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, field_type_id: #{@field_type_id.inspect}, name:"\ " #{@name.inspect}, is_multi: #{@is_multi.inspect}, options: #{@options.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
103 104 105 106 107 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_single_custom_field.rb', line 103 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, field_type_id: #{@field_type_id}, name: #{@name}, is_multi:"\ " #{@is_multi}, options: #{@options}, additional_properties: #{@additional_properties}>" end |