Class: StickyIoRestfulApiV2025731::DataGetSubscriptionCredit

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/data_get_subscription_credit.rb

Overview

DataGetSubscriptionCredit Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(item_id:, amount:, created_at:, updated_at:, type:, creator:, updator:, additional_properties: nil) ⇒ DataGetSubscriptionCredit

Returns a new instance of DataGetSubscriptionCredit.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_subscription_credit.rb', line 63

def initialize(item_id:, amount:, created_at:, updated_at:, type:, creator:,
               updator:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @item_id = item_id
  @amount = amount
  @created_at = created_at
  @updated_at = updated_at
  @type = type
  @creator = creator
  @updator = updator
  @additional_properties = additional_properties
end

Instance Attribute Details

#amountString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_subscription_credit.rb', line 18

def amount
  @amount
end

#created_atString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_subscription_credit.rb', line 22

def created_at
  @created_at
end

#creatorCreator

TODO: Write general description for this method

Returns:



34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_subscription_credit.rb', line 34

def creator
  @creator
end

#item_idString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_subscription_credit.rb', line 14

def item_id
  @item_id
end

#typeTypeData

TODO: Write general description for this method

Returns:



30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_subscription_credit.rb', line 30

def type
  @type
end

#updated_atString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_subscription_credit.rb', line 26

def updated_at
  @updated_at
end

#updatorUpdatorData

TODO: Write general description for this method

Returns:



38
39
40
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_subscription_credit.rb', line 38

def updator
  @updator
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_subscription_credit.rb', line 79

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  item_id = hash.key?('item_id') ? hash['item_id'] : nil
  amount = hash.key?('amount') ? hash['amount'] : nil
  created_at = hash.key?('created_at') ? hash['created_at'] : nil
  updated_at = hash.key?('updated_at') ? hash['updated_at'] : nil
  type = TypeData.from_hash(hash['type']) if hash['type']
  creator = Creator.from_hash(hash['creator']) if hash['creator']
  updator = UpdatorData.from_hash(hash['updator']) if hash['updator']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DataGetSubscriptionCredit.new(item_id: item_id,
                                amount: amount,
                                created_at: created_at,
                                updated_at: updated_at,
                                type: type,
                                creator: creator,
                                updator: updator,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_subscription_credit.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['item_id'] = 'item_id'
  @_hash['amount'] = 'amount'
  @_hash['created_at'] = 'created_at'
  @_hash['updated_at'] = 'updated_at'
  @_hash['type'] = 'type'
  @_hash['creator'] = 'creator'
  @_hash['updator'] = 'updator'
  @_hash
end

.nullablesObject

An array for nullable fields



59
60
61
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_subscription_credit.rb', line 59

def self.nullables
  []
end

.optionalsObject

An array for optional fields



54
55
56
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_subscription_credit.rb', line 54

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



118
119
120
121
122
123
124
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_subscription_credit.rb', line 118

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} item_id: #{@item_id.inspect}, amount: #{@amount.inspect}, created_at:"\
  " #{@created_at.inspect}, updated_at: #{@updated_at.inspect}, type: #{@type.inspect},"\
  " creator: #{@creator.inspect}, updator: #{@updator.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



110
111
112
113
114
115
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_subscription_credit.rb', line 110

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} item_id: #{@item_id}, amount: #{@amount}, created_at: #{@created_at},"\
  " updated_at: #{@updated_at}, type: #{@type}, creator: #{@creator}, updator: #{@updator},"\
  " additional_properties: #{@additional_properties}>"
end