Class: StickyIoRestfulApiV2025731::DataSetProductImages

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/data_set_product_images.rb

Overview

DataSetProductImages Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, uuid:, malias:, created_at:, updated_at:, path:, is_default:, is_default_email:, additional_properties: nil) ⇒ DataSetProductImages

Returns a new instance of DataSetProductImages.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/sticky_io_restful_api_v2025731/models/data_set_product_images.rb', line 68

def initialize(id:, uuid:, malias:, created_at:, updated_at:, path:,
               is_default:, is_default_email:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @uuid = uuid
  @malias = malias
  @created_at = created_at
  @updated_at = updated_at
  @path = path
  @is_default = is_default
  @is_default_email = is_default_email
  @additional_properties = additional_properties
end

Instance Attribute Details

#created_atString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/data_set_product_images.rb', line 26

def created_at
  @created_at
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/data_set_product_images.rb', line 14

def id
  @id
end

#is_defaultInteger

TODO: Write general description for this method

Returns:

  • (Integer)


38
39
40
# File 'lib/sticky_io_restful_api_v2025731/models/data_set_product_images.rb', line 38

def is_default
  @is_default
end

#is_default_emailInteger

TODO: Write general description for this method

Returns:

  • (Integer)


42
43
44
# File 'lib/sticky_io_restful_api_v2025731/models/data_set_product_images.rb', line 42

def is_default_email
  @is_default_email
end

#maliasString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/data_set_product_images.rb', line 22

def malias
  @malias
end

#pathString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/data_set_product_images.rb', line 34

def path
  @path
end

#updated_atString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/data_set_product_images.rb', line 30

def updated_at
  @updated_at
end

#uuidString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/data_set_product_images.rb', line 18

def uuid
  @uuid
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/sticky_io_restful_api_v2025731/models/data_set_product_images.rb', line 85

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  uuid = hash.key?('uuid') ? hash['uuid'] : nil
  malias = hash.key?('alias') ? hash['alias'] : nil
  created_at = hash.key?('created_at') ? hash['created_at'] : nil
  updated_at = hash.key?('updated_at') ? hash['updated_at'] : nil
  path = hash.key?('path') ? hash['path'] : nil
  is_default = hash.key?('is_default') ? hash['is_default'] : nil
  is_default_email =
    hash.key?('is_default_email') ? hash['is_default_email'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DataSetProductImages.new(id: id,
                           uuid: uuid,
                           malias: malias,
                           created_at: created_at,
                           updated_at: updated_at,
                           path: path,
                           is_default: is_default,
                           is_default_email: is_default_email,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/sticky_io_restful_api_v2025731/models/data_set_product_images.rb', line 45

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['uuid'] = 'uuid'
  @_hash['malias'] = 'alias'
  @_hash['created_at'] = 'created_at'
  @_hash['updated_at'] = 'updated_at'
  @_hash['path'] = 'path'
  @_hash['is_default'] = 'is_default'
  @_hash['is_default_email'] = 'is_default_email'
  @_hash
end

.nullablesObject

An array for nullable fields



64
65
66
# File 'lib/sticky_io_restful_api_v2025731/models/data_set_product_images.rb', line 64

def self.nullables
  []
end

.optionalsObject

An array for optional fields



59
60
61
# File 'lib/sticky_io_restful_api_v2025731/models/data_set_product_images.rb', line 59

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



127
128
129
130
131
132
133
# File 'lib/sticky_io_restful_api_v2025731/models/data_set_product_images.rb', line 127

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, uuid: #{@uuid.inspect}, malias: #{@malias.inspect},"\
  " created_at: #{@created_at.inspect}, updated_at: #{@updated_at.inspect}, path:"\
  " #{@path.inspect}, is_default: #{@is_default.inspect}, is_default_email:"\
  " #{@is_default_email.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



119
120
121
122
123
124
# File 'lib/sticky_io_restful_api_v2025731/models/data_set_product_images.rb', line 119

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, uuid: #{@uuid}, malias: #{@malias}, created_at: #{@created_at},"\
  " updated_at: #{@updated_at}, path: #{@path}, is_default: #{@is_default}, is_default_email:"\
  " #{@is_default_email}, additional_properties: #{@additional_properties}>"
end