Class: StickyIoRestfulApiV2025731::DataUpdateBillingModel

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb

Overview

DataUpdateBillingModel Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, name:, created_at:, updated_at:, is_archived:, is_preserve_quantity:, is_default:, date:, description:, type:, frequency:, frequency_type_id:, creator:, updator:, additional_properties: nil) ⇒ DataUpdateBillingModel

Returns a new instance of DataUpdateBillingModel.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 100

def initialize(id:, name:, created_at:, updated_at:, is_archived:,
               is_preserve_quantity:, is_default:, date:, description:,
               type:, frequency:, frequency_type_id:, creator:, updator:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @name = name
  @created_at = created_at
  @updated_at = updated_at
  @is_archived = is_archived
  @is_preserve_quantity = is_preserve_quantity
  @is_default = is_default
  @date = date
  @description = description
  @type = type
  @frequency = frequency
  @frequency_type_id = frequency_type_id
  @creator = creator
  @updator = updator
  @additional_properties = additional_properties
end

Instance Attribute Details

#created_atCreatedAt

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 22

def created_at
  @created_at
end

#creatorCreatorData

TODO: Write general description for this method

Returns:



62
63
64
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 62

def creator
  @creator
end

#dateInteger

TODO: Write general description for this method

Returns:

  • (Integer)


42
43
44
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 42

def date
  @date
end

#descriptionString

TODO: Write general description for this method

Returns:

  • (String)


46
47
48
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 46

def description
  @description
end

#frequencyInteger

TODO: Write general description for this method

Returns:

  • (Integer)


54
55
56
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 54

def frequency
  @frequency
end

#frequency_type_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


58
59
60
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 58

def frequency_type_id
  @frequency_type_id
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 14

def id
  @id
end

#is_archivedInteger

TODO: Write general description for this method

Returns:

  • (Integer)


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 30

def is_archived
  @is_archived
end

#is_defaultString

TODO: Write general description for this method

Returns:

  • (String)


38
39
40
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 38

def is_default
  @is_default
end

#is_preserve_quantityInteger

TODO: Write general description for this method

Returns:

  • (Integer)


34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 34

def is_preserve_quantity
  @is_preserve_quantity
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 18

def name
  @name
end

#typeTypeData

TODO: Write general description for this method

Returns:



50
51
52
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 50

def type
  @type
end

#updated_atUpdatedAtData

TODO: Write general description for this method

Returns:



26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 26

def updated_at
  @updated_at
end

#updatorUpdatorData1

TODO: Write general description for this method

Returns:



66
67
68
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 66

def updator
  @updator
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 125

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  name = hash.key?('name') ? hash['name'] : nil
  created_at = CreatedAt.from_hash(hash['created_at']) if hash['created_at']
  updated_at = UpdatedAtData.from_hash(hash['updated_at']) if hash['updated_at']
  is_archived = hash.key?('is_archived') ? hash['is_archived'] : nil
  is_preserve_quantity =
    hash.key?('is_preserve_quantity') ? hash['is_preserve_quantity'] : nil
  is_default = hash.key?('is_default') ? hash['is_default'] : nil
  date = hash.key?('date') ? hash['date'] : nil
  description = hash.key?('description') ? hash['description'] : nil
  type = TypeData.from_hash(hash['type']) if hash['type']
  frequency = hash.key?('frequency') ? hash['frequency'] : nil
  frequency_type_id =
    hash.key?('frequency_type_id') ? hash['frequency_type_id'] : nil
  creator = CreatorData.from_hash(hash['creator']) if hash['creator']
  updator = UpdatorData1.from_hash(hash['updator']) if hash['updator']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DataUpdateBillingModel.new(id: id,
                             name: name,
                             created_at: created_at,
                             updated_at: updated_at,
                             is_archived: is_archived,
                             is_preserve_quantity: is_preserve_quantity,
                             is_default: is_default,
                             date: date,
                             description: description,
                             type: type,
                             frequency: frequency,
                             frequency_type_id: frequency_type_id,
                             creator: creator,
                             updator: updator,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 69

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['name'] = 'name'
  @_hash['created_at'] = 'created_at'
  @_hash['updated_at'] = 'updated_at'
  @_hash['is_archived'] = 'is_archived'
  @_hash['is_preserve_quantity'] = 'is_preserve_quantity'
  @_hash['is_default'] = 'is_default'
  @_hash['date'] = 'date'
  @_hash['description'] = 'description'
  @_hash['type'] = 'type'
  @_hash['frequency'] = 'frequency'
  @_hash['frequency_type_id'] = 'frequency_type_id'
  @_hash['creator'] = 'creator'
  @_hash['updator'] = 'updator'
  @_hash
end

.nullablesObject

An array for nullable fields



94
95
96
97
98
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 94

def self.nullables
  %w[
    is_default
  ]
end

.optionalsObject

An array for optional fields



89
90
91
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 89

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



183
184
185
186
187
188
189
190
191
192
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 183

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, created_at:"\
  " #{@created_at.inspect}, updated_at: #{@updated_at.inspect}, is_archived:"\
  " #{@is_archived.inspect}, is_preserve_quantity: #{@is_preserve_quantity.inspect},"\
  " is_default: #{@is_default.inspect}, date: #{@date.inspect}, description:"\
  " #{@description.inspect}, type: #{@type.inspect}, frequency: #{@frequency.inspect},"\
  " frequency_type_id: #{@frequency_type_id.inspect}, creator: #{@creator.inspect}, updator:"\
  " #{@updator.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



172
173
174
175
176
177
178
179
180
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_billing_model.rb', line 172

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, name: #{@name}, created_at: #{@created_at}, updated_at:"\
  " #{@updated_at}, is_archived: #{@is_archived}, is_preserve_quantity:"\
  " #{@is_preserve_quantity}, is_default: #{@is_default}, date: #{@date}, description:"\
  " #{@description}, type: #{@type}, frequency: #{@frequency}, frequency_type_id:"\
  " #{@frequency_type_id}, creator: #{@creator}, updator: #{@updator}, additional_properties:"\
  " #{@additional_properties}>"
end