Class: StickyIoRestfulApiV2025731::DataUpdateShippingType

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/data_update_shipping_type.rb

Overview

DataUpdateShippingType Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, name:, code:, created_at:, updated_at:, additional_properties: nil) ⇒ DataUpdateShippingType

Returns a new instance of DataUpdateShippingType.



53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_shipping_type.rb', line 53

def initialize(id:, name:, code:, created_at:, updated_at:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @name = name
  @code = code
  @created_at = created_at
  @updated_at = updated_at
  @additional_properties = additional_properties
end

Instance Attribute Details

#codeString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_shipping_type.rb', line 22

def code
  @code
end

#created_atCreatedAt

TODO: Write general description for this method

Returns:



26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_shipping_type.rb', line 26

def created_at
  @created_at
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_shipping_type.rb', line 14

def id
  @id
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_shipping_type.rb', line 18

def name
  @name
end

#updated_atUpdatedAtData

TODO: Write general description for this method

Returns:



30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_shipping_type.rb', line 30

def updated_at
  @updated_at
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_shipping_type.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  name = hash.key?('name') ? hash['name'] : nil
  code = hash.key?('code') ? hash['code'] : nil
  created_at = CreatedAt.from_hash(hash['created_at']) if hash['created_at']
  updated_at = UpdatedAtData.from_hash(hash['updated_at']) if hash['updated_at']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DataUpdateShippingType.new(id: id,
                             name: name,
                             code: code,
                             created_at: created_at,
                             updated_at: updated_at,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_shipping_type.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['name'] = 'name'
  @_hash['code'] = 'code'
  @_hash['created_at'] = 'created_at'
  @_hash['updated_at'] = 'updated_at'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_shipping_type.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_shipping_type.rb', line 44

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



101
102
103
104
105
106
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_shipping_type.rb', line 101

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, code: #{@code.inspect},"\
  " created_at: #{@created_at.inspect}, updated_at: #{@updated_at.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



94
95
96
97
98
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_shipping_type.rb', line 94

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, name: #{@name}, code: #{@code}, created_at: #{@created_at},"\
  " updated_at: #{@updated_at}, additional_properties: #{@additional_properties}>"
end