Class: StickyIoRestfulApiV2025731::Date
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::Date
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/date.rb
Overview
Date Model.
Instance Attribute Summary collapse
-
#billing_model_id ⇒ Integer
TODO: Write general description for this method.
-
#day ⇒ Integer
TODO: Write general description for this method.
-
#month ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(billing_model_id: SKIP, month: SKIP, day: SKIP, additional_properties: nil) ⇒ Date
constructor
A new instance of Date.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(billing_model_id: SKIP, month: SKIP, day: SKIP, additional_properties: nil) ⇒ Date
Returns a new instance of Date.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/date.rb', line 47 def initialize(billing_model_id: SKIP, month: SKIP, day: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @billing_model_id = billing_model_id unless billing_model_id == SKIP @month = month unless month == SKIP @day = day unless day == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#billing_model_id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/date.rb', line 14 def billing_model_id @billing_model_id end |
#day ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/date.rb', line 22 def day @day end |
#month ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/date.rb', line 18 def month @month end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/sticky_io_restful_api_v2025731/models/date.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. billing_model_id = hash.key?('billing_model_id') ? hash['billing_model_id'] : SKIP month = hash.key?('month') ? hash['month'] : SKIP day = hash.key?('day') ? hash['day'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Date.new(billing_model_id: billing_model_id, month: month, day: day, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/sticky_io_restful_api_v2025731/models/date.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['billing_model_id'] = 'billing_model_id' @_hash['month'] = 'month' @_hash['day'] = 'day' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/sticky_io_restful_api_v2025731/models/date.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/sticky_io_restful_api_v2025731/models/date.rb', line 34 def self.optionals %w[ billing_model_id month day ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
84 85 86 87 88 89 90 |
# File 'lib/sticky_io_restful_api_v2025731/models/date.rb', line 84 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
100 101 102 103 104 |
# File 'lib/sticky_io_restful_api_v2025731/models/date.rb', line 100 def inspect class_name = self.class.name.split('::').last "<#{class_name} billing_model_id: #{@billing_model_id.inspect}, month: #{@month.inspect},"\ " day: #{@day.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 |
# File 'lib/sticky_io_restful_api_v2025731/models/date.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} billing_model_id: #{@billing_model_id}, month: #{@month}, day: #{@day},"\ " additional_properties: #{@additional_properties}>" end |