Class: StickyIoRestfulApiV2025731::DateOneOf1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/date_one_of1.rb

Overview

DateOneOf1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(billing_model_id:, month:, day:, additional_properties: nil) ⇒ DateOneOf1

Returns a new instance of DateOneOf1.



43
44
45
46
47
48
49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/date_one_of1.rb', line 43

def initialize(billing_model_id:, month:, day:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @billing_model_id = billing_model_id
  @month = month
  @day = day
  @additional_properties = additional_properties
end

Instance Attribute Details

#billing_model_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/date_one_of1.rb', line 14

def billing_model_id
  @billing_model_id
end

#dayInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/date_one_of1.rb', line 22

def day
  @day
end

#monthInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/date_one_of1.rb', line 18

def month
  @month
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/sticky_io_restful_api_v2025731/models/date_one_of1.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  billing_model_id =
    hash.key?('billing_model_id') ? hash['billing_model_id'] : nil
  month = hash.key?('month') ? hash['month'] : nil
  day = hash.key?('day') ? hash['day'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DateOneOf1.new(billing_model_id: billing_model_id,
                 month: month,
                 day: day,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/sticky_io_restful_api_v2025731/models/date_one_of1.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['billing_model_id'] = 'billing_model_id'
  @_hash['month'] = 'month'
  @_hash['day'] = 'day'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/sticky_io_restful_api_v2025731/models/date_one_of1.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/date_one_of1.rb', line 34

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (DateOneOf1 | Hash)

    value against the validation is performed.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/sticky_io_restful_api_v2025731/models/date_one_of1.rb', line 79

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.billing_model_id,
                            ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.month,
                              ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.day,
                              ->(val) { val.instance_of? Integer })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['billing_model_id'],
                          ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['month'],
                            ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['day'],
                            ->(val) { val.instance_of? Integer })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



111
112
113
114
115
# File 'lib/sticky_io_restful_api_v2025731/models/date_one_of1.rb', line 111

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} billing_model_id: #{@billing_model_id.inspect}, month: #{@month.inspect},"\
  " day: #{@day.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



104
105
106
107
108
# File 'lib/sticky_io_restful_api_v2025731/models/date_one_of1.rb', line 104

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} billing_model_id: #{@billing_model_id}, month: #{@month}, day: #{@day},"\
  " additional_properties: #{@additional_properties}>"
end