Class: StickyIoRestfulApiV2025731::DelayedBillingTrial

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/delayed_billing_trial.rb

Overview

DelayedBillingTrial Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(is_delayed_email_suppressed:, is_custom_price:, price:, days:, additional_properties: nil) ⇒ DelayedBillingTrial

Returns a new instance of DelayedBillingTrial.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/sticky_io_restful_api_v2025731/models/delayed_billing_trial.rb', line 48

def initialize(is_delayed_email_suppressed:, is_custom_price:, price:,
               days:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @is_delayed_email_suppressed = is_delayed_email_suppressed
  @is_custom_price = is_custom_price
  @price = price
  @days = days
  @additional_properties = additional_properties
end

Instance Attribute Details

#daysInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/delayed_billing_trial.rb', line 26

def days
  @days
end

#is_custom_priceInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/delayed_billing_trial.rb', line 18

def is_custom_price
  @is_custom_price
end

#is_delayed_email_suppressedInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/delayed_billing_trial.rb', line 14

def is_delayed_email_suppressed
  @is_delayed_email_suppressed
end

#priceString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/delayed_billing_trial.rb', line 22

def price
  @price
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/sticky_io_restful_api_v2025731/models/delayed_billing_trial.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  is_delayed_email_suppressed =
    hash.key?('is_delayed_email_suppressed') ? hash['is_delayed_email_suppressed'] : nil
  is_custom_price =
    hash.key?('is_custom_price') ? hash['is_custom_price'] : nil
  price = hash.key?('price') ? hash['price'] : nil
  days = hash.key?('days') ? hash['days'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DelayedBillingTrial.new(is_delayed_email_suppressed: is_delayed_email_suppressed,
                          is_custom_price: is_custom_price,
                          price: price,
                          days: days,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/delayed_billing_trial.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['is_delayed_email_suppressed'] = 'is_delayed_email_suppressed'
  @_hash['is_custom_price'] = 'is_custom_price'
  @_hash['price'] = 'price'
  @_hash['days'] = 'days'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/sticky_io_restful_api_v2025731/models/delayed_billing_trial.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/sticky_io_restful_api_v2025731/models/delayed_billing_trial.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



96
97
98
99
100
101
# File 'lib/sticky_io_restful_api_v2025731/models/delayed_billing_trial.rb', line 96

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} is_delayed_email_suppressed: #{@is_delayed_email_suppressed.inspect},"\
  " is_custom_price: #{@is_custom_price.inspect}, price: #{@price.inspect}, days:"\
  " #{@days.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



88
89
90
91
92
93
# File 'lib/sticky_io_restful_api_v2025731/models/delayed_billing_trial.rb', line 88

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} is_delayed_email_suppressed: #{@is_delayed_email_suppressed},"\
  " is_custom_price: #{@is_custom_price}, price: #{@price}, days: #{@days},"\
  " additional_properties: #{@additional_properties}>"
end