Class: StickyIoRestfulApiV2025731::DiscountCreateCouponProfileRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::DiscountCreateCouponProfileRequest
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/discount_create_coupon_profile_request.rb
Overview
DiscountCreateCouponProfileRequest Model.
Instance Attribute Summary collapse
-
#behavior_type_id ⇒ Integer
TODO: Write general description for this method.
-
#percent ⇒ Integer
TODO: Write general description for this method.
-
#type_id ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(type_id:, behavior_type_id:, percent:, additional_properties: nil) ⇒ DiscountCreateCouponProfileRequest
constructor
A new instance of DiscountCreateCouponProfileRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(type_id:, behavior_type_id:, percent:, additional_properties: nil) ⇒ DiscountCreateCouponProfileRequest
Returns a new instance of DiscountCreateCouponProfileRequest.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_create_coupon_profile_request.rb', line 43 def initialize(type_id:, behavior_type_id:, percent:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @type_id = type_id @behavior_type_id = behavior_type_id @percent = percent @additional_properties = additional_properties end |
Instance Attribute Details
#behavior_type_id ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_create_coupon_profile_request.rb', line 18 def behavior_type_id @behavior_type_id end |
#percent ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_create_coupon_profile_request.rb', line 22 def percent @percent end |
#type_id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_create_coupon_profile_request.rb', line 14 def type_id @type_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_create_coupon_profile_request.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. type_id = hash.key?('type_id') ? hash['type_id'] : nil behavior_type_id = hash.key?('behavior_type_id') ? hash['behavior_type_id'] : nil percent = hash.key?('percent') ? hash['percent'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DiscountCreateCouponProfileRequest.new(type_id: type_id, behavior_type_id: behavior_type_id, percent: percent, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_create_coupon_profile_request.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['type_id'] = 'type_id' @_hash['behavior_type_id'] = 'behavior_type_id' @_hash['percent'] = 'percent' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_create_coupon_profile_request.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_create_coupon_profile_request.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 91 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_create_coupon_profile_request.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} type_id: #{@type_id.inspect}, behavior_type_id:"\ " #{@behavior_type_id.inspect}, percent: #{@percent.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_create_coupon_profile_request.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} type_id: #{@type_id}, behavior_type_id: #{@behavior_type_id}, percent:"\ " #{@percent}, additional_properties: #{@additional_properties}>" end |