Class: StickyIoRestfulApiV2025731::DiscountOneOf0
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::DiscountOneOf0
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/discount_one_of0.rb
Overview
DiscountOneOf0 Model.
Instance Attribute Summary collapse
-
#amount ⇒ String
TODO: Write general description for this method.
-
#percent ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(percent: SKIP, amount: SKIP, additional_properties: nil) ⇒ DiscountOneOf0
constructor
A new instance of DiscountOneOf0.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(percent: SKIP, amount: SKIP, additional_properties: nil) ⇒ DiscountOneOf0
Returns a new instance of DiscountOneOf0.
43 44 45 46 47 48 49 50 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_one_of0.rb', line 43 def initialize(percent: SKIP, amount: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @percent = percent unless percent == SKIP @amount = amount unless amount == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_one_of0.rb', line 18 def amount @amount end |
#percent ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_one_of0.rb', line 14 def percent @percent end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_one_of0.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. percent = hash.key?('percent') ? hash['percent'] : SKIP amount = hash.key?('amount') ? hash['amount'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DiscountOneOf0.new(percent: percent, amount: amount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_one_of0.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['percent'] = 'percent' @_hash['amount'] = 'amount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_one_of0.rb', line 37 def self.nullables %w[ amount ] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_one_of0.rb', line 29 def self.optionals %w[ percent amount ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
75 76 77 78 79 80 81 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_one_of0.rb', line 75 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
91 92 93 94 95 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_one_of0.rb', line 91 def inspect class_name = self.class.name.split('::').last "<#{class_name} percent: #{@percent.inspect}, amount: #{@amount.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
84 85 86 87 88 |
# File 'lib/sticky_io_restful_api_v2025731/models/discount_one_of0.rb', line 84 def to_s class_name = self.class.name.split('::').last "<#{class_name} percent: #{@percent}, amount: #{@amount}, additional_properties:"\ " #{@additional_properties}>" end |