Class: StickyIoRestfulApiV2025731::ExpiresAt

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/expires_at.rb

Overview

ExpiresAt Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(date:, timezone_type:, timezone:, additional_properties: nil) ⇒ ExpiresAt

Returns a new instance of ExpiresAt.



43
44
45
46
47
48
49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/expires_at.rb', line 43

def initialize(date:, timezone_type:, timezone:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @date = date
  @timezone_type = timezone_type
  @timezone = timezone
  @additional_properties = additional_properties
end

Instance Attribute Details

#dateString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/expires_at.rb', line 14

def date
  @date
end

#timezoneString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/expires_at.rb', line 22

def timezone
  @timezone
end

#timezone_typeInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/expires_at.rb', line 18

def timezone_type
  @timezone_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/sticky_io_restful_api_v2025731/models/expires_at.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  date = hash.key?('date') ? hash['date'] : nil
  timezone_type = hash.key?('timezone_type') ? hash['timezone_type'] : nil
  timezone = hash.key?('timezone') ? hash['timezone'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ExpiresAt.new(date: date,
                timezone_type: timezone_type,
                timezone: timezone,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/sticky_io_restful_api_v2025731/models/expires_at.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['date'] = 'date'
  @_hash['timezone_type'] = 'timezone_type'
  @_hash['timezone'] = 'timezone'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/sticky_io_restful_api_v2025731/models/expires_at.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/expires_at.rb', line 34

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (ExpiresAt | Hash)

    value against the validation is performed.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/sticky_io_restful_api_v2025731/models/expires_at.rb', line 78

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.date,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.timezone_type,
                              ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.timezone,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['date'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['timezone_type'],
                            ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['timezone'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



110
111
112
113
114
# File 'lib/sticky_io_restful_api_v2025731/models/expires_at.rb', line 110

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} date: #{@date.inspect}, timezone_type: #{@timezone_type.inspect}, timezone:"\
  " #{@timezone.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



103
104
105
106
107
# File 'lib/sticky_io_restful_api_v2025731/models/expires_at.rb', line 103

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} date: #{@date}, timezone_type: #{@timezone_type}, timezone: #{@timezone},"\
  " additional_properties: #{@additional_properties}>"
end