Class: StickyIoRestfulApiV2025731::FeeFields

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/fee_fields.rb

Overview

FeeFields Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(mastercard:, discover:, american_express:, visa:, other:, batch_fee:, monthly_fee:, additional_properties: nil) ⇒ FeeFields

Returns a new instance of FeeFields.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/sticky_io_restful_api_v2025731/models/fee_fields.rb', line 63

def initialize(mastercard:, discover:, american_express:, visa:, other:,
               batch_fee:, monthly_fee:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @mastercard = mastercard
  @discover = discover
  @american_express = american_express
  @visa = visa
  @other = other
  @batch_fee = batch_fee
  @monthly_fee = monthly_fee
  @additional_properties = additional_properties
end

Instance Attribute Details

#american_expressInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/fee_fields.rb', line 22

def american_express
  @american_express
end

#batch_feeInteger

TODO: Write general description for this method

Returns:

  • (Integer)


34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/fee_fields.rb', line 34

def batch_fee
  @batch_fee
end

#discoverInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/fee_fields.rb', line 18

def discover
  @discover
end

#mastercardInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/fee_fields.rb', line 14

def mastercard
  @mastercard
end

#monthly_feeInteger

TODO: Write general description for this method

Returns:

  • (Integer)


38
39
40
# File 'lib/sticky_io_restful_api_v2025731/models/fee_fields.rb', line 38

def monthly_fee
  @monthly_fee
end

#otherInteger

TODO: Write general description for this method

Returns:

  • (Integer)


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/fee_fields.rb', line 30

def other
  @other
end

#visaInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/fee_fields.rb', line 26

def visa
  @visa
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/sticky_io_restful_api_v2025731/models/fee_fields.rb', line 79

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  mastercard = hash.key?('mastercard') ? hash['mastercard'] : nil
  discover = hash.key?('discover') ? hash['discover'] : nil
  american_express =
    hash.key?('american_express') ? hash['american_express'] : nil
  visa = hash.key?('visa') ? hash['visa'] : nil
  other = hash.key?('other') ? hash['other'] : nil
  batch_fee = hash.key?('batch_fee') ? hash['batch_fee'] : nil
  monthly_fee = hash.key?('monthly_fee') ? hash['monthly_fee'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  FeeFields.new(mastercard: mastercard,
                discover: discover,
                american_express: american_express,
                visa: visa,
                other: other,
                batch_fee: batch_fee,
                monthly_fee: monthly_fee,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/fee_fields.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['mastercard'] = 'mastercard'
  @_hash['discover'] = 'discover'
  @_hash['american_express'] = 'american_express'
  @_hash['visa'] = 'visa'
  @_hash['other'] = 'other'
  @_hash['batch_fee'] = 'batch_fee'
  @_hash['monthly_fee'] = 'monthly_fee'
  @_hash
end

.nullablesObject

An array for nullable fields



59
60
61
# File 'lib/sticky_io_restful_api_v2025731/models/fee_fields.rb', line 59

def self.nullables
  []
end

.optionalsObject

An array for optional fields



54
55
56
# File 'lib/sticky_io_restful_api_v2025731/models/fee_fields.rb', line 54

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



119
120
121
122
123
124
125
# File 'lib/sticky_io_restful_api_v2025731/models/fee_fields.rb', line 119

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} mastercard: #{@mastercard.inspect}, discover: #{@discover.inspect},"\
  " american_express: #{@american_express.inspect}, visa: #{@visa.inspect}, other:"\
  " #{@other.inspect}, batch_fee: #{@batch_fee.inspect}, monthly_fee: #{@monthly_fee.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



111
112
113
114
115
116
# File 'lib/sticky_io_restful_api_v2025731/models/fee_fields.rb', line 111

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} mastercard: #{@mastercard}, discover: #{@discover}, american_express:"\
  " #{@american_express}, visa: #{@visa}, other: #{@other}, batch_fee: #{@batch_fee},"\
  " monthly_fee: #{@monthly_fee}, additional_properties: #{@additional_properties}>"
end