Class: StickyIoRestfulApiV2025731::Fields
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::Fields
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/fields.rb
Overview
Fields Model.
Instance Attribute Summary collapse
-
#account_fields ⇒ AccountFields
TODO: Write general description for this method.
-
#fee_fields ⇒ FeeFields
TODO: Write general description for this method.
-
#global_fields ⇒ GlobalFields
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(global_fields:, account_fields:, fee_fields:, additional_properties: nil) ⇒ Fields
constructor
A new instance of Fields.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(global_fields:, account_fields:, fee_fields:, additional_properties: nil) ⇒ Fields
Returns a new instance of Fields.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/sticky_io_restful_api_v2025731/models/fields.rb', line 43 def initialize(global_fields:, account_fields:, fee_fields:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @global_fields = global_fields @account_fields = account_fields @fee_fields = fee_fields @additional_properties = additional_properties end |
Instance Attribute Details
#account_fields ⇒ AccountFields
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/fields.rb', line 18 def account_fields @account_fields end |
#fee_fields ⇒ FeeFields
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/fields.rb', line 22 def fee_fields @fee_fields end |
#global_fields ⇒ GlobalFields
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/fields.rb', line 14 def global_fields @global_fields end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/sticky_io_restful_api_v2025731/models/fields.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. global_fields = GlobalFields.from_hash(hash['global_fields']) if hash['global_fields'] account_fields = AccountFields.from_hash(hash['account_fields']) if hash['account_fields'] fee_fields = FeeFields.from_hash(hash['fee_fields']) if hash['fee_fields'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Fields.new(global_fields: global_fields, account_fields: account_fields, fee_fields: fee_fields, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/sticky_io_restful_api_v2025731/models/fields.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['global_fields'] = 'global_fields' @_hash['account_fields'] = 'account_fields' @_hash['fee_fields'] = 'fee_fields' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/fields.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/fields.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 90 |
# File 'lib/sticky_io_restful_api_v2025731/models/fields.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} global_fields: #{@global_fields.inspect}, account_fields:"\ " #{@account_fields.inspect}, fee_fields: #{@fee_fields.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/sticky_io_restful_api_v2025731/models/fields.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} global_fields: #{@global_fields}, account_fields: #{@account_fields},"\ " fee_fields: #{@fee_fields}, additional_properties: #{@additional_properties}>" end |