Class: StickyIoRestfulApiV2025731::FieldsUpdateProfileRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/fields_update_profile_request.rb

Overview

FieldsUpdateProfileRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(global_fields:, account_fields:, fee_fields:, additional_properties: nil) ⇒ FieldsUpdateProfileRequest

Returns a new instance of FieldsUpdateProfileRequest.



43
44
45
46
47
48
49
50
51
52
# File 'lib/sticky_io_restful_api_v2025731/models/fields_update_profile_request.rb', line 43

def initialize(global_fields:, account_fields:, fee_fields:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @global_fields = global_fields
  @account_fields = 
  @fee_fields = fee_fields
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_fieldsAccountFieldsFields

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/fields_update_profile_request.rb', line 18

def 
  @account_fields
end

#fee_fieldsFeeFields

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/fields_update_profile_request.rb', line 22

def fee_fields
  @fee_fields
end

#global_fieldsGlobalFieldsFields

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/fields_update_profile_request.rb', line 14

def global_fields
  @global_fields
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/sticky_io_restful_api_v2025731/models/fields_update_profile_request.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  global_fields = GlobalFieldsFields.from_hash(hash['global_fields']) if hash['global_fields']
   = AccountFieldsFields.from_hash(hash['account_fields']) if
    hash['account_fields']
  fee_fields = FeeFields.from_hash(hash['fee_fields']) if hash['fee_fields']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  FieldsUpdateProfileRequest.new(global_fields: global_fields,
                                 account_fields: ,
                                 fee_fields: fee_fields,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/sticky_io_restful_api_v2025731/models/fields_update_profile_request.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['global_fields'] = 'global_fields'
  @_hash['account_fields'] = 'account_fields'
  @_hash['fee_fields'] = 'fee_fields'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/sticky_io_restful_api_v2025731/models/fields_update_profile_request.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/fields_update_profile_request.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



86
87
88
89
90
91
# File 'lib/sticky_io_restful_api_v2025731/models/fields_update_profile_request.rb', line 86

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} global_fields: #{@global_fields.inspect}, account_fields:"\
  " #{@account_fields.inspect}, fee_fields: #{@fee_fields.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
83
# File 'lib/sticky_io_restful_api_v2025731/models/fields_update_profile_request.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} global_fields: #{@global_fields}, account_fields: #{@account_fields},"\
  " fee_fields: #{@fee_fields}, additional_properties: #{@additional_properties}>"
end