Class: StickyIoRestfulApiV2025731::GetOfferInvalidIdException
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- StickyIoRestfulApiV2025731::GetOfferInvalidIdException
- Defined in:
- lib/sticky_io_restful_api_v2025731/exceptions/get_offer_invalid_id_exception.rb
Overview
Get Offer Invalid ID class.
Instance Attribute Summary collapse
-
#code ⇒ Integer
TODO: Write general description for this method.
-
#message ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ GetOfferInvalidIdException
constructor
The constructor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ GetOfferInvalidIdException
The constructor.
27 28 29 30 31 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/get_offer_invalid_id_exception.rb', line 27 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#code ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/get_offer_invalid_id_exception.rb', line 18 def code @code end |
#message ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/get_offer_invalid_id_exception.rb', line 22 def @message end |
#status ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/get_offer_invalid_id_exception.rb', line 14 def status @status end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
51 52 53 54 55 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/get_offer_invalid_id_exception.rb', line 51 def inspect class_name = self.class.name.split('::').last "<#{class_name} status: #{@status.inspect}, code: #{@code.inspect}, message:"\ " #{@message.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
45 46 47 48 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/get_offer_invalid_id_exception.rb', line 45 def to_s class_name = self.class.name.split('::').last "<#{class_name} status: #{@status}, code: #{@code}, message: #{@message}>" end |
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
36 37 38 39 40 41 42 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/get_offer_invalid_id_exception.rb', line 36 def unbox(hash) return nil unless hash @status = hash.key?('status') ? hash['status'] : nil @code = hash.key?('code') ? hash['code'] : nil @message = hash.key?('message') ? hash['message'] : nil end |