Class: StickyIoRestfulApiV2025731::GetOfferNotFoundException

Inherits:
APIException
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/exceptions/get_offer_not_found_exception.rb

Overview

Get Offer Not Found class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(reason, response) ⇒ GetOfferNotFoundException

The constructor.

Parameters:

  • reason (String)

    The reason for raising an exception.

  • response (HttpResponse)

    The HttpReponse of the API call.



23
24
25
26
27
# File 'lib/sticky_io_restful_api_v2025731/exceptions/get_offer_not_found_exception.rb', line 23

def initialize(reason, response)
  super(reason, response)
  hash = APIHelper.json_deserialize(@response.raw_body)
  unbox(hash)
end

Instance Attribute Details

#messageString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/exceptions/get_offer_not_found_exception.rb', line 18

def message
  @message
end

#statusString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/exceptions/get_offer_not_found_exception.rb', line 14

def status
  @status
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



46
47
48
49
# File 'lib/sticky_io_restful_api_v2025731/exceptions/get_offer_not_found_exception.rb', line 46

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status.inspect}, message: #{@message.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



40
41
42
43
# File 'lib/sticky_io_restful_api_v2025731/exceptions/get_offer_not_found_exception.rb', line 40

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status}, message: #{@message}>"
end

#unbox(hash) ⇒ Object

Populates this object by extracting properties from a hash. response body.

Parameters:

  • hash (Hash)

    The deserialized response sent by the server in the



32
33
34
35
36
37
# File 'lib/sticky_io_restful_api_v2025731/exceptions/get_offer_not_found_exception.rb', line 32

def unbox(hash)
  return nil unless hash

  @status = hash.key?('status') ? hash['status'] : nil
  @message = hash.key?('message') ? hash['message'] : nil
end