Class: StickyIoRestfulApiV2025731::GlobalFieldsFields

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/global_fields_fields.rb

Overview

GlobalFieldsFields Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(global_monthly_cap:, customer_service_number:, descriptor:, merchant_id:, additional_properties: nil) ⇒ GlobalFieldsFields

Returns a new instance of GlobalFieldsFields.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/sticky_io_restful_api_v2025731/models/global_fields_fields.rb', line 48

def initialize(global_monthly_cap:, customer_service_number:, descriptor:,
               merchant_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @global_monthly_cap = global_monthly_cap
  @customer_service_number = customer_service_number
  @descriptor = descriptor
  @merchant_id = merchant_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#customer_service_numberInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/global_fields_fields.rb', line 18

def customer_service_number
  @customer_service_number
end

#descriptorString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/global_fields_fields.rb', line 22

def descriptor
  @descriptor
end

#global_monthly_capInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/global_fields_fields.rb', line 14

def global_monthly_cap
  @global_monthly_cap
end

#merchant_idString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/global_fields_fields.rb', line 26

def merchant_id
  @merchant_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/sticky_io_restful_api_v2025731/models/global_fields_fields.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  global_monthly_cap =
    hash.key?('global_monthly_cap') ? hash['global_monthly_cap'] : nil
  customer_service_number =
    hash.key?('customer_service_number') ? hash['customer_service_number'] : nil
  descriptor = hash.key?('descriptor') ? hash['descriptor'] : nil
  merchant_id = hash.key?('merchant_id') ? hash['merchant_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  GlobalFieldsFields.new(global_monthly_cap: global_monthly_cap,
                         customer_service_number: customer_service_number,
                         descriptor: descriptor,
                         merchant_id: merchant_id,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/global_fields_fields.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['global_monthly_cap'] = 'global_monthly_cap'
  @_hash['customer_service_number'] = 'customer_service_number'
  @_hash['descriptor'] = 'descriptor'
  @_hash['merchant_id'] = 'merchant_id'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/sticky_io_restful_api_v2025731/models/global_fields_fields.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/sticky_io_restful_api_v2025731/models/global_fields_fields.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



96
97
98
99
100
101
102
# File 'lib/sticky_io_restful_api_v2025731/models/global_fields_fields.rb', line 96

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} global_monthly_cap: #{@global_monthly_cap.inspect},"\
  " customer_service_number: #{@customer_service_number.inspect}, descriptor:"\
  " #{@descriptor.inspect}, merchant_id: #{@merchant_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



88
89
90
91
92
93
# File 'lib/sticky_io_restful_api_v2025731/models/global_fields_fields.rb', line 88

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} global_monthly_cap: #{@global_monthly_cap}, customer_service_number:"\
  " #{@customer_service_number}, descriptor: #{@descriptor}, merchant_id: #{@merchant_id},"\
  " additional_properties: #{@additional_properties}>"
end