Class: StickyIoRestfulApiV2025731::InvalidSubscripitionIdException
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- StickyIoRestfulApiV2025731::InvalidSubscripitionIdException
- Defined in:
- lib/sticky_io_restful_api_v2025731/exceptions/invalid_subscripition_id_exception.rb
Overview
Invalid Subscripition ID class.
Instance Attribute Summary collapse
-
#message ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ InvalidSubscripitionIdException
constructor
The constructor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ InvalidSubscripitionIdException
The constructor.
23 24 25 26 27 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/invalid_subscripition_id_exception.rb', line 23 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#message ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/invalid_subscripition_id_exception.rb', line 18 def @message end |
#status ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/invalid_subscripition_id_exception.rb', line 14 def status @status end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
46 47 48 49 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/invalid_subscripition_id_exception.rb', line 46 def inspect class_name = self.class.name.split('::').last "<#{class_name} status: #{@status.inspect}, message: #{@message.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
40 41 42 43 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/invalid_subscripition_id_exception.rb', line 40 def to_s class_name = self.class.name.split('::').last "<#{class_name} status: #{@status}, message: #{@message}>" end |
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
32 33 34 35 36 37 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/invalid_subscripition_id_exception.rb', line 32 def unbox(hash) return nil unless hash @status = hash.key?('status') ? hash['status'] : nil @message = hash.key?('message') ? hash['message'] : nil end |