Class: StickyIoRestfulApiV2025731::Limits

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/limits.rb

Overview

Limits Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(total: SKIP, per_customer: SKIP, per_code: SKIP, per_code_per_customer: SKIP, additional_properties: nil) ⇒ Limits

Returns a new instance of Limits.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/sticky_io_restful_api_v2025731/models/limits.rb', line 53

def initialize(total: SKIP, per_customer: SKIP, per_code: SKIP,
               per_code_per_customer: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @total = total unless total == SKIP
  @per_customer = per_customer unless per_customer == SKIP
  @per_code = per_code unless per_code == SKIP
  @per_code_per_customer = per_code_per_customer unless per_code_per_customer == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#per_codeInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/limits.rb', line 22

def per_code
  @per_code
end

#per_code_per_customerInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/limits.rb', line 26

def per_code_per_customer
  @per_code_per_customer
end

#per_customerInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/limits.rb', line 18

def per_customer
  @per_customer
end

#totalInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/limits.rb', line 14

def total
  @total
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/sticky_io_restful_api_v2025731/models/limits.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  total = hash.key?('total') ? hash['total'] : SKIP
  per_customer = hash.key?('per_customer') ? hash['per_customer'] : SKIP
  per_code = hash.key?('per_code') ? hash['per_code'] : SKIP
  per_code_per_customer =
    hash.key?('per_code_per_customer') ? hash['per_code_per_customer'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Limits.new(total: total,
             per_customer: per_customer,
             per_code: per_code,
             per_code_per_customer: per_code_per_customer,
             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/limits.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['total'] = 'total'
  @_hash['per_customer'] = 'per_customer'
  @_hash['per_code'] = 'per_code'
  @_hash['per_code_per_customer'] = 'per_code_per_customer'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/limits.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/sticky_io_restful_api_v2025731/models/limits.rb', line 39

def self.optionals
  %w[
    total
    per_customer
    per_code
    per_code_per_customer
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Limits | Hash)

    value against the validation is performed.



93
94
95
96
97
98
99
# File 'lib/sticky_io_restful_api_v2025731/models/limits.rb', line 93

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



110
111
112
113
114
115
# File 'lib/sticky_io_restful_api_v2025731/models/limits.rb', line 110

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} total: #{@total.inspect}, per_customer: #{@per_customer.inspect}, per_code:"\
  " #{@per_code.inspect}, per_code_per_customer: #{@per_code_per_customer.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



102
103
104
105
106
107
# File 'lib/sticky_io_restful_api_v2025731/models/limits.rb', line 102

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} total: #{@total}, per_customer: #{@per_customer}, per_code: #{@per_code},"\
  " per_code_per_customer: #{@per_code_per_customer}, additional_properties:"\
  " #{@additional_properties}>"
end