Class: StickyIoRestfulApiV2025731::LimitsCreateCouponProfileRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::LimitsCreateCouponProfileRequest
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/limits_create_coupon_profile_request.rb
Overview
LimitsCreateCouponProfileRequest Model.
Instance Attribute Summary collapse
-
#per_code ⇒ Integer
TODO: Write general description for this method.
-
#per_code_per_customer ⇒ Integer
TODO: Write general description for this method.
-
#per_customer ⇒ Integer
TODO: Write general description for this method.
-
#total ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(total:, per_customer:, per_code:, per_code_per_customer:, additional_properties: nil) ⇒ LimitsCreateCouponProfileRequest
constructor
A new instance of LimitsCreateCouponProfileRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(total:, per_customer:, per_code:, per_code_per_customer:, additional_properties: nil) ⇒ LimitsCreateCouponProfileRequest
Returns a new instance of LimitsCreateCouponProfileRequest.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/sticky_io_restful_api_v2025731/models/limits_create_coupon_profile_request.rb', line 48 def initialize(total:, per_customer:, per_code:, per_code_per_customer:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @total = total @per_customer = per_customer @per_code = per_code @per_code_per_customer = per_code_per_customer @additional_properties = additional_properties end |
Instance Attribute Details
#per_code ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/limits_create_coupon_profile_request.rb', line 22 def per_code @per_code end |
#per_code_per_customer ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/limits_create_coupon_profile_request.rb', line 26 def per_code_per_customer @per_code_per_customer end |
#per_customer ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/limits_create_coupon_profile_request.rb', line 18 def per_customer @per_customer end |
#total ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/limits_create_coupon_profile_request.rb', line 14 def total @total end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/sticky_io_restful_api_v2025731/models/limits_create_coupon_profile_request.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. total = hash.key?('total') ? hash['total'] : nil per_customer = hash.key?('per_customer') ? hash['per_customer'] : nil per_code = hash.key?('per_code') ? hash['per_code'] : nil per_code_per_customer = hash.key?('per_code_per_customer') ? hash['per_code_per_customer'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LimitsCreateCouponProfileRequest.new(total: total, per_customer: per_customer, per_code: per_code, per_code_per_customer: per_code_per_customer, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/limits_create_coupon_profile_request.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['total'] = 'total' @_hash['per_customer'] = 'per_customer' @_hash['per_code'] = 'per_code' @_hash['per_code_per_customer'] = 'per_code_per_customer' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/limits_create_coupon_profile_request.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/limits_create_coupon_profile_request.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
95 96 97 98 99 100 |
# File 'lib/sticky_io_restful_api_v2025731/models/limits_create_coupon_profile_request.rb', line 95 def inspect class_name = self.class.name.split('::').last "<#{class_name} total: #{@total.inspect}, per_customer: #{@per_customer.inspect}, per_code:"\ " #{@per_code.inspect}, per_code_per_customer: #{@per_code_per_customer.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 92 |
# File 'lib/sticky_io_restful_api_v2025731/models/limits_create_coupon_profile_request.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} total: #{@total}, per_customer: #{@per_customer}, per_code: #{@per_code},"\ " per_code_per_customer: #{@per_code_per_customer}, additional_properties:"\ " #{@additional_properties}>" end |