Class: StickyIoRestfulApiV2025731::Location
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::Location
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/location.rb
Overview
Location Model.
Instance Attribute Summary collapse
-
#country ⇒ String
TODO: Write general description for this method.
-
#postal_code ⇒ Integer
TODO: Write general description for this method.
-
#state ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(state:, country:, postal_code:, additional_properties: nil) ⇒ Location
constructor
A new instance of Location.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(state:, country:, postal_code:, additional_properties: nil) ⇒ Location
Returns a new instance of Location.
43 44 45 46 47 48 49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/location.rb', line 43 def initialize(state:, country:, postal_code:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @state = state @country = country @postal_code = postal_code @additional_properties = additional_properties end |
Instance Attribute Details
#country ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/location.rb', line 18 def country @country end |
#postal_code ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/location.rb', line 22 def postal_code @postal_code end |
#state ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/location.rb', line 14 def state @state end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/sticky_io_restful_api_v2025731/models/location.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. state = hash.key?('state') ? hash['state'] : nil country = hash.key?('country') ? hash['country'] : nil postal_code = hash.key?('postal_code') ? hash['postal_code'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Location.new(state: state, country: country, postal_code: postal_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/sticky_io_restful_api_v2025731/models/location.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['state'] = 'state' @_hash['country'] = 'country' @_hash['postal_code'] = 'postal_code' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/location.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/location.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/sticky_io_restful_api_v2025731/models/location.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} state: #{@state.inspect}, country: #{@country.inspect}, postal_code:"\ " #{@postal_code.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/sticky_io_restful_api_v2025731/models/location.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} state: #{@state}, country: #{@country}, postal_code: #{@postal_code},"\ " additional_properties: #{@additional_properties}>" end |