Class: StickyIoRestfulApiV2025731::Product

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/product.rb

Overview

Product Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(is_trial_allowed:, id:, name:, is_bundle:, is_custom_bundle:, additional_properties: nil) ⇒ Product

Returns a new instance of Product.



53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/sticky_io_restful_api_v2025731/models/product.rb', line 53

def initialize(is_trial_allowed:, id:, name:, is_bundle:, is_custom_bundle:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @is_trial_allowed = is_trial_allowed
  @id = id
  @name = name
  @is_bundle = is_bundle
  @is_custom_bundle = is_custom_bundle
  @additional_properties = additional_properties
end

Instance Attribute Details

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/product.rb', line 18

def id
  @id
end

#is_bundleInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/product.rb', line 26

def is_bundle
  @is_bundle
end

#is_custom_bundleInteger

TODO: Write general description for this method

Returns:

  • (Integer)


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/product.rb', line 30

def is_custom_bundle
  @is_custom_bundle
end

#is_trial_allowedInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/product.rb', line 14

def is_trial_allowed
  @is_trial_allowed
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/product.rb', line 22

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/sticky_io_restful_api_v2025731/models/product.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  is_trial_allowed =
    hash.key?('is_trial_allowed') ? hash['is_trial_allowed'] : nil
  id = hash.key?('id') ? hash['id'] : nil
  name = hash.key?('name') ? hash['name'] : nil
  is_bundle = hash.key?('is_bundle') ? hash['is_bundle'] : nil
  is_custom_bundle =
    hash.key?('is_custom_bundle') ? hash['is_custom_bundle'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Product.new(is_trial_allowed: is_trial_allowed,
              id: id,
              name: name,
              is_bundle: is_bundle,
              is_custom_bundle: is_custom_bundle,
              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/sticky_io_restful_api_v2025731/models/product.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['is_trial_allowed'] = 'is_trial_allowed'
  @_hash['id'] = 'id'
  @_hash['name'] = 'name'
  @_hash['is_bundle'] = 'is_bundle'
  @_hash['is_custom_bundle'] = 'is_custom_bundle'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/product.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
# File 'lib/sticky_io_restful_api_v2025731/models/product.rb', line 44

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Product | Hash)

    value against the validation is performed.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/sticky_io_restful_api_v2025731/models/product.rb', line 97

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.is_trial_allowed,
                            ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.id,
                              ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.name,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.is_bundle,
                              ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.is_custom_bundle,
                              ->(val) { val.instance_of? Integer })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['is_trial_allowed'],
                          ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['id'],
                            ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['name'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['is_bundle'],
                            ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['is_custom_bundle'],
                            ->(val) { val.instance_of? Integer })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



138
139
140
141
142
143
# File 'lib/sticky_io_restful_api_v2025731/models/product.rb', line 138

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} is_trial_allowed: #{@is_trial_allowed.inspect}, id: #{@id.inspect}, name:"\
  " #{@name.inspect}, is_bundle: #{@is_bundle.inspect}, is_custom_bundle:"\
  " #{@is_custom_bundle.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



130
131
132
133
134
135
# File 'lib/sticky_io_restful_api_v2025731/models/product.rb', line 130

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} is_trial_allowed: #{@is_trial_allowed}, id: #{@id}, name: #{@name},"\
  " is_bundle: #{@is_bundle}, is_custom_bundle: #{@is_custom_bundle}, additional_properties:"\
  " #{@additional_properties}>"
end