Class: StickyIoRestfulApiV2025731::ProductData

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/product_data.rb

Overview

ProductData Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, coupon_id:, product_id:, variant_id:, additional_properties: nil) ⇒ ProductData

Returns a new instance of ProductData.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/sticky_io_restful_api_v2025731/models/product_data.rb', line 48

def initialize(id:, coupon_id:, product_id:, variant_id:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @coupon_id = coupon_id
  @product_id = product_id
  @variant_id = variant_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#coupon_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/product_data.rb', line 18

def coupon_id
  @coupon_id
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/product_data.rb', line 14

def id
  @id
end

#product_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/product_data.rb', line 22

def product_id
  @product_id
end

#variant_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/product_data.rb', line 26

def variant_id
  @variant_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/sticky_io_restful_api_v2025731/models/product_data.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  coupon_id = hash.key?('coupon_id') ? hash['coupon_id'] : nil
  product_id = hash.key?('product_id') ? hash['product_id'] : nil
  variant_id = hash.key?('variant_id') ? hash['variant_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProductData.new(id: id,
                  coupon_id: coupon_id,
                  product_id: product_id,
                  variant_id: variant_id,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/product_data.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['coupon_id'] = 'coupon_id'
  @_hash['product_id'] = 'product_id'
  @_hash['variant_id'] = 'variant_id'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/sticky_io_restful_api_v2025731/models/product_data.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/sticky_io_restful_api_v2025731/models/product_data.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



93
94
95
96
97
98
# File 'lib/sticky_io_restful_api_v2025731/models/product_data.rb', line 93

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, coupon_id: #{@coupon_id.inspect}, product_id:"\
  " #{@product_id.inspect}, variant_id: #{@variant_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



86
87
88
89
90
# File 'lib/sticky_io_restful_api_v2025731/models/product_data.rb', line 86

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, coupon_id: #{@coupon_id}, product_id: #{@product_id},"\
  " variant_id: #{@variant_id}, additional_properties: #{@additional_properties}>"
end