Class: StickyIoRestfulApiV2025731::Provider

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/provider.rb

Overview

Provider Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_id:, id:, malias:, account_name:, currency:, additional_properties: nil) ⇒ Provider

Returns a new instance of Provider.



53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/sticky_io_restful_api_v2025731/models/provider.rb', line 53

def initialize(account_id:, id:, malias:, account_name:, currency:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_id = 
  @id = id
  @malias = malias
  @account_name = 
  @currency = currency
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/provider.rb', line 14

def 
  @account_id
end

#account_nameString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/provider.rb', line 26

def 
  @account_name
end

#currencyCurrency

TODO: Write general description for this method

Returns:



30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/provider.rb', line 30

def currency
  @currency
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/provider.rb', line 18

def id
  @id
end

#maliasString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/provider.rb', line 22

def malias
  @malias
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/sticky_io_restful_api_v2025731/models/provider.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('account_id') ? hash['account_id'] : nil
  id = hash.key?('id') ? hash['id'] : nil
  malias = hash.key?('alias') ? hash['alias'] : nil
   = hash.key?('account_name') ? hash['account_name'] : nil
  currency = Currency.from_hash(hash['currency']) if hash['currency']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Provider.new(account_id: ,
               id: id,
               malias: malias,
               account_name: ,
               currency: currency,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/sticky_io_restful_api_v2025731/models/provider.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_id'] = 'account_id'
  @_hash['id'] = 'id'
  @_hash['malias'] = 'alias'
  @_hash['account_name'] = 'account_name'
  @_hash['currency'] = 'currency'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/provider.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
# File 'lib/sticky_io_restful_api_v2025731/models/provider.rb', line 44

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



102
103
104
105
106
107
# File 'lib/sticky_io_restful_api_v2025731/models/provider.rb', line 102

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_id: #{@account_id.inspect}, id: #{@id.inspect}, malias:"\
  " #{@malias.inspect}, account_name: #{@account_name.inspect}, currency:"\
  " #{@currency.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



94
95
96
97
98
99
# File 'lib/sticky_io_restful_api_v2025731/models/provider.rb', line 94

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_id: #{@account_id}, id: #{@id}, malias: #{@malias}, account_name:"\
  " #{@account_name}, currency: #{@currency}, additional_properties:"\
  " #{@additional_properties}>"
end