Class: StickyIoRestfulApiV2025731::Quantity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/quantity.rb

Overview

Quantity Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id: SKIP, volume_discount_id: SKIP, lower_bound: SKIP, upper_bound: SKIP, discount_type_id: SKIP, amount: SKIP, created_at: SKIP, updated_at: SKIP, additional_properties: nil) ⇒ Quantity

Returns a new instance of Quantity.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/sticky_io_restful_api_v2025731/models/quantity.rb', line 77

def initialize(id: SKIP, volume_discount_id: SKIP, lower_bound: SKIP,
               upper_bound: SKIP, discount_type_id: SKIP, amount: SKIP,
               created_at: SKIP, updated_at: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id unless id == SKIP
  @volume_discount_id = volume_discount_id unless volume_discount_id == SKIP
  @lower_bound = lower_bound unless lower_bound == SKIP
  @upper_bound = upper_bound unless upper_bound == SKIP
  @discount_type_id = discount_type_id unless discount_type_id == SKIP
  @amount = amount unless amount == SKIP
  @created_at = created_at unless created_at == SKIP
  @updated_at = updated_at unless updated_at == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#amountString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/quantity.rb', line 34

def amount
  @amount
end

#created_atString

TODO: Write general description for this method

Returns:

  • (String)


38
39
40
# File 'lib/sticky_io_restful_api_v2025731/models/quantity.rb', line 38

def created_at
  @created_at
end

#discount_type_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/quantity.rb', line 30

def discount_type_id
  @discount_type_id
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/quantity.rb', line 14

def id
  @id
end

#lower_boundInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/quantity.rb', line 22

def lower_bound
  @lower_bound
end

#updated_atString

TODO: Write general description for this method

Returns:

  • (String)


42
43
44
# File 'lib/sticky_io_restful_api_v2025731/models/quantity.rb', line 42

def updated_at
  @updated_at
end

#upper_boundInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/quantity.rb', line 26

def upper_bound
  @upper_bound
end

#volume_discount_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/quantity.rb', line 18

def volume_discount_id
  @volume_discount_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/sticky_io_restful_api_v2025731/models/quantity.rb', line 96

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : SKIP
  volume_discount_id =
    hash.key?('volume_discount_id') ? hash['volume_discount_id'] : SKIP
  lower_bound = hash.key?('lower_bound') ? hash['lower_bound'] : SKIP
  upper_bound = hash.key?('upper_bound') ? hash['upper_bound'] : SKIP
  discount_type_id =
    hash.key?('discount_type_id') ? hash['discount_type_id'] : SKIP
  amount = hash.key?('amount') ? hash['amount'] : SKIP
  created_at = hash.key?('created_at') ? hash['created_at'] : SKIP
  updated_at = hash.key?('updated_at') ? hash['updated_at'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Quantity.new(id: id,
               volume_discount_id: volume_discount_id,
               lower_bound: lower_bound,
               upper_bound: upper_bound,
               discount_type_id: discount_type_id,
               amount: amount,
               created_at: created_at,
               updated_at: updated_at,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/sticky_io_restful_api_v2025731/models/quantity.rb', line 45

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['volume_discount_id'] = 'volume_discount_id'
  @_hash['lower_bound'] = 'lower_bound'
  @_hash['upper_bound'] = 'upper_bound'
  @_hash['discount_type_id'] = 'discount_type_id'
  @_hash['amount'] = 'amount'
  @_hash['created_at'] = 'created_at'
  @_hash['updated_at'] = 'updated_at'
  @_hash
end

.nullablesObject

An array for nullable fields



73
74
75
# File 'lib/sticky_io_restful_api_v2025731/models/quantity.rb', line 73

def self.nullables
  []
end

.optionalsObject

An array for optional fields



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/sticky_io_restful_api_v2025731/models/quantity.rb', line 59

def self.optionals
  %w[
    id
    volume_discount_id
    lower_bound
    upper_bound
    discount_type_id
    amount
    created_at
    updated_at
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Quantity | Hash)

    value against the validation is performed.



132
133
134
135
136
137
138
# File 'lib/sticky_io_restful_api_v2025731/models/quantity.rb', line 132

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



150
151
152
153
154
155
156
157
# File 'lib/sticky_io_restful_api_v2025731/models/quantity.rb', line 150

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, volume_discount_id: #{@volume_discount_id.inspect},"\
  " lower_bound: #{@lower_bound.inspect}, upper_bound: #{@upper_bound.inspect},"\
  " discount_type_id: #{@discount_type_id.inspect}, amount: #{@amount.inspect}, created_at:"\
  " #{@created_at.inspect}, updated_at: #{@updated_at.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



141
142
143
144
145
146
147
# File 'lib/sticky_io_restful_api_v2025731/models/quantity.rb', line 141

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, volume_discount_id: #{@volume_discount_id}, lower_bound:"\
  " #{@lower_bound}, upper_bound: #{@upper_bound}, discount_type_id: #{@discount_type_id},"\
  " amount: #{@amount}, created_at: #{@created_at}, updated_at: #{@updated_at},"\
  " additional_properties: #{@additional_properties}>"
end