Class: StickyIoRestfulApiV2025731::QuantityAddVolumeDiscountRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::QuantityAddVolumeDiscountRequest
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/quantity_add_volume_discount_request.rb
Overview
QuantityAddVolumeDiscountRequest Model.
Instance Attribute Summary collapse
-
#amount ⇒ Integer
TODO: Write general description for this method.
-
#discount_type_id ⇒ Integer
TODO: Write general description for this method.
-
#lower_bound ⇒ Integer
TODO: Write general description for this method.
-
#tier_id ⇒ Integer
TODO: Write general description for this method.
-
#upper_bound ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tier_id:, lower_bound:, upper_bound:, discount_type_id:, amount:, additional_properties: nil) ⇒ QuantityAddVolumeDiscountRequest
constructor
A new instance of QuantityAddVolumeDiscountRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tier_id:, lower_bound:, upper_bound:, discount_type_id:, amount:, additional_properties: nil) ⇒ QuantityAddVolumeDiscountRequest
Returns a new instance of QuantityAddVolumeDiscountRequest.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/sticky_io_restful_api_v2025731/models/quantity_add_volume_discount_request.rb', line 53 def initialize(tier_id:, lower_bound:, upper_bound:, discount_type_id:, amount:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tier_id = tier_id @lower_bound = lower_bound @upper_bound = upper_bound @discount_type_id = discount_type_id @amount = amount @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ Integer
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/quantity_add_volume_discount_request.rb', line 30 def amount @amount end |
#discount_type_id ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/quantity_add_volume_discount_request.rb', line 26 def discount_type_id @discount_type_id end |
#lower_bound ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/quantity_add_volume_discount_request.rb', line 18 def lower_bound @lower_bound end |
#tier_id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/quantity_add_volume_discount_request.rb', line 14 def tier_id @tier_id end |
#upper_bound ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/quantity_add_volume_discount_request.rb', line 22 def upper_bound @upper_bound end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/sticky_io_restful_api_v2025731/models/quantity_add_volume_discount_request.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tier_id = hash.key?('tier_id') ? hash['tier_id'] : nil lower_bound = hash.key?('lower_bound') ? hash['lower_bound'] : nil upper_bound = hash.key?('upper_bound') ? hash['upper_bound'] : nil discount_type_id = hash.key?('discount_type_id') ? hash['discount_type_id'] : nil amount = hash.key?('amount') ? hash['amount'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. QuantityAddVolumeDiscountRequest.new(tier_id: tier_id, lower_bound: lower_bound, upper_bound: upper_bound, discount_type_id: discount_type_id, amount: amount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/quantity_add_volume_discount_request.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['tier_id'] = 'tier_id' @_hash['lower_bound'] = 'lower_bound' @_hash['upper_bound'] = 'upper_bound' @_hash['discount_type_id'] = 'discount_type_id' @_hash['amount'] = 'amount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/quantity_add_volume_discount_request.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/quantity_add_volume_discount_request.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
103 104 105 106 107 108 |
# File 'lib/sticky_io_restful_api_v2025731/models/quantity_add_volume_discount_request.rb', line 103 def inspect class_name = self.class.name.split('::').last "<#{class_name} tier_id: #{@tier_id.inspect}, lower_bound: #{@lower_bound.inspect},"\ " upper_bound: #{@upper_bound.inspect}, discount_type_id: #{@discount_type_id.inspect},"\ " amount: #{@amount.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
95 96 97 98 99 100 |
# File 'lib/sticky_io_restful_api_v2025731/models/quantity_add_volume_discount_request.rb', line 95 def to_s class_name = self.class.name.split('::').last "<#{class_name} tier_id: #{@tier_id}, lower_bound: #{@lower_bound}, upper_bound:"\ " #{@upper_bound}, discount_type_id: #{@discount_type_id}, amount: #{@amount},"\ " additional_properties: #{@additional_properties}>" end |