Class: StickyIoRestfulApiV2025731::RelateToOfferRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/relate_to_offer_request.rb

Overview

RelateToOfferRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(is_default:, additional_properties: nil) ⇒ RelateToOfferRequest

Returns a new instance of RelateToOfferRequest.



33
34
35
36
37
38
39
# File 'lib/sticky_io_restful_api_v2025731/models/relate_to_offer_request.rb', line 33

def initialize(is_default:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @is_default = is_default
  @additional_properties = additional_properties
end

Instance Attribute Details

#is_defaultInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/relate_to_offer_request.rb', line 14

def is_default
  @is_default
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/sticky_io_restful_api_v2025731/models/relate_to_offer_request.rb', line 42

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  is_default = hash.key?('is_default') ? hash['is_default'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RelateToOfferRequest.new(is_default: is_default,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/sticky_io_restful_api_v2025731/models/relate_to_offer_request.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['is_default'] = 'is_default'
  @_hash
end

.nullablesObject

An array for nullable fields



29
30
31
# File 'lib/sticky_io_restful_api_v2025731/models/relate_to_offer_request.rb', line 29

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
# File 'lib/sticky_io_restful_api_v2025731/models/relate_to_offer_request.rb', line 24

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



68
69
70
71
72
# File 'lib/sticky_io_restful_api_v2025731/models/relate_to_offer_request.rb', line 68

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} is_default: #{@is_default.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



61
62
63
64
65
# File 'lib/sticky_io_restful_api_v2025731/models/relate_to_offer_request.rb', line 61

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} is_default: #{@is_default}, additional_properties:"\
  " #{@additional_properties}>"
end