Class: StickyIoRestfulApiV2025731::SetSubscriptionAddressOverrideRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::SetSubscriptionAddressOverrideRequest
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/set_subscription_address_override_request.rb
Overview
SetSubscriptionAddressOverrideRequest Model.
Instance Attribute Summary collapse
-
#city ⇒ String
TODO: Write general description for this method.
-
#country ⇒ String
TODO: Write general description for this method.
-
#state ⇒ String
TODO: Write general description for this method.
-
#street ⇒ String
TODO: Write general description for this method.
-
#zip ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(street:, city:, state:, zip:, country:, additional_properties: nil) ⇒ SetSubscriptionAddressOverrideRequest
constructor
A new instance of SetSubscriptionAddressOverrideRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(street:, city:, state:, zip:, country:, additional_properties: nil) ⇒ SetSubscriptionAddressOverrideRequest
Returns a new instance of SetSubscriptionAddressOverrideRequest.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/sticky_io_restful_api_v2025731/models/set_subscription_address_override_request.rb', line 53 def initialize(street:, city:, state:, zip:, country:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @street = street @city = city @state = state @zip = zip @country = country @additional_properties = additional_properties end |
Instance Attribute Details
#city ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/set_subscription_address_override_request.rb', line 18 def city @city end |
#country ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/set_subscription_address_override_request.rb', line 30 def country @country end |
#state ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/set_subscription_address_override_request.rb', line 22 def state @state end |
#street ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/set_subscription_address_override_request.rb', line 14 def street @street end |
#zip ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/set_subscription_address_override_request.rb', line 26 def zip @zip end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/sticky_io_restful_api_v2025731/models/set_subscription_address_override_request.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. street = hash.key?('street') ? hash['street'] : nil city = hash.key?('city') ? hash['city'] : nil state = hash.key?('state') ? hash['state'] : nil zip = hash.key?('zip') ? hash['zip'] : nil country = hash.key?('country') ? hash['country'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SetSubscriptionAddressOverrideRequest.new(street: street, city: city, state: state, zip: zip, country: country, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/set_subscription_address_override_request.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['street'] = 'street' @_hash['city'] = 'city' @_hash['state'] = 'state' @_hash['zip'] = 'zip' @_hash['country'] = 'country' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/set_subscription_address_override_request.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/set_subscription_address_override_request.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 106 |
# File 'lib/sticky_io_restful_api_v2025731/models/set_subscription_address_override_request.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} street: #{@street.inspect}, city: #{@city.inspect}, state:"\ " #{@state.inspect}, zip: #{@zip.inspect}, country: #{@country.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 |
# File 'lib/sticky_io_restful_api_v2025731/models/set_subscription_address_override_request.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} street: #{@street}, city: #{@city}, state: #{@state}, zip: #{@zip},"\ " country: #{@country}, additional_properties: #{@additional_properties}>" end |