Class: StickyIoRestfulApiV2025731::ShippingProfile

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/shipping_profile.rb

Overview

ShippingProfile Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, name:, amount_trial:, amount_recurring:, type:, created_at:, updated_at:, additional_properties: nil) ⇒ ShippingProfile

Returns a new instance of ShippingProfile.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/sticky_io_restful_api_v2025731/models/shipping_profile.rb', line 63

def initialize(id:, name:, amount_trial:, amount_recurring:, type:,
               created_at:, updated_at:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @name = name
  @amount_trial = amount_trial
  @amount_recurring = amount_recurring
  @type = type
  @created_at = created_at
  @updated_at = updated_at
  @additional_properties = additional_properties
end

Instance Attribute Details

#amount_recurringString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/shipping_profile.rb', line 26

def amount_recurring
  @amount_recurring
end

#amount_trialString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/shipping_profile.rb', line 22

def amount_trial
  @amount_trial
end

#created_atCreatedAt

TODO: Write general description for this method

Returns:



34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/shipping_profile.rb', line 34

def created_at
  @created_at
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/shipping_profile.rb', line 14

def id
  @id
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/shipping_profile.rb', line 18

def name
  @name
end

#typeTypeShippingProfile

TODO: Write general description for this method

Returns:



30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/shipping_profile.rb', line 30

def type
  @type
end

#updated_atObject

TODO: Write general description for this method

Returns:

  • (Object)


38
39
40
# File 'lib/sticky_io_restful_api_v2025731/models/shipping_profile.rb', line 38

def updated_at
  @updated_at
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/sticky_io_restful_api_v2025731/models/shipping_profile.rb', line 79

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  name = hash.key?('name') ? hash['name'] : nil
  amount_trial = hash.key?('amount_trial') ? hash['amount_trial'] : nil
  amount_recurring =
    hash.key?('amount_recurring') ? hash['amount_recurring'] : nil
  type = TypeShippingProfile.from_hash(hash['type']) if hash['type']
  created_at = CreatedAt.from_hash(hash['created_at']) if hash['created_at']
  updated_at = hash.key?('updated_at') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:ShippingProfileUpdatedAt), hash['updated_at']
  ) : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ShippingProfile.new(id: id,
                      name: name,
                      amount_trial: amount_trial,
                      amount_recurring: amount_recurring,
                      type: type,
                      created_at: created_at,
                      updated_at: updated_at,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/shipping_profile.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['name'] = 'name'
  @_hash['amount_trial'] = 'amount_trial'
  @_hash['amount_recurring'] = 'amount_recurring'
  @_hash['type'] = 'type'
  @_hash['created_at'] = 'created_at'
  @_hash['updated_at'] = 'updated_at'
  @_hash
end

.nullablesObject

An array for nullable fields



59
60
61
# File 'lib/sticky_io_restful_api_v2025731/models/shipping_profile.rb', line 59

def self.nullables
  []
end

.optionalsObject

An array for optional fields



54
55
56
# File 'lib/sticky_io_restful_api_v2025731/models/shipping_profile.rb', line 54

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (ShippingProfile | Hash)

    value against the validation is performed.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/sticky_io_restful_api_v2025731/models/shipping_profile.rb', line 114

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.id,
                            ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.name,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.amount_trial,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.amount_recurring,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.type,
                              ->(val) { TypeShippingProfile.validate(val) },
                              is_model_hash: true) and
        APIHelper.valid_type?(value.created_at,
                              ->(val) { CreatedAt.validate(val) },
                              is_model_hash: true) and
        UnionTypeLookUp.get(:ShippingProfileUpdatedAt)
                       .validate(value.updated_at)
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['id'],
                          ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['name'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['amount_trial'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['amount_recurring'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['type'],
                            ->(val) { TypeShippingProfile.validate(val) },
                            is_model_hash: true) and
      APIHelper.valid_type?(value['created_at'],
                            ->(val) { CreatedAt.validate(val) },
                            is_model_hash: true) and
      UnionTypeLookUp.get(:ShippingProfileUpdatedAt)
                     .validate(value['updated_at'])
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



167
168
169
170
171
172
173
# File 'lib/sticky_io_restful_api_v2025731/models/shipping_profile.rb', line 167

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, amount_trial:"\
  " #{@amount_trial.inspect}, amount_recurring: #{@amount_recurring.inspect}, type:"\
  " #{@type.inspect}, created_at: #{@created_at.inspect}, updated_at: #{@updated_at.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



159
160
161
162
163
164
# File 'lib/sticky_io_restful_api_v2025731/models/shipping_profile.rb', line 159

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, name: #{@name}, amount_trial: #{@amount_trial},"\
  " amount_recurring: #{@amount_recurring}, type: #{@type}, created_at: #{@created_at},"\
  " updated_at: #{@updated_at}, additional_properties: #{@additional_properties}>"
end