Class: StickyIoRestfulApiV2025731::StopInvalidRequestException

Inherits:
APIException
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/exceptions/stop_invalid_request_exception.rb

Overview

Stop Invalid Request class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(reason, response) ⇒ StopInvalidRequestException

The constructor.

Parameters:

  • reason (String)

    The reason for raising an exception.

  • response (HttpResponse)

    The HttpReponse of the API call.



27
28
29
30
31
# File 'lib/sticky_io_restful_api_v2025731/exceptions/stop_invalid_request_exception.rb', line 27

def initialize(reason, response)
  super(reason, response)
  hash = APIHelper.json_deserialize(@response.raw_body)
  unbox(hash)
end

Instance Attribute Details

#codeInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/exceptions/stop_invalid_request_exception.rb', line 18

def code
  @code
end

#messageString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/exceptions/stop_invalid_request_exception.rb', line 22

def message
  @message
end

#statusString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/exceptions/stop_invalid_request_exception.rb', line 14

def status
  @status
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



51
52
53
54
55
# File 'lib/sticky_io_restful_api_v2025731/exceptions/stop_invalid_request_exception.rb', line 51

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status.inspect}, code: #{@code.inspect}, message:"\
  " #{@message.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



45
46
47
48
# File 'lib/sticky_io_restful_api_v2025731/exceptions/stop_invalid_request_exception.rb', line 45

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status}, code: #{@code}, message: #{@message}>"
end

#unbox(hash) ⇒ Object

Populates this object by extracting properties from a hash. response body.

Parameters:

  • hash (Hash)

    The deserialized response sent by the server in the



36
37
38
39
40
41
42
# File 'lib/sticky_io_restful_api_v2025731/exceptions/stop_invalid_request_exception.rb', line 36

def unbox(hash)
  return nil unless hash

  @status = hash.key?('status') ? hash['status'] : nil
  @code = hash.key?('code') ? hash['code'] : nil
  @message = hash.key?('message') ? hash['message'] : nil
end