Class: StickyIoRestfulApiV2025731::Term

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/term.rb

Overview

Term Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(cycles:, discount_value:, discount_type:, additional_properties: nil) ⇒ Term

Returns a new instance of Term.



43
44
45
46
47
48
49
50
51
52
# File 'lib/sticky_io_restful_api_v2025731/models/term.rb', line 43

def initialize(cycles:, discount_value:, discount_type:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @cycles = cycles
  @discount_value = discount_value
  @discount_type = discount_type
  @additional_properties = additional_properties
end

Instance Attribute Details

#cyclesInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/term.rb', line 14

def cycles
  @cycles
end

#discount_typeDiscountType

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/term.rb', line 22

def discount_type
  @discount_type
end

#discount_valueString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/term.rb', line 18

def discount_value
  @discount_value
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/sticky_io_restful_api_v2025731/models/term.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  cycles = hash.key?('cycles') ? hash['cycles'] : nil
  discount_value =
    hash.key?('discount_value') ? hash['discount_value'] : nil
  discount_type = DiscountType.from_hash(hash['discount_type']) if hash['discount_type']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Term.new(cycles: cycles,
           discount_value: discount_value,
           discount_type: discount_type,
           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/sticky_io_restful_api_v2025731/models/term.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['cycles'] = 'cycles'
  @_hash['discount_value'] = 'discount_value'
  @_hash['discount_type'] = 'discount_type'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/sticky_io_restful_api_v2025731/models/term.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/term.rb', line 34

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Term | Hash)

    value against the validation is performed.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/sticky_io_restful_api_v2025731/models/term.rb', line 80

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.cycles,
                            ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.discount_value,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.discount_type,
                              ->(val) { DiscountType.validate(val) },
                              is_model_hash: true)
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['cycles'],
                          ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['discount_value'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['discount_type'],
                            ->(val) { DiscountType.validate(val) },
                            is_model_hash: true)
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



114
115
116
117
118
119
# File 'lib/sticky_io_restful_api_v2025731/models/term.rb', line 114

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} cycles: #{@cycles.inspect}, discount_value: #{@discount_value.inspect},"\
  " discount_type: #{@discount_type.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



107
108
109
110
111
# File 'lib/sticky_io_restful_api_v2025731/models/term.rb', line 107

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} cycles: #{@cycles}, discount_value: #{@discount_value}, discount_type:"\
  " #{@discount_type}, additional_properties: #{@additional_properties}>"
end