Class: StickyIoRestfulApiV2025731::Trial

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/trial.rb

Overview

Trial Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(is_custom_duration: SKIP, days: SKIP, is_custom_price: SKIP, price: SKIP, is_delayed_billing: SKIP, delayed_billing: SKIP, additional_properties: nil) ⇒ Trial

Returns a new instance of Trial.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/sticky_io_restful_api_v2025731/models/trial.rb', line 67

def initialize(is_custom_duration: SKIP, days: SKIP, is_custom_price: SKIP,
               price: SKIP, is_delayed_billing: SKIP, delayed_billing: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @is_custom_duration = is_custom_duration unless is_custom_duration == SKIP
  @days = days unless days == SKIP
  @is_custom_price = is_custom_price unless is_custom_price == SKIP
  @price = price unless price == SKIP
  @is_delayed_billing = is_delayed_billing unless is_delayed_billing == SKIP
  @delayed_billing = delayed_billing unless delayed_billing == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#daysInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/trial.rb', line 18

def days
  @days
end

#delayed_billingArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/trial.rb', line 34

def delayed_billing
  @delayed_billing
end

#is_custom_durationInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/trial.rb', line 14

def is_custom_duration
  @is_custom_duration
end

#is_custom_priceInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/trial.rb', line 22

def is_custom_price
  @is_custom_price
end

#is_delayed_billingInteger

TODO: Write general description for this method

Returns:

  • (Integer)


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/trial.rb', line 30

def is_delayed_billing
  @is_delayed_billing
end

#priceString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/trial.rb', line 26

def price
  @price
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/sticky_io_restful_api_v2025731/models/trial.rb', line 83

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  is_custom_duration =
    hash.key?('is_custom_duration') ? hash['is_custom_duration'] : SKIP
  days = hash.key?('days') ? hash['days'] : SKIP
  is_custom_price =
    hash.key?('is_custom_price') ? hash['is_custom_price'] : SKIP
  price = hash.key?('price') ? hash['price'] : SKIP
  is_delayed_billing =
    hash.key?('is_delayed_billing') ? hash['is_delayed_billing'] : SKIP
  delayed_billing =
    hash.key?('delayed_billing') ? hash['delayed_billing'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Trial.new(is_custom_duration: is_custom_duration,
            days: days,
            is_custom_price: is_custom_price,
            price: price,
            is_delayed_billing: is_delayed_billing,
            delayed_billing: delayed_billing,
            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/sticky_io_restful_api_v2025731/models/trial.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['is_custom_duration'] = 'is_custom_duration'
  @_hash['days'] = 'days'
  @_hash['is_custom_price'] = 'is_custom_price'
  @_hash['price'] = 'price'
  @_hash['is_delayed_billing'] = 'is_delayed_billing'
  @_hash['delayed_billing'] = 'delayed_billing'
  @_hash
end

.nullablesObject

An array for nullable fields



61
62
63
64
65
# File 'lib/sticky_io_restful_api_v2025731/models/trial.rb', line 61

def self.nullables
  %w[
    price
  ]
end

.optionalsObject

An array for optional fields



49
50
51
52
53
54
55
56
57
58
# File 'lib/sticky_io_restful_api_v2025731/models/trial.rb', line 49

def self.optionals
  %w[
    is_custom_duration
    days
    is_custom_price
    price
    is_delayed_billing
    delayed_billing
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Trial | Hash)

    value against the validation is performed.



117
118
119
120
121
122
123
# File 'lib/sticky_io_restful_api_v2025731/models/trial.rb', line 117

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



135
136
137
138
139
140
141
# File 'lib/sticky_io_restful_api_v2025731/models/trial.rb', line 135

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} is_custom_duration: #{@is_custom_duration.inspect}, days: #{@days.inspect},"\
  " is_custom_price: #{@is_custom_price.inspect}, price: #{@price.inspect},"\
  " is_delayed_billing: #{@is_delayed_billing.inspect}, delayed_billing:"\
  " #{@delayed_billing.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



126
127
128
129
130
131
132
# File 'lib/sticky_io_restful_api_v2025731/models/trial.rb', line 126

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} is_custom_duration: #{@is_custom_duration}, days: #{@days},"\
  " is_custom_price: #{@is_custom_price}, price: #{@price}, is_delayed_billing:"\
  " #{@is_delayed_billing}, delayed_billing: #{@delayed_billing}, additional_properties:"\
  " #{@additional_properties}>"
end