Class: StickyIoRestfulApiV2025731::TrialData

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/trial_data.rb

Overview

TrialData Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(is_custom_duration:, days:, is_custom_price:, price:, is_delayed_billing:, delayed_billing:, additional_properties: nil) ⇒ TrialData

Returns a new instance of TrialData.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/sticky_io_restful_api_v2025731/models/trial_data.rb', line 58

def initialize(is_custom_duration:, days:, is_custom_price:, price:,
               is_delayed_billing:, delayed_billing:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @is_custom_duration = is_custom_duration
  @days = days
  @is_custom_price = is_custom_price
  @price = price
  @is_delayed_billing = is_delayed_billing
  @delayed_billing = delayed_billing
  @additional_properties = additional_properties
end

Instance Attribute Details

#daysInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/trial_data.rb', line 18

def days
  @days
end

#delayed_billingDelayedBillingTrial

TODO: Write general description for this method

Returns:



34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/trial_data.rb', line 34

def delayed_billing
  @delayed_billing
end

#is_custom_durationInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/trial_data.rb', line 14

def is_custom_duration
  @is_custom_duration
end

#is_custom_priceInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/trial_data.rb', line 22

def is_custom_price
  @is_custom_price
end

#is_delayed_billingInteger

TODO: Write general description for this method

Returns:

  • (Integer)


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/trial_data.rb', line 30

def is_delayed_billing
  @is_delayed_billing
end

#priceString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/trial_data.rb', line 26

def price
  @price
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/sticky_io_restful_api_v2025731/models/trial_data.rb', line 74

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  is_custom_duration =
    hash.key?('is_custom_duration') ? hash['is_custom_duration'] : nil
  days = hash.key?('days') ? hash['days'] : nil
  is_custom_price =
    hash.key?('is_custom_price') ? hash['is_custom_price'] : nil
  price = hash.key?('price') ? hash['price'] : nil
  is_delayed_billing =
    hash.key?('is_delayed_billing') ? hash['is_delayed_billing'] : nil
  delayed_billing = DelayedBillingTrial.from_hash(hash['delayed_billing']) if
    hash['delayed_billing']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TrialData.new(is_custom_duration: is_custom_duration,
                days: days,
                is_custom_price: is_custom_price,
                price: price,
                is_delayed_billing: is_delayed_billing,
                delayed_billing: delayed_billing,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/sticky_io_restful_api_v2025731/models/trial_data.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['is_custom_duration'] = 'is_custom_duration'
  @_hash['days'] = 'days'
  @_hash['is_custom_price'] = 'is_custom_price'
  @_hash['price'] = 'price'
  @_hash['is_delayed_billing'] = 'is_delayed_billing'
  @_hash['delayed_billing'] = 'delayed_billing'
  @_hash
end

.nullablesObject

An array for nullable fields



54
55
56
# File 'lib/sticky_io_restful_api_v2025731/models/trial_data.rb', line 54

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/trial_data.rb', line 49

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



116
117
118
119
120
121
122
# File 'lib/sticky_io_restful_api_v2025731/models/trial_data.rb', line 116

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} is_custom_duration: #{@is_custom_duration.inspect}, days: #{@days.inspect},"\
  " is_custom_price: #{@is_custom_price.inspect}, price: #{@price.inspect},"\
  " is_delayed_billing: #{@is_delayed_billing.inspect}, delayed_billing:"\
  " #{@delayed_billing.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



107
108
109
110
111
112
113
# File 'lib/sticky_io_restful_api_v2025731/models/trial_data.rb', line 107

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} is_custom_duration: #{@is_custom_duration}, days: #{@days},"\
  " is_custom_price: #{@is_custom_price}, price: #{@price}, is_delayed_billing:"\
  " #{@is_delayed_billing}, delayed_billing: #{@delayed_billing}, additional_properties:"\
  " #{@additional_properties}>"
end