Class: StickyIoRestfulApiV2025731::TrialOneOf1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/trial_one_of1.rb

Overview

TrialOneOf1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(is_custom_duration:, days:, is_custom_price:, price:, is_delayed_billing:, delayed_billing:, additional_properties: nil) ⇒ TrialOneOf1

Returns a new instance of TrialOneOf1.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/sticky_io_restful_api_v2025731/models/trial_one_of1.rb', line 60

def initialize(is_custom_duration:, days:, is_custom_price:, price:,
               is_delayed_billing:, delayed_billing:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @is_custom_duration = is_custom_duration
  @days = days
  @is_custom_price = is_custom_price
  @price = price
  @is_delayed_billing = is_delayed_billing
  @delayed_billing = delayed_billing
  @additional_properties = additional_properties
end

Instance Attribute Details

#daysInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/trial_one_of1.rb', line 18

def days
  @days
end

#delayed_billingArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/trial_one_of1.rb', line 34

def delayed_billing
  @delayed_billing
end

#is_custom_durationInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/trial_one_of1.rb', line 14

def is_custom_duration
  @is_custom_duration
end

#is_custom_priceInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/trial_one_of1.rb', line 22

def is_custom_price
  @is_custom_price
end

#is_delayed_billingInteger

TODO: Write general description for this method

Returns:

  • (Integer)


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/trial_one_of1.rb', line 30

def is_delayed_billing
  @is_delayed_billing
end

#priceString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/trial_one_of1.rb', line 26

def price
  @price
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/sticky_io_restful_api_v2025731/models/trial_one_of1.rb', line 76

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  is_custom_duration =
    hash.key?('is_custom_duration') ? hash['is_custom_duration'] : nil
  days = hash.key?('days') ? hash['days'] : nil
  is_custom_price =
    hash.key?('is_custom_price') ? hash['is_custom_price'] : nil
  price = hash.key?('price') ? hash['price'] : nil
  is_delayed_billing =
    hash.key?('is_delayed_billing') ? hash['is_delayed_billing'] : nil
  delayed_billing =
    hash.key?('delayed_billing') ? hash['delayed_billing'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TrialOneOf1.new(is_custom_duration: is_custom_duration,
                  days: days,
                  is_custom_price: is_custom_price,
                  price: price,
                  is_delayed_billing: is_delayed_billing,
                  delayed_billing: delayed_billing,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/sticky_io_restful_api_v2025731/models/trial_one_of1.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['is_custom_duration'] = 'is_custom_duration'
  @_hash['days'] = 'days'
  @_hash['is_custom_price'] = 'is_custom_price'
  @_hash['price'] = 'price'
  @_hash['is_delayed_billing'] = 'is_delayed_billing'
  @_hash['delayed_billing'] = 'delayed_billing'
  @_hash
end

.nullablesObject

An array for nullable fields



54
55
56
57
58
# File 'lib/sticky_io_restful_api_v2025731/models/trial_one_of1.rb', line 54

def self.nullables
  %w[
    price
  ]
end

.optionalsObject

An array for optional fields



49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/trial_one_of1.rb', line 49

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (TrialOneOf1 | Hash)

    value against the validation is performed.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/sticky_io_restful_api_v2025731/models/trial_one_of1.rb', line 110

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.is_custom_duration,
                            ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.days,
                              ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.is_custom_price,
                              ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.price,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.is_delayed_billing,
                              ->(val) { val.instance_of? Integer }) and
        APIHelper.valid_type?(value.delayed_billing,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['is_custom_duration'],
                          ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['days'],
                            ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['is_custom_price'],
                            ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['price'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['is_delayed_billing'],
                            ->(val) { val.instance_of? Integer }) and
      APIHelper.valid_type?(value['delayed_billing'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



156
157
158
159
160
161
162
# File 'lib/sticky_io_restful_api_v2025731/models/trial_one_of1.rb', line 156

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} is_custom_duration: #{@is_custom_duration.inspect}, days: #{@days.inspect},"\
  " is_custom_price: #{@is_custom_price.inspect}, price: #{@price.inspect},"\
  " is_delayed_billing: #{@is_delayed_billing.inspect}, delayed_billing:"\
  " #{@delayed_billing.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



147
148
149
150
151
152
153
# File 'lib/sticky_io_restful_api_v2025731/models/trial_one_of1.rb', line 147

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} is_custom_duration: #{@is_custom_duration}, days: #{@days},"\
  " is_custom_price: #{@is_custom_price}, price: #{@price}, is_delayed_billing:"\
  " #{@is_delayed_billing}, delayed_billing: #{@delayed_billing}, additional_properties:"\
  " #{@additional_properties}>"
end