Class: StickyIoRestfulApiV2025731::UpdateBillingModelInvalidBillingModelException
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- StickyIoRestfulApiV2025731::UpdateBillingModelInvalidBillingModelException
- Defined in:
- lib/sticky_io_restful_api_v2025731/exceptions/update_billing_model_invalid_billing_model_exception.rb
Overview
Update Billing Model Invalid Billing Model class.
Instance Attribute Summary collapse
-
#data ⇒ DataUpdateBillingModelInvalidBillingModel
TODO: Write general description for this method.
-
#message ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ UpdateBillingModelInvalidBillingModelException
constructor
The constructor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ UpdateBillingModelInvalidBillingModelException
The constructor.
27 28 29 30 31 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/update_billing_model_invalid_billing_model_exception.rb', line 27 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#data ⇒ DataUpdateBillingModelInvalidBillingModel
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/update_billing_model_invalid_billing_model_exception.rb', line 22 def data @data end |
#message ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/update_billing_model_invalid_billing_model_exception.rb', line 18 def @message end |
#status ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/update_billing_model_invalid_billing_model_exception.rb', line 14 def status @status end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
51 52 53 54 55 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/update_billing_model_invalid_billing_model_exception.rb', line 51 def inspect class_name = self.class.name.split('::').last "<#{class_name} status: #{@status.inspect}, message: #{@message.inspect}, data:"\ " #{@data.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
45 46 47 48 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/update_billing_model_invalid_billing_model_exception.rb', line 45 def to_s class_name = self.class.name.split('::').last "<#{class_name} status: #{@status}, message: #{@message}, data: #{@data}>" end |
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
36 37 38 39 40 41 42 |
# File 'lib/sticky_io_restful_api_v2025731/exceptions/update_billing_model_invalid_billing_model_exception.rb', line 36 def unbox(hash) return nil unless hash @status = hash.key?('status') ? hash['status'] : nil @message = hash.key?('message') ? hash['message'] : nil @data = DataUpdateBillingModelInvalidBillingModel.from_hash(hash['data']) if hash['data'] end |