Class: StickyIoRestfulApiV2025731::UpdateContactPaymentSourceRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/update_contact_payment_source_request.rb

Overview

UpdateContactPaymentSourceRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(expiry:, is_default:, address_id:, additional_properties: nil) ⇒ UpdateContactPaymentSourceRequest

Returns a new instance of UpdateContactPaymentSourceRequest.



43
44
45
46
47
48
49
50
51
52
# File 'lib/sticky_io_restful_api_v2025731/models/update_contact_payment_source_request.rb', line 43

def initialize(expiry:, is_default:, address_id:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @expiry = expiry
  @is_default = is_default
  @address_id = address_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#address_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/update_contact_payment_source_request.rb', line 22

def address_id
  @address_id
end

#expiryString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/update_contact_payment_source_request.rb', line 14

def expiry
  @expiry
end

#is_defaultInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/update_contact_payment_source_request.rb', line 18

def is_default
  @is_default
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/sticky_io_restful_api_v2025731/models/update_contact_payment_source_request.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  expiry = hash.key?('expiry') ? hash['expiry'] : nil
  is_default = hash.key?('is_default') ? hash['is_default'] : nil
  address_id = hash.key?('address_id') ? hash['address_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UpdateContactPaymentSourceRequest.new(expiry: expiry,
                                        is_default: is_default,
                                        address_id: address_id,
                                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/sticky_io_restful_api_v2025731/models/update_contact_payment_source_request.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['expiry'] = 'expiry'
  @_hash['is_default'] = 'is_default'
  @_hash['address_id'] = 'address_id'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/sticky_io_restful_api_v2025731/models/update_contact_payment_source_request.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/update_contact_payment_source_request.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
89
# File 'lib/sticky_io_restful_api_v2025731/models/update_contact_payment_source_request.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} expiry: #{@expiry.inspect}, is_default: #{@is_default.inspect}, address_id:"\
  " #{@address_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



78
79
80
81
82
# File 'lib/sticky_io_restful_api_v2025731/models/update_contact_payment_source_request.rb', line 78

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} expiry: #{@expiry}, is_default: #{@is_default}, address_id: #{@address_id},"\
  " additional_properties: #{@additional_properties}>"
end