Class: StickyIoRestfulApiV2025731::UpdateCustomFieldRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::UpdateCustomFieldRequest
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/update_custom_field_request.rb
Overview
UpdateCustomFieldRequest Model.
Instance Attribute Summary collapse
-
#name ⇒ String
TODO: Write general description for this method.
-
#options ⇒ Array[String]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name:, options:, additional_properties: nil) ⇒ UpdateCustomFieldRequest
constructor
A new instance of UpdateCustomFieldRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name:, options:, additional_properties: nil) ⇒ UpdateCustomFieldRequest
Returns a new instance of UpdateCustomFieldRequest.
38 39 40 41 42 43 44 45 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_custom_field_request.rb', line 38 def initialize(name:, options:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name @options = @additional_properties = additional_properties end |
Instance Attribute Details
#name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_custom_field_request.rb', line 14 def name @name end |
#options ⇒ Array[String]
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_custom_field_request.rb', line 18 def @options end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_custom_field_request.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil = hash.key?('options') ? hash['options'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UpdateCustomFieldRequest.new(name: name, options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_custom_field_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['options'] = 'options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_custom_field_request.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_custom_field_request.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_custom_field_request.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, options: #{@options.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_custom_field_request.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, options: #{@options}, additional_properties:"\ " #{@additional_properties}>" end |