Class: StickyIoRestfulApiV2025731::UpdateNextRecurringQuantityRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::UpdateNextRecurringQuantityRequest
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/update_next_recurring_quantity_request.rb
Overview
UpdateNextRecurringQuantityRequest Model.
Instance Attribute Summary collapse
-
#next_recurring_quantity ⇒ Integer
TODO: Write general description for this method.
-
#order_id ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(order_id:, next_recurring_quantity:, additional_properties: nil) ⇒ UpdateNextRecurringQuantityRequest
constructor
A new instance of UpdateNextRecurringQuantityRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(order_id:, next_recurring_quantity:, additional_properties: nil) ⇒ UpdateNextRecurringQuantityRequest
Returns a new instance of UpdateNextRecurringQuantityRequest.
38 39 40 41 42 43 44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_next_recurring_quantity_request.rb', line 38 def initialize(order_id:, next_recurring_quantity:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @order_id = order_id @next_recurring_quantity = next_recurring_quantity @additional_properties = additional_properties end |
Instance Attribute Details
#next_recurring_quantity ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_next_recurring_quantity_request.rb', line 18 def next_recurring_quantity @next_recurring_quantity end |
#order_id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_next_recurring_quantity_request.rb', line 14 def order_id @order_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_next_recurring_quantity_request.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. order_id = hash.key?('order_id') ? hash['order_id'] : nil next_recurring_quantity = hash.key?('next_recurring_quantity') ? hash['next_recurring_quantity'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UpdateNextRecurringQuantityRequest.new(order_id: order_id, next_recurring_quantity: next_recurring_quantity, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_next_recurring_quantity_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['order_id'] = 'order_id' @_hash['next_recurring_quantity'] = 'next_recurring_quantity' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_next_recurring_quantity_request.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_next_recurring_quantity_request.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_next_recurring_quantity_request.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} order_id: #{@order_id.inspect}, next_recurring_quantity:"\ " #{@next_recurring_quantity.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_next_recurring_quantity_request.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} order_id: #{@order_id}, next_recurring_quantity:"\ " #{@next_recurring_quantity}, additional_properties: #{@additional_properties}>" end |