Class: StickyIoRestfulApiV2025731::UpdateProductImagesRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::UpdateProductImagesRequest
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/update_product_images_request.rb
Overview
UpdateProductImagesRequest Model.
Instance Attribute Summary collapse
-
#image_ids ⇒ Array[Object]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(image_ids:, additional_properties: nil) ⇒ UpdateProductImagesRequest
constructor
A new instance of UpdateProductImagesRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(image_ids:, additional_properties: nil) ⇒ UpdateProductImagesRequest
Returns a new instance of UpdateProductImagesRequest.
33 34 35 36 37 38 39 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_images_request.rb', line 33 def initialize(image_ids:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @image_ids = image_ids @additional_properties = additional_properties end |
Instance Attribute Details
#image_ids ⇒ Array[Object]
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_images_request.rb', line 14 def image_ids @image_ids end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_images_request.rb', line 42 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. image_ids = hash.key?('image_ids') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:UpdateProductImagesRequestImageIds), hash['image_ids'] ) : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UpdateProductImagesRequest.new(image_ids: image_ids, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_images_request.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['image_ids'] = 'image_ids' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_images_request.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_images_request.rb', line 24 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_images_request.rb', line 64 def self.validate(value) if value.instance_of? self return UnionTypeLookUp.get(:UpdateProductImagesRequestImageIds) .validate(value.image_ids) end return false unless value.instance_of? Hash UnionTypeLookUp.get(:UpdateProductImagesRequestImageIds) .validate(value['image_ids']) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_images_request.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} image_ids: #{@image_ids.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_images_request.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} image_ids: #{@image_ids}, additional_properties:"\ " #{@additional_properties}>" end |