Class: StickyIoRestfulApiV2025731::UpdateSubscriptionRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/update_subscription_request.rb

Overview

UpdateSubscriptionRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(recurring_date:, billing_model_id:, use_new_day:, additional_properties: nil) ⇒ UpdateSubscriptionRequest

Returns a new instance of UpdateSubscriptionRequest.



43
44
45
46
47
48
49
50
51
52
# File 'lib/sticky_io_restful_api_v2025731/models/update_subscription_request.rb', line 43

def initialize(recurring_date:, billing_model_id:, use_new_day:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @recurring_date = recurring_date
  @billing_model_id = billing_model_id
  @use_new_day = use_new_day
  @additional_properties = additional_properties
end

Instance Attribute Details

#billing_model_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/update_subscription_request.rb', line 18

def billing_model_id
  @billing_model_id
end

#recurring_dateString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/update_subscription_request.rb', line 14

def recurring_date
  @recurring_date
end

#use_new_dayTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/update_subscription_request.rb', line 22

def use_new_day
  @use_new_day
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/sticky_io_restful_api_v2025731/models/update_subscription_request.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  recurring_date =
    hash.key?('recurring_date') ? hash['recurring_date'] : nil
  billing_model_id =
    hash.key?('billing_model_id') ? hash['billing_model_id'] : nil
  use_new_day = hash.key?('use_new_day') ? hash['use_new_day'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UpdateSubscriptionRequest.new(recurring_date: recurring_date,
                                billing_model_id: billing_model_id,
                                use_new_day: use_new_day,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/sticky_io_restful_api_v2025731/models/update_subscription_request.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['recurring_date'] = 'recurring_date'
  @_hash['billing_model_id'] = 'billing_model_id'
  @_hash['use_new_day'] = 'use_new_day'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/sticky_io_restful_api_v2025731/models/update_subscription_request.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/update_subscription_request.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



87
88
89
90
91
92
# File 'lib/sticky_io_restful_api_v2025731/models/update_subscription_request.rb', line 87

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} recurring_date: #{@recurring_date.inspect}, billing_model_id:"\
  " #{@billing_model_id.inspect}, use_new_day: #{@use_new_day.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
84
# File 'lib/sticky_io_restful_api_v2025731/models/update_subscription_request.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} recurring_date: #{@recurring_date}, billing_model_id: #{@billing_model_id},"\
  " use_new_day: #{@use_new_day}, additional_properties: #{@additional_properties}>"
end