Class: StickyIoRestfulApiV2025731::UpdateVariantInventoryRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::UpdateVariantInventoryRequest
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/update_variant_inventory_request.rb
Overview
UpdateVariantInventoryRequest Model.
Instance Attribute Summary collapse
-
#description ⇒ String
TODO: Write general description for this method.
-
#initial_quantity ⇒ Integer
TODO: Write general description for this method.
-
#inventory_threshold ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#quantity ⇒ Integer
TODO: Write general description for this method.
-
#reorder_amount ⇒ Integer
TODO: Write general description for this method.
-
#warehouse_id ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name:, description:, initial_quantity:, quantity:, inventory_threshold:, reorder_amount:, warehouse_id:, additional_properties: nil) ⇒ UpdateVariantInventoryRequest
constructor
A new instance of UpdateVariantInventoryRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name:, description:, initial_quantity:, quantity:, inventory_threshold:, reorder_amount:, warehouse_id:, additional_properties: nil) ⇒ UpdateVariantInventoryRequest
Returns a new instance of UpdateVariantInventoryRequest.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_variant_inventory_request.rb', line 63 def initialize(name:, description:, initial_quantity:, quantity:, inventory_threshold:, reorder_amount:, warehouse_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name @description = description @initial_quantity = initial_quantity @quantity = quantity @inventory_threshold = inventory_threshold @reorder_amount = reorder_amount @warehouse_id = warehouse_id @additional_properties = additional_properties end |
Instance Attribute Details
#description ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_variant_inventory_request.rb', line 18 def description @description end |
#initial_quantity ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_variant_inventory_request.rb', line 22 def initial_quantity @initial_quantity end |
#inventory_threshold ⇒ Integer
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_variant_inventory_request.rb', line 30 def inventory_threshold @inventory_threshold end |
#name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_variant_inventory_request.rb', line 14 def name @name end |
#quantity ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_variant_inventory_request.rb', line 26 def quantity @quantity end |
#reorder_amount ⇒ Integer
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_variant_inventory_request.rb', line 34 def reorder_amount @reorder_amount end |
#warehouse_id ⇒ Integer
TODO: Write general description for this method
38 39 40 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_variant_inventory_request.rb', line 38 def warehouse_id @warehouse_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_variant_inventory_request.rb', line 80 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil description = hash.key?('description') ? hash['description'] : nil initial_quantity = hash.key?('initial_quantity') ? hash['initial_quantity'] : nil quantity = hash.key?('quantity') ? hash['quantity'] : nil inventory_threshold = hash.key?('inventory_threshold') ? hash['inventory_threshold'] : nil reorder_amount = hash.key?('reorder_amount') ? hash['reorder_amount'] : nil warehouse_id = hash.key?('warehouse_id') ? hash['warehouse_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UpdateVariantInventoryRequest.new(name: name, description: description, initial_quantity: initial_quantity, quantity: quantity, inventory_threshold: inventory_threshold, reorder_amount: reorder_amount, warehouse_id: warehouse_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_variant_inventory_request.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['description'] = 'description' @_hash['initial_quantity'] = 'initial_quantity' @_hash['quantity'] = 'quantity' @_hash['inventory_threshold'] = 'inventory_threshold' @_hash['reorder_amount'] = 'reorder_amount' @_hash['warehouse_id'] = 'warehouse_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
59 60 61 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_variant_inventory_request.rb', line 59 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_variant_inventory_request.rb', line 54 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
123 124 125 126 127 128 129 130 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_variant_inventory_request.rb', line 123 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, description: #{@description.inspect},"\ " initial_quantity: #{@initial_quantity.inspect}, quantity: #{@quantity.inspect},"\ " inventory_threshold: #{@inventory_threshold.inspect}, reorder_amount:"\ " #{@reorder_amount.inspect}, warehouse_id: #{@warehouse_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
114 115 116 117 118 119 120 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_variant_inventory_request.rb', line 114 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, description: #{@description}, initial_quantity:"\ " #{@initial_quantity}, quantity: #{@quantity}, inventory_threshold:"\ " #{@inventory_threshold}, reorder_amount: #{@reorder_amount}, warehouse_id:"\ " #{@warehouse_id}, additional_properties: #{@additional_properties}>" end |