Class: StickyIoRestfulApiV2025731::UpdatedAt
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::UpdatedAt
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/updated_at.rb
Overview
UpdatedAt Model.
Instance Attribute Summary collapse
-
#date ⇒ String
TODO: Write general description for this method.
-
#timezone ⇒ String
TODO: Write general description for this method.
-
#timezone_type ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(date: SKIP, timezone_type: SKIP, timezone: SKIP, additional_properties: nil) ⇒ UpdatedAt
constructor
A new instance of UpdatedAt.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(date: SKIP, timezone_type: SKIP, timezone: SKIP, additional_properties: nil) ⇒ UpdatedAt
Returns a new instance of UpdatedAt.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/updated_at.rb', line 47 def initialize(date: SKIP, timezone_type: SKIP, timezone: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @date = date unless date == SKIP @timezone_type = timezone_type unless timezone_type == SKIP @timezone = timezone unless timezone == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#date ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/updated_at.rb', line 14 def date @date end |
#timezone ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/updated_at.rb', line 22 def timezone @timezone end |
#timezone_type ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/updated_at.rb', line 18 def timezone_type @timezone_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/sticky_io_restful_api_v2025731/models/updated_at.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. date = hash.key?('date') ? hash['date'] : SKIP timezone_type = hash.key?('timezone_type') ? hash['timezone_type'] : SKIP timezone = hash.key?('timezone') ? hash['timezone'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UpdatedAt.new(date: date, timezone_type: timezone_type, timezone: timezone, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/sticky_io_restful_api_v2025731/models/updated_at.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['date'] = 'date' @_hash['timezone_type'] = 'timezone_type' @_hash['timezone'] = 'timezone' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/sticky_io_restful_api_v2025731/models/updated_at.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/sticky_io_restful_api_v2025731/models/updated_at.rb', line 34 def self.optionals %w[ date timezone_type timezone ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
83 84 85 86 87 88 89 |
# File 'lib/sticky_io_restful_api_v2025731/models/updated_at.rb', line 83 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 |
# File 'lib/sticky_io_restful_api_v2025731/models/updated_at.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} date: #{@date.inspect}, timezone_type: #{@timezone_type.inspect}, timezone:"\ " #{@timezone.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/sticky_io_restful_api_v2025731/models/updated_at.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} date: #{@date}, timezone_type: #{@timezone_type}, timezone: #{@timezone},"\ " additional_properties: #{@additional_properties}>" end |