Class: StickyIoRestfulApiV2025731::UpdatorBillingModel
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::UpdatorBillingModel
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/updator_billing_model.rb
Overview
UpdatorBillingModel Model.
Instance Attribute Summary collapse
-
#call_center_provider_id ⇒ Integer
TODO: Write general description for this method.
-
#department_id ⇒ Integer
TODO: Write general description for this method.
-
#email ⇒ String
TODO: Write general description for this method.
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#is_active ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(department_id:, id:, is_active:, name:, email:, call_center_provider_id:, additional_properties: nil) ⇒ UpdatorBillingModel
constructor
A new instance of UpdatorBillingModel.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(department_id:, id:, is_active:, name:, email:, call_center_provider_id:, additional_properties: nil) ⇒ UpdatorBillingModel
Returns a new instance of UpdatorBillingModel.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator_billing_model.rb', line 58 def initialize(department_id:, id:, is_active:, name:, email:, call_center_provider_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @department_id = department_id @id = id @is_active = is_active @name = name @email = email @call_center_provider_id = call_center_provider_id @additional_properties = additional_properties end |
Instance Attribute Details
#call_center_provider_id ⇒ Integer
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator_billing_model.rb', line 34 def call_center_provider_id @call_center_provider_id end |
#department_id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator_billing_model.rb', line 14 def department_id @department_id end |
#email ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator_billing_model.rb', line 30 def email @email end |
#id ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator_billing_model.rb', line 18 def id @id end |
#is_active ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator_billing_model.rb', line 22 def is_active @is_active end |
#name ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator_billing_model.rb', line 26 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator_billing_model.rb', line 73 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. department_id = hash.key?('department_id') ? hash['department_id'] : nil id = hash.key?('id') ? hash['id'] : nil is_active = hash.key?('is_active') ? hash['is_active'] : nil name = hash.key?('name') ? hash['name'] : nil email = hash.key?('email') ? hash['email'] : nil call_center_provider_id = hash.key?('call_center_provider_id') ? hash['call_center_provider_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UpdatorBillingModel.new(department_id: department_id, id: id, is_active: is_active, name: name, email: email, call_center_provider_id: call_center_provider_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator_billing_model.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['department_id'] = 'department_id' @_hash['id'] = 'id' @_hash['is_active'] = 'is_active' @_hash['name'] = 'name' @_hash['email'] = 'email' @_hash['call_center_provider_id'] = 'call_center_provider_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator_billing_model.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator_billing_model.rb', line 49 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator_billing_model.rb', line 104 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.department_id, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.id, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.is_active, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.name, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.email, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.call_center_provider_id, ->(val) { val.instance_of? Integer }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['department_id'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['id'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['is_active'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['name'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['email'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['call_center_provider_id'], ->(val) { val.instance_of? Integer }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
149 150 151 152 153 154 155 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator_billing_model.rb', line 149 def inspect class_name = self.class.name.split('::').last "<#{class_name} department_id: #{@department_id.inspect}, id: #{@id.inspect}, is_active:"\ " #{@is_active.inspect}, name: #{@name.inspect}, email: #{@email.inspect},"\ " call_center_provider_id: #{@call_center_provider_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
141 142 143 144 145 146 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator_billing_model.rb', line 141 def to_s class_name = self.class.name.split('::').last "<#{class_name} department_id: #{@department_id}, id: #{@id}, is_active: #{@is_active},"\ " name: #{@name}, email: #{@email}, call_center_provider_id: #{@call_center_provider_id},"\ " additional_properties: #{@additional_properties}>" end |