Class: StickyIoRestfulApiV2025731::UpdatorData1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/updator_data1.rb

Overview

UpdatorData1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(department_id:, timezone:, id:, is_active:, name:, email:, call_center_provider_id:, additional_properties: nil) ⇒ UpdatorData1

Returns a new instance of UpdatorData1.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/sticky_io_restful_api_v2025731/models/updator_data1.rb', line 63

def initialize(department_id:, timezone:, id:, is_active:, name:, email:,
               call_center_provider_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @department_id = department_id
  @timezone = timezone
  @id = id
  @is_active = is_active
  @name = name
  @email = email
  @call_center_provider_id = call_center_provider_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#call_center_provider_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


38
39
40
# File 'lib/sticky_io_restful_api_v2025731/models/updator_data1.rb', line 38

def call_center_provider_id
  @call_center_provider_id
end

#department_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/updator_data1.rb', line 14

def department_id
  @department_id
end

#emailString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/sticky_io_restful_api_v2025731/models/updator_data1.rb', line 34

def email
  @email
end

#idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/updator_data1.rb', line 22

def id
  @id
end

#is_activeInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/updator_data1.rb', line 26

def is_active
  @is_active
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/updator_data1.rb', line 30

def name
  @name
end

#timezoneString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/updator_data1.rb', line 18

def timezone
  @timezone
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/sticky_io_restful_api_v2025731/models/updator_data1.rb', line 79

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  department_id = hash.key?('department_id') ? hash['department_id'] : nil
  timezone = hash.key?('timezone') ? hash['timezone'] : nil
  id = hash.key?('id') ? hash['id'] : nil
  is_active = hash.key?('is_active') ? hash['is_active'] : nil
  name = hash.key?('name') ? hash['name'] : nil
  email = hash.key?('email') ? hash['email'] : nil
  call_center_provider_id =
    hash.key?('call_center_provider_id') ? hash['call_center_provider_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UpdatorData1.new(department_id: department_id,
                   timezone: timezone,
                   id: id,
                   is_active: is_active,
                   name: name,
                   email: email,
                   call_center_provider_id: call_center_provider_id,
                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/updator_data1.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['department_id'] = 'department_id'
  @_hash['timezone'] = 'timezone'
  @_hash['id'] = 'id'
  @_hash['is_active'] = 'is_active'
  @_hash['name'] = 'name'
  @_hash['email'] = 'email'
  @_hash['call_center_provider_id'] = 'call_center_provider_id'
  @_hash
end

.nullablesObject

An array for nullable fields



59
60
61
# File 'lib/sticky_io_restful_api_v2025731/models/updator_data1.rb', line 59

def self.nullables
  []
end

.optionalsObject

An array for optional fields



54
55
56
# File 'lib/sticky_io_restful_api_v2025731/models/updator_data1.rb', line 54

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



119
120
121
122
123
124
125
# File 'lib/sticky_io_restful_api_v2025731/models/updator_data1.rb', line 119

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} department_id: #{@department_id.inspect}, timezone: #{@timezone.inspect},"\
  " id: #{@id.inspect}, is_active: #{@is_active.inspect}, name: #{@name.inspect}, email:"\
  " #{@email.inspect}, call_center_provider_id: #{@call_center_provider_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



111
112
113
114
115
116
# File 'lib/sticky_io_restful_api_v2025731/models/updator_data1.rb', line 111

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} department_id: #{@department_id}, timezone: #{@timezone}, id: #{@id},"\
  " is_active: #{@is_active}, name: #{@name}, email: #{@email}, call_center_provider_id:"\
  " #{@call_center_provider_id}, additional_properties: #{@additional_properties}>"
end