Class: StickyIoRestfulApiV2025731::Variant

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/sticky_io_restful_api_v2025731/models/variant.rb

Overview

Variant Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(price:, quantity:, weight:, sku_num:, attributes:, additional_properties: nil) ⇒ Variant

Returns a new instance of Variant.



53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/sticky_io_restful_api_v2025731/models/variant.rb', line 53

def initialize(price:, quantity:, weight:, sku_num:, attributes:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @price = price
  @quantity = quantity
  @weight = weight
  @sku_num = sku_num
  @attributes = attributes
  @additional_properties = additional_properties
end

Instance Attribute Details

#attributesArray[AttributeVariant]

TODO: Write general description for this method

Returns:



30
31
32
# File 'lib/sticky_io_restful_api_v2025731/models/variant.rb', line 30

def attributes
  @attributes
end

#priceFloat

TODO: Write general description for this method

Returns:

  • (Float)


14
15
16
# File 'lib/sticky_io_restful_api_v2025731/models/variant.rb', line 14

def price
  @price
end

#quantityInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/sticky_io_restful_api_v2025731/models/variant.rb', line 18

def quantity
  @quantity
end

#sku_numString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/sticky_io_restful_api_v2025731/models/variant.rb', line 26

def sku_num
  @sku_num
end

#weightFloat

TODO: Write general description for this method

Returns:

  • (Float)


22
23
24
# File 'lib/sticky_io_restful_api_v2025731/models/variant.rb', line 22

def weight
  @weight
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/sticky_io_restful_api_v2025731/models/variant.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  price = hash.key?('price') ? hash['price'] : nil
  quantity = hash.key?('quantity') ? hash['quantity'] : nil
  weight = hash.key?('weight') ? hash['weight'] : nil
  sku_num = hash.key?('sku_num') ? hash['sku_num'] : nil
  # Parameter is an array, so we need to iterate through it
  attributes = nil
  unless hash['attributes'].nil?
    attributes = []
    hash['attributes'].each do |structure|
      attributes << (AttributeVariant.from_hash(structure) if structure)
    end
  end

  attributes = nil unless hash.key?('attributes')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Variant.new(price: price,
              quantity: quantity,
              weight: weight,
              sku_num: sku_num,
              attributes: attributes,
              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/sticky_io_restful_api_v2025731/models/variant.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['price'] = 'price'
  @_hash['quantity'] = 'quantity'
  @_hash['weight'] = 'weight'
  @_hash['sku_num'] = 'sku_num'
  @_hash['attributes'] = 'attributes'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/sticky_io_restful_api_v2025731/models/variant.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
# File 'lib/sticky_io_restful_api_v2025731/models/variant.rb', line 44

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



111
112
113
114
115
116
# File 'lib/sticky_io_restful_api_v2025731/models/variant.rb', line 111

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} price: #{@price.inspect}, quantity: #{@quantity.inspect}, weight:"\
  " #{@weight.inspect}, sku_num: #{@sku_num.inspect}, attributes: #{@attributes.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



103
104
105
106
107
108
# File 'lib/sticky_io_restful_api_v2025731/models/variant.rb', line 103

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} price: #{@price}, quantity: #{@quantity}, weight: #{@weight}, sku_num:"\
  " #{@sku_num}, attributes: #{@attributes}, additional_properties:"\
  " #{@additional_properties}>"
end