Class: StickyIoRestfulApiV2025731::AccountFields
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::AccountFields
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/account_fields.rb
Overview
AccountFields Model.
Instance Attribute Summary collapse
-
#api_login ⇒ String
TODO: Write general description for this method.
-
#capture_on_shipment ⇒ Integer
TODO: Write general description for this method.
-
#lime_light_3d_verify ⇒ Integer
TODO: Write general description for this method.
-
#signature_key ⇒ String
TODO: Write general description for this method.
-
#test_mode ⇒ Integer
TODO: Write general description for this method.
-
#trans_key ⇒ String
TODO: Write general description for this method.
-
#use_pre_auth_filter ⇒ Integer
TODO: Write general description for this method.
-
#void_pre_auth ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(signature_key:, void_pre_auth:, use_pre_auth_filter:, trans_key:, test_mode:, capture_on_shipment:, api_login:, lime_light_3d_verify:, additional_properties: nil) ⇒ AccountFields
constructor
A new instance of AccountFields.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(signature_key:, void_pre_auth:, use_pre_auth_filter:, trans_key:, test_mode:, capture_on_shipment:, api_login:, lime_light_3d_verify:, additional_properties: nil) ⇒ AccountFields
Returns a new instance of AccountFields.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/sticky_io_restful_api_v2025731/models/account_fields.rb', line 68 def initialize(signature_key:, void_pre_auth:, use_pre_auth_filter:, trans_key:, test_mode:, capture_on_shipment:, api_login:, lime_light_3d_verify:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @signature_key = signature_key @void_pre_auth = void_pre_auth @use_pre_auth_filter = use_pre_auth_filter @trans_key = trans_key @test_mode = test_mode @capture_on_shipment = capture_on_shipment @api_login = api_login @lime_light_3d_verify = lime_light_3d_verify @additional_properties = additional_properties end |
Instance Attribute Details
#api_login ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/sticky_io_restful_api_v2025731/models/account_fields.rb', line 38 def api_login @api_login end |
#capture_on_shipment ⇒ Integer
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/account_fields.rb', line 34 def capture_on_shipment @capture_on_shipment end |
#lime_light_3d_verify ⇒ Integer
TODO: Write general description for this method
42 43 44 |
# File 'lib/sticky_io_restful_api_v2025731/models/account_fields.rb', line 42 def lime_light_3d_verify @lime_light_3d_verify end |
#signature_key ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/account_fields.rb', line 14 def signature_key @signature_key end |
#test_mode ⇒ Integer
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/account_fields.rb', line 30 def test_mode @test_mode end |
#trans_key ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/account_fields.rb', line 26 def trans_key @trans_key end |
#use_pre_auth_filter ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/account_fields.rb', line 22 def use_pre_auth_filter @use_pre_auth_filter end |
#void_pre_auth ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/account_fields.rb', line 18 def void_pre_auth @void_pre_auth end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/sticky_io_restful_api_v2025731/models/account_fields.rb', line 86 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. signature_key = hash.key?('signature_key') ? hash['signature_key'] : nil void_pre_auth = hash.key?('void_pre_auth') ? hash['void_pre_auth'] : nil use_pre_auth_filter = hash.key?('use_pre_auth_filter') ? hash['use_pre_auth_filter'] : nil trans_key = hash.key?('trans_key') ? hash['trans_key'] : nil test_mode = hash.key?('test_mode') ? hash['test_mode'] : nil capture_on_shipment = hash.key?('capture_on_shipment') ? hash['capture_on_shipment'] : nil api_login = hash.key?('api_login') ? hash['api_login'] : nil lime_light_3d_verify = hash.key?('lime_light_3d_verify') ? hash['lime_light_3d_verify'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AccountFields.new(signature_key: signature_key, void_pre_auth: void_pre_auth, use_pre_auth_filter: use_pre_auth_filter, trans_key: trans_key, test_mode: test_mode, capture_on_shipment: capture_on_shipment, api_login: api_login, lime_light_3d_verify: lime_light_3d_verify, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/account_fields.rb', line 45 def self.names @_hash = {} if @_hash.nil? @_hash['signature_key'] = 'signature_key' @_hash['void_pre_auth'] = 'void_pre_auth' @_hash['use_pre_auth_filter'] = 'use_pre_auth_filter' @_hash['trans_key'] = 'trans_key' @_hash['test_mode'] = 'test_mode' @_hash['capture_on_shipment'] = 'capture_on_shipment' @_hash['api_login'] = 'api_login' @_hash['lime_light_3d_verify'] = 'lime_light_3d_verify' @_hash end |
.nullables ⇒ Object
An array for nullable fields
64 65 66 |
# File 'lib/sticky_io_restful_api_v2025731/models/account_fields.rb', line 64 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
59 60 61 |
# File 'lib/sticky_io_restful_api_v2025731/models/account_fields.rb', line 59 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
132 133 134 135 136 137 138 139 |
# File 'lib/sticky_io_restful_api_v2025731/models/account_fields.rb', line 132 def inspect class_name = self.class.name.split('::').last "<#{class_name} signature_key: #{@signature_key.inspect}, void_pre_auth:"\ " #{@void_pre_auth.inspect}, use_pre_auth_filter: #{@use_pre_auth_filter.inspect},"\ " trans_key: #{@trans_key.inspect}, test_mode: #{@test_mode.inspect}, capture_on_shipment:"\ " #{@capture_on_shipment.inspect}, api_login: #{@api_login.inspect}, lime_light_3d_verify:"\ " #{@lime_light_3d_verify.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
122 123 124 125 126 127 128 129 |
# File 'lib/sticky_io_restful_api_v2025731/models/account_fields.rb', line 122 def to_s class_name = self.class.name.split('::').last "<#{class_name} signature_key: #{@signature_key}, void_pre_auth: #{@void_pre_auth},"\ " use_pre_auth_filter: #{@use_pre_auth_filter}, trans_key: #{@trans_key}, test_mode:"\ " #{@test_mode}, capture_on_shipment: #{@capture_on_shipment}, api_login: #{@api_login},"\ " lime_light_3d_verify: #{@lime_light_3d_verify}, additional_properties:"\ " #{@additional_properties}>" end |