Class: StickyIoRestfulApiV2025731::Author
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::Author
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/author.rb
Overview
Author Model.
Instance Attribute Summary collapse
-
#email ⇒ String
TODO: Write general description for this method.
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#is_active ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id:, is_active:, name:, email:, additional_properties: nil) ⇒ Author
constructor
A new instance of Author.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, is_active:, name:, email:, additional_properties: nil) ⇒ Author
Returns a new instance of Author.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/sticky_io_restful_api_v2025731/models/author.rb', line 48 def initialize(id:, is_active:, name:, email:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @is_active = is_active @name = name @email = email @additional_properties = additional_properties end |
Instance Attribute Details
#email ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/author.rb', line 26 def email @email end |
#id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/author.rb', line 14 def id @id end |
#is_active ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/author.rb', line 18 def is_active @is_active end |
#name ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/author.rb', line 22 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/sticky_io_restful_api_v2025731/models/author.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil is_active = hash.key?('is_active') ? hash['is_active'] : nil name = hash.key?('name') ? hash['name'] : nil email = hash.key?('email') ? hash['email'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Author.new(id: id, is_active: is_active, name: name, email: email, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/author.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['is_active'] = 'is_active' @_hash['name'] = 'name' @_hash['email'] = 'email' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/author.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/author.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
92 93 94 95 96 97 |
# File 'lib/sticky_io_restful_api_v2025731/models/author.rb', line 92 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, is_active: #{@is_active.inspect}, name:"\ " #{@name.inspect}, email: #{@email.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
85 86 87 88 89 |
# File 'lib/sticky_io_restful_api_v2025731/models/author.rb', line 85 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, is_active: #{@is_active}, name: #{@name}, email: #{@email},"\ " additional_properties: #{@additional_properties}>" end |