Class: StickyIoRestfulApiV2025731::BillingModelData3
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::BillingModelData3
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb
Overview
BillingModelData3 Model.
Instance Attribute Summary collapse
-
#bill_by_days ⇒ Integer
TODO: Write general description for this method.
-
#bill_by_type_id ⇒ Integer
TODO: Write general description for this method.
-
#buffer_days ⇒ Integer
TODO: Write general description for this method.
-
#created_at ⇒ CreatedAt
TODO: Write general description for this method.
-
#created_by ⇒ Integer
TODO: Write general description for this method.
-
#expire_cycles ⇒ Integer
TODO: Write general description for this method.
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#interval_day ⇒ Integer
TODO: Write general description for this method.
-
#interval_week ⇒ Integer
TODO: Write general description for this method.
-
#is_archived ⇒ Integer
TODO: Write general description for this method.
-
#is_preserve_quantity ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#type_id ⇒ Integer
TODO: Write general description for this method.
-
#updated_at ⇒ String
TODO: Write general description for this method.
-
#updated_by ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(id:, name:, expire_cycles:, bill_by_type_id:, bill_by_days:, interval_day:, interval_week:, type_id:, updated_by:, created_by:, buffer_days:, created_at:, updated_at:, is_archived:, is_preserve_quantity:, additional_properties: nil) ⇒ BillingModelData3
constructor
A new instance of BillingModelData3.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, name:, expire_cycles:, bill_by_type_id:, bill_by_days:, interval_day:, interval_week:, type_id:, updated_by:, created_by:, buffer_days:, created_at:, updated_at:, is_archived:, is_preserve_quantity:, additional_properties: nil) ⇒ BillingModelData3
Returns a new instance of BillingModelData3.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 105 def initialize(id:, name:, expire_cycles:, bill_by_type_id:, bill_by_days:, interval_day:, interval_week:, type_id:, updated_by:, created_by:, buffer_days:, created_at:, updated_at:, is_archived:, is_preserve_quantity:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @name = name @expire_cycles = expire_cycles @bill_by_type_id = bill_by_type_id @bill_by_days = bill_by_days @interval_day = interval_day @interval_week = interval_week @type_id = type_id @updated_by = updated_by @created_by = created_by @buffer_days = buffer_days @created_at = created_at @updated_at = updated_at @is_archived = is_archived @is_preserve_quantity = is_preserve_quantity @additional_properties = additional_properties end |
Instance Attribute Details
#bill_by_days ⇒ Integer
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 30 def bill_by_days @bill_by_days end |
#bill_by_type_id ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 26 def bill_by_type_id @bill_by_type_id end |
#buffer_days ⇒ Integer
TODO: Write general description for this method
54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 54 def buffer_days @buffer_days end |
#created_at ⇒ CreatedAt
TODO: Write general description for this method
58 59 60 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 58 def created_at @created_at end |
#created_by ⇒ Integer
TODO: Write general description for this method
50 51 52 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 50 def created_by @created_by end |
#expire_cycles ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 22 def expire_cycles @expire_cycles end |
#id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 14 def id @id end |
#interval_day ⇒ Integer
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 34 def interval_day @interval_day end |
#interval_week ⇒ Integer
TODO: Write general description for this method
38 39 40 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 38 def interval_week @interval_week end |
#is_archived ⇒ Integer
TODO: Write general description for this method
66 67 68 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 66 def is_archived @is_archived end |
#is_preserve_quantity ⇒ Integer
TODO: Write general description for this method
70 71 72 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 70 def is_preserve_quantity @is_preserve_quantity end |
#name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 18 def name @name end |
#type_id ⇒ Integer
TODO: Write general description for this method
42 43 44 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 42 def type_id @type_id end |
#updated_at ⇒ String
TODO: Write general description for this method
62 63 64 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 62 def updated_at @updated_at end |
#updated_by ⇒ Integer
TODO: Write general description for this method
46 47 48 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 46 def updated_by @updated_by end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 132 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil name = hash.key?('name') ? hash['name'] : nil expire_cycles = hash.key?('expire_cycles') ? hash['expire_cycles'] : nil bill_by_type_id = hash.key?('bill_by_type_id') ? hash['bill_by_type_id'] : nil bill_by_days = hash.key?('bill_by_days') ? hash['bill_by_days'] : nil interval_day = hash.key?('interval_day') ? hash['interval_day'] : nil interval_week = hash.key?('interval_week') ? hash['interval_week'] : nil type_id = hash.key?('type_id') ? hash['type_id'] : nil updated_by = hash.key?('updated_by') ? hash['updated_by'] : nil created_by = hash.key?('created_by') ? hash['created_by'] : nil buffer_days = hash.key?('buffer_days') ? hash['buffer_days'] : nil created_at = CreatedAt.from_hash(hash['created_at']) if hash['created_at'] updated_at = hash.key?('updated_at') ? hash['updated_at'] : nil is_archived = hash.key?('is_archived') ? hash['is_archived'] : nil is_preserve_quantity = hash.key?('is_preserve_quantity') ? hash['is_preserve_quantity'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BillingModelData3.new(id: id, name: name, expire_cycles: expire_cycles, bill_by_type_id: bill_by_type_id, bill_by_days: bill_by_days, interval_day: interval_day, interval_week: interval_week, type_id: type_id, updated_by: updated_by, created_by: created_by, buffer_days: buffer_days, created_at: created_at, updated_at: updated_at, is_archived: is_archived, is_preserve_quantity: is_preserve_quantity, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 73 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['name'] = 'name' @_hash['expire_cycles'] = 'expire_cycles' @_hash['bill_by_type_id'] = 'bill_by_type_id' @_hash['bill_by_days'] = 'bill_by_days' @_hash['interval_day'] = 'interval_day' @_hash['interval_week'] = 'interval_week' @_hash['type_id'] = 'type_id' @_hash['updated_by'] = 'updated_by' @_hash['created_by'] = 'created_by' @_hash['buffer_days'] = 'buffer_days' @_hash['created_at'] = 'created_at' @_hash['updated_at'] = 'updated_at' @_hash['is_archived'] = 'is_archived' @_hash['is_preserve_quantity'] = 'is_preserve_quantity' @_hash end |
.nullables ⇒ Object
An array for nullable fields
99 100 101 102 103 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 99 def self.nullables %w[ updated_at ] end |
.optionals ⇒ Object
An array for optional fields
94 95 96 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 94 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 182 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.id, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.name, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.expire_cycles, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.bill_by_type_id, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.bill_by_days, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.interval_day, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.interval_week, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.type_id, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.updated_by, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.created_by, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.buffer_days, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.created_at, ->(val) { CreatedAt.validate(val) }, is_model_hash: true) and APIHelper.valid_type?(value.updated_at, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.is_archived, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.is_preserve_quantity, ->(val) { val.instance_of? Integer }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['id'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['name'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['expire_cycles'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['bill_by_type_id'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['bill_by_days'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['interval_day'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['interval_week'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['type_id'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['updated_by'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['created_by'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['buffer_days'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['created_at'], ->(val) { CreatedAt.validate(val) }, is_model_hash: true) and APIHelper.valid_type?(value['updated_at'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['is_archived'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['is_preserve_quantity'], ->(val) { val.instance_of? Integer }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 269 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, expire_cycles:"\ " #{@expire_cycles.inspect}, bill_by_type_id: #{@bill_by_type_id.inspect}, bill_by_days:"\ " #{@bill_by_days.inspect}, interval_day: #{@interval_day.inspect}, interval_week:"\ " #{@interval_week.inspect}, type_id: #{@type_id.inspect}, updated_by:"\ " #{@updated_by.inspect}, created_by: #{@created_by.inspect}, buffer_days:"\ " #{@buffer_days.inspect}, created_at: #{@created_at.inspect}, updated_at:"\ " #{@updated_at.inspect}, is_archived: #{@is_archived.inspect}, is_preserve_quantity:"\ " #{@is_preserve_quantity.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
257 258 259 260 261 262 263 264 265 266 |
# File 'lib/sticky_io_restful_api_v2025731/models/billing_model_data3.rb', line 257 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, name: #{@name}, expire_cycles: #{@expire_cycles},"\ " bill_by_type_id: #{@bill_by_type_id}, bill_by_days: #{@bill_by_days}, interval_day:"\ " #{@interval_day}, interval_week: #{@interval_week}, type_id: #{@type_id}, updated_by:"\ " #{@updated_by}, created_by: #{@created_by}, buffer_days: #{@buffer_days}, created_at:"\ " #{@created_at}, updated_at: #{@updated_at}, is_archived: #{@is_archived},"\ " is_preserve_quantity: #{@is_preserve_quantity}, additional_properties:"\ " #{@additional_properties}>" end |