Class: StickyIoRestfulApiV2025731::CalculateOrderTotalRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::CalculateOrderTotalRequest
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/calculate_order_total_request.rb
Overview
CalculateOrderTotalRequest Model.
Instance Attribute Summary collapse
-
#campaign_id ⇒ Integer
TODO: Write general description for this method.
-
#location ⇒ Location
TODO: Write general description for this method.
-
#offers ⇒ Array[OfferCalculateOrderTotalRequest]
TODO: Write general description for this method.
-
#promo ⇒ Promo
TODO: Write general description for this method.
-
#shipping_id ⇒ Integer
TODO: Write general description for this method.
-
#use_tax_provider ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(campaign_id:, shipping_id:, use_tax_provider:, offers:, location:, promo:, additional_properties: nil) ⇒ CalculateOrderTotalRequest
constructor
A new instance of CalculateOrderTotalRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(campaign_id:, shipping_id:, use_tax_provider:, offers:, location:, promo:, additional_properties: nil) ⇒ CalculateOrderTotalRequest
Returns a new instance of CalculateOrderTotalRequest.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/sticky_io_restful_api_v2025731/models/calculate_order_total_request.rb', line 58 def initialize(campaign_id:, shipping_id:, use_tax_provider:, offers:, location:, promo:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @campaign_id = campaign_id @shipping_id = shipping_id @use_tax_provider = use_tax_provider @offers = offers @location = location @promo = promo @additional_properties = additional_properties end |
Instance Attribute Details
#campaign_id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/calculate_order_total_request.rb', line 14 def campaign_id @campaign_id end |
#location ⇒ Location
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/calculate_order_total_request.rb', line 30 def location @location end |
#offers ⇒ Array[OfferCalculateOrderTotalRequest]
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/calculate_order_total_request.rb', line 26 def offers @offers end |
#promo ⇒ Promo
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/calculate_order_total_request.rb', line 34 def promo @promo end |
#shipping_id ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/calculate_order_total_request.rb', line 18 def shipping_id @shipping_id end |
#use_tax_provider ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/calculate_order_total_request.rb', line 22 def use_tax_provider @use_tax_provider end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/sticky_io_restful_api_v2025731/models/calculate_order_total_request.rb', line 73 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. campaign_id = hash.key?('campaign_id') ? hash['campaign_id'] : nil shipping_id = hash.key?('shipping_id') ? hash['shipping_id'] : nil use_tax_provider = hash.key?('use_tax_provider') ? hash['use_tax_provider'] : nil # Parameter is an array, so we need to iterate through it offers = nil unless hash['offers'].nil? offers = [] hash['offers'].each do |structure| offers << (OfferCalculateOrderTotalRequest.from_hash(structure) if structure) end end offers = nil unless hash.key?('offers') location = Location.from_hash(hash['location']) if hash['location'] promo = Promo.from_hash(hash['promo']) if hash['promo'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CalculateOrderTotalRequest.new(campaign_id: campaign_id, shipping_id: shipping_id, use_tax_provider: use_tax_provider, offers: offers, location: location, promo: promo, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/calculate_order_total_request.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['campaign_id'] = 'campaign_id' @_hash['shipping_id'] = 'shipping_id' @_hash['use_tax_provider'] = 'use_tax_provider' @_hash['offers'] = 'offers' @_hash['location'] = 'location' @_hash['promo'] = 'promo' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/calculate_order_total_request.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/calculate_order_total_request.rb', line 49 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
120 121 122 123 124 125 126 |
# File 'lib/sticky_io_restful_api_v2025731/models/calculate_order_total_request.rb', line 120 def inspect class_name = self.class.name.split('::').last "<#{class_name} campaign_id: #{@campaign_id.inspect}, shipping_id: #{@shipping_id.inspect},"\ " use_tax_provider: #{@use_tax_provider.inspect}, offers: #{@offers.inspect}, location:"\ " #{@location.inspect}, promo: #{@promo.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
112 113 114 115 116 117 |
# File 'lib/sticky_io_restful_api_v2025731/models/calculate_order_total_request.rb', line 112 def to_s class_name = self.class.name.split('::').last "<#{class_name} campaign_id: #{@campaign_id}, shipping_id: #{@shipping_id},"\ " use_tax_provider: #{@use_tax_provider}, offers: #{@offers}, location: #{@location}, promo:"\ " #{@promo}, additional_properties: #{@additional_properties}>" end |