Class: StickyIoRestfulApiV2025731::CreateCustomFieldRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::CreateCustomFieldRequest
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/create_custom_field_request.rb
Overview
CreateCustomFieldRequest Model.
Instance Attribute Summary collapse
-
#field_type_id ⇒ Integer
TODO: Write general description for this method.
-
#is_multi ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#options ⇒ Array[String]
TODO: Write general description for this method.
-
#token_key ⇒ String
TODO: Write general description for this method.
-
#type_id ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name:, field_type_id:, type_id:, is_multi:, options:, token_key:, additional_properties: nil) ⇒ CreateCustomFieldRequest
constructor
A new instance of CreateCustomFieldRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name:, field_type_id:, type_id:, is_multi:, options:, token_key:, additional_properties: nil) ⇒ CreateCustomFieldRequest
Returns a new instance of CreateCustomFieldRequest.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_custom_field_request.rb', line 58 def initialize(name:, field_type_id:, type_id:, is_multi:, options:, token_key:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name @field_type_id = field_type_id @type_id = type_id @is_multi = is_multi @options = @token_key = token_key @additional_properties = additional_properties end |
Instance Attribute Details
#field_type_id ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_custom_field_request.rb', line 18 def field_type_id @field_type_id end |
#is_multi ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_custom_field_request.rb', line 26 def is_multi @is_multi end |
#name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_custom_field_request.rb', line 14 def name @name end |
#options ⇒ Array[String]
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_custom_field_request.rb', line 30 def @options end |
#token_key ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_custom_field_request.rb', line 34 def token_key @token_key end |
#type_id ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_custom_field_request.rb', line 22 def type_id @type_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_custom_field_request.rb', line 73 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil field_type_id = hash.key?('field_type_id') ? hash['field_type_id'] : nil type_id = hash.key?('type_id') ? hash['type_id'] : nil is_multi = hash.key?('is_multi') ? hash['is_multi'] : nil = hash.key?('options') ? hash['options'] : nil token_key = hash.key?('token_key') ? hash['token_key'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreateCustomFieldRequest.new(name: name, field_type_id: field_type_id, type_id: type_id, is_multi: is_multi, options: , token_key: token_key, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_custom_field_request.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['field_type_id'] = 'field_type_id' @_hash['type_id'] = 'type_id' @_hash['is_multi'] = 'is_multi' @_hash['options'] = 'options' @_hash['token_key'] = 'token_key' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_custom_field_request.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_custom_field_request.rb', line 49 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
110 111 112 113 114 115 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_custom_field_request.rb', line 110 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, field_type_id: #{@field_type_id.inspect}, type_id:"\ " #{@type_id.inspect}, is_multi: #{@is_multi.inspect}, options: #{@options.inspect},"\ " token_key: #{@token_key.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
102 103 104 105 106 107 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_custom_field_request.rb', line 102 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, field_type_id: #{@field_type_id}, type_id: #{@type_id},"\ " is_multi: #{@is_multi}, options: #{@options}, token_key: #{@token_key},"\ " additional_properties: #{@additional_properties}>" end |