Class: StickyIoRestfulApiV2025731::CreateTrialWorkflowRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::CreateTrialWorkflowRequest
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/create_trial_workflow_request.rb
Overview
CreateTrialWorkflowRequest Model.
Instance Attribute Summary collapse
-
#is_active ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#units ⇒ Array[Unit]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name:, is_active:, units:, additional_properties: nil) ⇒ CreateTrialWorkflowRequest
constructor
A new instance of CreateTrialWorkflowRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name:, is_active:, units:, additional_properties: nil) ⇒ CreateTrialWorkflowRequest
Returns a new instance of CreateTrialWorkflowRequest.
43 44 45 46 47 48 49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_trial_workflow_request.rb', line 43 def initialize(name:, is_active:, units:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name @is_active = is_active @units = units @additional_properties = additional_properties end |
Instance Attribute Details
#is_active ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_trial_workflow_request.rb', line 18 def is_active @is_active end |
#name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_trial_workflow_request.rb', line 14 def name @name end |
#units ⇒ Array[Unit]
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_trial_workflow_request.rb', line 22 def units @units end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_trial_workflow_request.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil is_active = hash.key?('is_active') ? hash['is_active'] : nil # Parameter is an array, so we need to iterate through it units = nil unless hash['units'].nil? units = [] hash['units'].each do |structure| units << (Unit.from_hash(structure) if structure) end end units = nil unless hash.key?('units') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreateTrialWorkflowRequest.new(name: name, is_active: is_active, units: units, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_trial_workflow_request.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['is_active'] = 'is_active' @_hash['units'] = 'units' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_trial_workflow_request.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_trial_workflow_request.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_trial_workflow_request.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, is_active: #{@is_active.inspect}, units:"\ " #{@units.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/sticky_io_restful_api_v2025731/models/create_trial_workflow_request.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, is_active: #{@is_active}, units: #{@units},"\ " additional_properties: #{@additional_properties}>" end |