Class: StickyIoRestfulApiV2025731::DataBillBySchedule
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::DataBillBySchedule
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb
Overview
DataBillBySchedule Model.
Instance Attribute Summary collapse
-
#buffer_days ⇒ Integer
TODO: Write general description for this method.
-
#created_at ⇒ CreatedAt
TODO: Write general description for this method.
-
#creator ⇒ Creator
TODO: Write general description for this method.
-
#date ⇒ Integer
TODO: Write general description for this method.
-
#dates ⇒ Array[DateData]
TODO: Write general description for this method.
-
#day ⇒ Integer
TODO: Write general description for this method.
-
#days ⇒ Integer
TODO: Write general description for this method.
-
#description ⇒ String
TODO: Write general description for this method.
-
#expire_cycles ⇒ Integer
TODO: Write general description for this method.
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#is_archived ⇒ Integer
TODO: Write general description for this method.
-
#is_default ⇒ String
TODO: Write general description for this method.
-
#is_preserve_quantity ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#type ⇒ TypeData
TODO: Write general description for this method.
-
#updated_at ⇒ UpdatedAtData
TODO: Write general description for this method.
-
#updator ⇒ String
TODO: Write general description for this method.
-
#week ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id:, name:, expire_cycles:, buffer_days:, created_at:, updated_at:, is_archived:, is_preserve_quantity:, is_default:, week:, day:, days:, date:, dates:, description:, type:, creator:, updator:, additional_properties: nil) ⇒ DataBillBySchedule
constructor
A new instance of DataBillBySchedule.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, name:, expire_cycles:, buffer_days:, created_at:, updated_at:, is_archived:, is_preserve_quantity:, is_default:, week:, day:, days:, date:, dates:, description:, type:, creator:, updator:, additional_properties: nil) ⇒ DataBillBySchedule
Returns a new instance of DataBillBySchedule.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 121 def initialize(id:, name:, expire_cycles:, buffer_days:, created_at:, updated_at:, is_archived:, is_preserve_quantity:, is_default:, week:, day:, days:, date:, dates:, description:, type:, creator:, updator:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @name = name @expire_cycles = expire_cycles @buffer_days = buffer_days @created_at = created_at @updated_at = updated_at @is_archived = is_archived @is_preserve_quantity = is_preserve_quantity @is_default = is_default @week = week @day = day @days = days @date = date @dates = dates @description = description @type = type @creator = creator @updator = updator @additional_properties = additional_properties end |
Instance Attribute Details
#buffer_days ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 26 def buffer_days @buffer_days end |
#created_at ⇒ CreatedAt
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 30 def created_at @created_at end |
#creator ⇒ Creator
TODO: Write general description for this method
78 79 80 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 78 def creator @creator end |
#date ⇒ Integer
TODO: Write general description for this method
62 63 64 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 62 def date @date end |
#dates ⇒ Array[DateData]
TODO: Write general description for this method
66 67 68 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 66 def dates @dates end |
#day ⇒ Integer
TODO: Write general description for this method
54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 54 def day @day end |
#days ⇒ Integer
TODO: Write general description for this method
58 59 60 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 58 def days @days end |
#description ⇒ String
TODO: Write general description for this method
70 71 72 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 70 def description @description end |
#expire_cycles ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 22 def expire_cycles @expire_cycles end |
#id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 14 def id @id end |
#is_archived ⇒ Integer
TODO: Write general description for this method
38 39 40 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 38 def is_archived @is_archived end |
#is_default ⇒ String
TODO: Write general description for this method
46 47 48 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 46 def is_default @is_default end |
#is_preserve_quantity ⇒ Integer
TODO: Write general description for this method
42 43 44 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 42 def is_preserve_quantity @is_preserve_quantity end |
#name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 18 def name @name end |
#type ⇒ TypeData
TODO: Write general description for this method
74 75 76 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 74 def type @type end |
#updated_at ⇒ UpdatedAtData
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 34 def updated_at @updated_at end |
#updator ⇒ String
TODO: Write general description for this method
82 83 84 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 82 def updator @updator end |
#week ⇒ Integer
TODO: Write general description for this method
50 51 52 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 50 def week @week end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 150 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil name = hash.key?('name') ? hash['name'] : nil expire_cycles = hash.key?('expire_cycles') ? hash['expire_cycles'] : nil buffer_days = hash.key?('buffer_days') ? hash['buffer_days'] : nil created_at = CreatedAt.from_hash(hash['created_at']) if hash['created_at'] updated_at = UpdatedAtData.from_hash(hash['updated_at']) if hash['updated_at'] is_archived = hash.key?('is_archived') ? hash['is_archived'] : nil is_preserve_quantity = hash.key?('is_preserve_quantity') ? hash['is_preserve_quantity'] : nil is_default = hash.key?('is_default') ? hash['is_default'] : nil week = hash.key?('week') ? hash['week'] : nil day = hash.key?('day') ? hash['day'] : nil days = hash.key?('days') ? hash['days'] : nil date = hash.key?('date') ? hash['date'] : nil # Parameter is an array, so we need to iterate through it dates = nil unless hash['dates'].nil? dates = [] hash['dates'].each do |structure| dates << (DateData.from_hash(structure) if structure) end end dates = nil unless hash.key?('dates') description = hash.key?('description') ? hash['description'] : nil type = TypeData.from_hash(hash['type']) if hash['type'] creator = Creator.from_hash(hash['creator']) if hash['creator'] updator = hash.key?('updator') ? hash['updator'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DataBillBySchedule.new(id: id, name: name, expire_cycles: expire_cycles, buffer_days: buffer_days, created_at: created_at, updated_at: updated_at, is_archived: is_archived, is_preserve_quantity: is_preserve_quantity, is_default: is_default, week: week, day: day, days: days, date: date, dates: dates, description: description, type: type, creator: creator, updator: updator, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 85 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['name'] = 'name' @_hash['expire_cycles'] = 'expire_cycles' @_hash['buffer_days'] = 'buffer_days' @_hash['created_at'] = 'created_at' @_hash['updated_at'] = 'updated_at' @_hash['is_archived'] = 'is_archived' @_hash['is_preserve_quantity'] = 'is_preserve_quantity' @_hash['is_default'] = 'is_default' @_hash['week'] = 'week' @_hash['day'] = 'day' @_hash['days'] = 'days' @_hash['date'] = 'date' @_hash['dates'] = 'dates' @_hash['description'] = 'description' @_hash['type'] = 'type' @_hash['creator'] = 'creator' @_hash['updator'] = 'updator' @_hash end |
.nullables ⇒ Object
An array for nullable fields
114 115 116 117 118 119 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 114 def self.nullables %w[ is_default updator ] end |
.optionals ⇒ Object
An array for optional fields
109 110 111 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 109 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 224 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, expire_cycles:"\ " #{@expire_cycles.inspect}, buffer_days: #{@buffer_days.inspect}, created_at:"\ " #{@created_at.inspect}, updated_at: #{@updated_at.inspect}, is_archived:"\ " #{@is_archived.inspect}, is_preserve_quantity: #{@is_preserve_quantity.inspect},"\ " is_default: #{@is_default.inspect}, week: #{@week.inspect}, day: #{@day.inspect}, days:"\ " #{@days.inspect}, date: #{@date.inspect}, dates: #{@dates.inspect}, description:"\ " #{@description.inspect}, type: #{@type.inspect}, creator: #{@creator.inspect}, updator:"\ " #{@updator.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
213 214 215 216 217 218 219 220 221 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_bill_by_schedule.rb', line 213 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, name: #{@name}, expire_cycles: #{@expire_cycles}, buffer_days:"\ " #{@buffer_days}, created_at: #{@created_at}, updated_at: #{@updated_at}, is_archived:"\ " #{@is_archived}, is_preserve_quantity: #{@is_preserve_quantity}, is_default:"\ " #{@is_default}, week: #{@week}, day: #{@day}, days: #{@days}, date: #{@date}, dates:"\ " #{@dates}, description: #{@description}, type: #{@type}, creator: #{@creator}, updator:"\ " #{@updator}, additional_properties: #{@additional_properties}>" end |