Class: StickyIoRestfulApiV2025731::DataBillingShippingTaxLocation
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::DataBillingShippingTaxLocation
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/data_billing_shipping_tax_location.rb
Overview
DataBillingShippingTaxLocation Model.
Instance Attribute Summary collapse
-
#discounts ⇒ Array[DiscountsData1]
TODO: Write general description for this method.
-
#line_items ⇒ Array[LineItemData]
TODO: Write general description for this method.
-
#shipping ⇒ String
TODO: Write general description for this method.
-
#subtotal ⇒ String
TODO: Write general description for this method.
-
#tax ⇒ Tax
TODO: Write general description for this method.
-
#total ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(total:, subtotal:, line_items:, shipping:, tax:, discounts:, additional_properties: nil) ⇒ DataBillingShippingTaxLocation
constructor
A new instance of DataBillingShippingTaxLocation.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(total:, subtotal:, line_items:, shipping:, tax:, discounts:, additional_properties: nil) ⇒ DataBillingShippingTaxLocation
Returns a new instance of DataBillingShippingTaxLocation.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_billing_shipping_tax_location.rb', line 58 def initialize(total:, subtotal:, line_items:, shipping:, tax:, discounts:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @total = total @subtotal = subtotal @line_items = line_items @shipping = shipping @tax = tax @discounts = discounts @additional_properties = additional_properties end |
Instance Attribute Details
#discounts ⇒ Array[DiscountsData1]
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_billing_shipping_tax_location.rb', line 34 def discounts @discounts end |
#line_items ⇒ Array[LineItemData]
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_billing_shipping_tax_location.rb', line 22 def line_items @line_items end |
#shipping ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_billing_shipping_tax_location.rb', line 26 def shipping @shipping end |
#subtotal ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_billing_shipping_tax_location.rb', line 18 def subtotal @subtotal end |
#tax ⇒ Tax
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_billing_shipping_tax_location.rb', line 30 def tax @tax end |
#total ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_billing_shipping_tax_location.rb', line 14 def total @total end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_billing_shipping_tax_location.rb', line 73 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. total = hash.key?('total') ? hash['total'] : nil subtotal = hash.key?('subtotal') ? hash['subtotal'] : nil # Parameter is an array, so we need to iterate through it line_items = nil unless hash['line_items'].nil? line_items = [] hash['line_items'].each do |structure| line_items << (LineItemData.from_hash(structure) if structure) end end line_items = nil unless hash.key?('line_items') shipping = hash.key?('shipping') ? hash['shipping'] : nil tax = Tax.from_hash(hash['tax']) if hash['tax'] # Parameter is an array, so we need to iterate through it discounts = nil unless hash['discounts'].nil? discounts = [] hash['discounts'].each do |structure| discounts << (DiscountsData1.from_hash(structure) if structure) end end discounts = nil unless hash.key?('discounts') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DataBillingShippingTaxLocation.new(total: total, subtotal: subtotal, line_items: line_items, shipping: shipping, tax: tax, discounts: discounts, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_billing_shipping_tax_location.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['total'] = 'total' @_hash['subtotal'] = 'subtotal' @_hash['line_items'] = 'line_items' @_hash['shipping'] = 'shipping' @_hash['tax'] = 'tax' @_hash['discounts'] = 'discounts' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_billing_shipping_tax_location.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_billing_shipping_tax_location.rb', line 49 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
128 129 130 131 132 133 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_billing_shipping_tax_location.rb', line 128 def inspect class_name = self.class.name.split('::').last "<#{class_name} total: #{@total.inspect}, subtotal: #{@subtotal.inspect}, line_items:"\ " #{@line_items.inspect}, shipping: #{@shipping.inspect}, tax: #{@tax.inspect}, discounts:"\ " #{@discounts.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
120 121 122 123 124 125 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_billing_shipping_tax_location.rb', line 120 def to_s class_name = self.class.name.split('::').last "<#{class_name} total: #{@total}, subtotal: #{@subtotal}, line_items: #{@line_items},"\ " shipping: #{@shipping}, tax: #{@tax}, discounts: #{@discounts}, additional_properties:"\ " #{@additional_properties}>" end |