Class: StickyIoRestfulApiV2025731::DataGetCountries
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::DataGetCountries
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/data_get_countries.rb
Overview
DataGetCountries Model.
Instance Attribute Summary collapse
-
#calling_code ⇒ String
TODO: Write general description for this method.
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#iso_2 ⇒ String
TODO: Write general description for this method.
-
#iso_3 ⇒ String
TODO: Write general description for this method.
-
#iso_numeric ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(iso_numeric:, calling_code:, id:, name:, iso_2:, iso_3:, additional_properties: nil) ⇒ DataGetCountries
constructor
A new instance of DataGetCountries.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(iso_numeric:, calling_code:, id:, name:, iso_2:, iso_3:, additional_properties: nil) ⇒ DataGetCountries
Returns a new instance of DataGetCountries.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_countries.rb', line 58 def initialize(iso_numeric:, calling_code:, id:, name:, iso_2:, iso_3:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @iso_numeric = iso_numeric @calling_code = calling_code @id = id @name = name @iso_2 = iso_2 @iso_3 = iso_3 @additional_properties = additional_properties end |
Instance Attribute Details
#calling_code ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_countries.rb', line 18 def calling_code @calling_code end |
#id ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_countries.rb', line 22 def id @id end |
#iso_2 ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_countries.rb', line 30 def iso_2 @iso_2 end |
#iso_3 ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_countries.rb', line 34 def iso_3 @iso_3 end |
#iso_numeric ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_countries.rb', line 14 def iso_numeric @iso_numeric end |
#name ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_countries.rb', line 26 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_countries.rb', line 73 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. iso_numeric = hash.key?('iso_numeric') ? hash['iso_numeric'] : nil calling_code = hash.key?('calling_code') ? hash['calling_code'] : nil id = hash.key?('id') ? hash['id'] : nil name = hash.key?('name') ? hash['name'] : nil iso_2 = hash.key?('iso_2') ? hash['iso_2'] : nil iso_3 = hash.key?('iso_3') ? hash['iso_3'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DataGetCountries.new(iso_numeric: iso_numeric, calling_code: calling_code, id: id, name: name, iso_2: iso_2, iso_3: iso_3, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_countries.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['iso_numeric'] = 'iso_numeric' @_hash['calling_code'] = 'calling_code' @_hash['id'] = 'id' @_hash['name'] = 'name' @_hash['iso_2'] = 'iso_2' @_hash['iso_3'] = 'iso_3' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_countries.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_countries.rb', line 49 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
110 111 112 113 114 115 116 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_countries.rb', line 110 def inspect class_name = self.class.name.split('::').last "<#{class_name} iso_numeric: #{@iso_numeric.inspect}, calling_code:"\ " #{@calling_code.inspect}, id: #{@id.inspect}, name: #{@name.inspect}, iso_2:"\ " #{@iso_2.inspect}, iso_3: #{@iso_3.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
102 103 104 105 106 107 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_countries.rb', line 102 def to_s class_name = self.class.name.split('::').last "<#{class_name} iso_numeric: #{@iso_numeric}, calling_code: #{@calling_code}, id: #{@id},"\ " name: #{@name}, iso_2: #{@iso_2}, iso_3: #{@iso_3}, additional_properties:"\ " #{@additional_properties}>" end |