Class: StickyIoRestfulApiV2025731::DataGetProspectInterests
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::DataGetProspectInterests
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/data_get_prospect_interests.rb
Overview
DataGetProspectInterests Model.
Instance Attribute Summary collapse
-
#contact_id ⇒ Integer
TODO: Write general description for this method.
-
#entity_id ⇒ Integer
TODO: Write general description for this method.
-
#entity_type_id ⇒ Integer
TODO: Write general description for this method.
-
#type_id ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(contact_id:, entity_type_id:, entity_id:, type_id:, additional_properties: nil) ⇒ DataGetProspectInterests
constructor
A new instance of DataGetProspectInterests.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(contact_id:, entity_type_id:, entity_id:, type_id:, additional_properties: nil) ⇒ DataGetProspectInterests
Returns a new instance of DataGetProspectInterests.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_prospect_interests.rb', line 48 def initialize(contact_id:, entity_type_id:, entity_id:, type_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @contact_id = contact_id @entity_type_id = entity_type_id @entity_id = entity_id @type_id = type_id @additional_properties = additional_properties end |
Instance Attribute Details
#contact_id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_prospect_interests.rb', line 14 def contact_id @contact_id end |
#entity_id ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_prospect_interests.rb', line 22 def entity_id @entity_id end |
#entity_type_id ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_prospect_interests.rb', line 18 def entity_type_id @entity_type_id end |
#type_id ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_prospect_interests.rb', line 26 def type_id @type_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_prospect_interests.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. contact_id = hash.key?('contact_id') ? hash['contact_id'] : nil entity_type_id = hash.key?('entity_type_id') ? hash['entity_type_id'] : nil entity_id = hash.key?('entity_id') ? hash['entity_id'] : nil type_id = hash.key?('type_id') ? hash['type_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DataGetProspectInterests.new(contact_id: contact_id, entity_type_id: entity_type_id, entity_id: entity_id, type_id: type_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_prospect_interests.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['contact_id'] = 'contact_id' @_hash['entity_type_id'] = 'entity_type_id' @_hash['entity_id'] = 'entity_id' @_hash['type_id'] = 'type_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_prospect_interests.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_prospect_interests.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 99 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_prospect_interests.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} contact_id: #{@contact_id.inspect}, entity_type_id:"\ " #{@entity_type_id.inspect}, entity_id: #{@entity_id.inspect}, type_id:"\ " #{@type_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_get_prospect_interests.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} contact_id: #{@contact_id}, entity_type_id: #{@entity_type_id}, entity_id:"\ " #{@entity_id}, type_id: #{@type_id}, additional_properties: #{@additional_properties}>" end |