Class: StickyIoRestfulApiV2025731::DataUpdateCategory
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::DataUpdateCategory
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/data_update_category.rb
Overview
DataUpdateCategory Model.
Instance Attribute Summary collapse
-
#created_by ⇒ String
TODO: Write general description for this method.
-
#description ⇒ String
TODO: Write general description for this method.
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#product_count ⇒ Integer
TODO: Write general description for this method.
-
#updated_by ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id:, name:, description:, product_count:, created_by:, updated_by:, additional_properties: nil) ⇒ DataUpdateCategory
constructor
A new instance of DataUpdateCategory.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, name:, description:, product_count:, created_by:, updated_by:, additional_properties: nil) ⇒ DataUpdateCategory
Returns a new instance of DataUpdateCategory.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_category.rb', line 58 def initialize(id:, name:, description:, product_count:, created_by:, updated_by:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @name = name @description = description @product_count = product_count @created_by = created_by @updated_by = updated_by @additional_properties = additional_properties end |
Instance Attribute Details
#created_by ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_category.rb', line 30 def created_by @created_by end |
#description ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_category.rb', line 22 def description @description end |
#id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_category.rb', line 14 def id @id end |
#name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_category.rb', line 18 def name @name end |
#product_count ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_category.rb', line 26 def product_count @product_count end |
#updated_by ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_category.rb', line 34 def updated_by @updated_by end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_category.rb', line 73 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil name = hash.key?('name') ? hash['name'] : nil description = hash.key?('description') ? hash['description'] : nil product_count = hash.key?('product_count') ? hash['product_count'] : nil created_by = hash.key?('created_by') ? hash['created_by'] : nil updated_by = hash.key?('updated_by') ? hash['updated_by'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DataUpdateCategory.new(id: id, name: name, description: description, product_count: product_count, created_by: created_by, updated_by: updated_by, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_category.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['name'] = 'name' @_hash['description'] = 'description' @_hash['product_count'] = 'product_count' @_hash['created_by'] = 'created_by' @_hash['updated_by'] = 'updated_by' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_category.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_category.rb', line 49 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
110 111 112 113 114 115 116 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_category.rb', line 110 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, description:"\ " #{@description.inspect}, product_count: #{@product_count.inspect}, created_by:"\ " #{@created_by.inspect}, updated_by: #{@updated_by.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
102 103 104 105 106 107 |
# File 'lib/sticky_io_restful_api_v2025731/models/data_update_category.rb', line 102 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, name: #{@name}, description: #{@description}, product_count:"\ " #{@product_count}, created_by: #{@created_by}, updated_by: #{@updated_by},"\ " additional_properties: #{@additional_properties}>" end |