Class: StickyIoRestfulApiV2025731::DatumGetBillingModels
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::DatumGetBillingModels
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb
Overview
DatumGetBillingModels Model.
Instance Attribute Summary collapse
-
#buffer_days ⇒ Integer
TODO: Write general description for this method.
-
#created_at ⇒ CreatedAt
TODO: Write general description for this method.
-
#creator ⇒ Creator
TODO: Write general description for this method.
-
#date ⇒ Integer
TODO: Write general description for this method.
-
#dates ⇒ Array[Object]
TODO: Write general description for this method.
-
#day ⇒ Integer
TODO: Write general description for this method.
-
#days ⇒ Integer
TODO: Write general description for this method.
-
#description ⇒ String
TODO: Write general description for this method.
-
#expire_cycles ⇒ Integer
TODO: Write general description for this method.
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#is_archived ⇒ Integer
TODO: Write general description for this method.
-
#is_default ⇒ Object
TODO: Write general description for this method.
-
#is_preserve_quantity ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#type ⇒ Object
TODO: Write general description for this method.
-
#updated_at ⇒ Object
TODO: Write general description for this method.
-
#updator ⇒ Object
TODO: Write general description for this method.
-
#week ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(id:, name:, expire_cycles:, buffer_days:, created_at:, updated_at:, is_archived:, is_preserve_quantity:, is_default:, week:, day:, days:, date:, dates:, description:, type:, creator:, updator:, additional_properties: nil) ⇒ DatumGetBillingModels
constructor
A new instance of DatumGetBillingModels.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, name:, expire_cycles:, buffer_days:, created_at:, updated_at:, is_archived:, is_preserve_quantity:, is_default:, week:, day:, days:, date:, dates:, description:, type:, creator:, updator:, additional_properties: nil) ⇒ DatumGetBillingModels
Returns a new instance of DatumGetBillingModels.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 120 def initialize(id:, name:, expire_cycles:, buffer_days:, created_at:, updated_at:, is_archived:, is_preserve_quantity:, is_default:, week:, day:, days:, date:, dates:, description:, type:, creator:, updator:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @name = name @expire_cycles = expire_cycles @buffer_days = buffer_days @created_at = created_at @updated_at = updated_at @is_archived = is_archived @is_preserve_quantity = is_preserve_quantity @is_default = is_default @week = week @day = day @days = days @date = date @dates = dates @description = description @type = type @creator = creator @updator = updator @additional_properties = additional_properties end |
Instance Attribute Details
#buffer_days ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 26 def buffer_days @buffer_days end |
#created_at ⇒ CreatedAt
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 30 def created_at @created_at end |
#creator ⇒ Creator
TODO: Write general description for this method
78 79 80 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 78 def creator @creator end |
#date ⇒ Integer
TODO: Write general description for this method
62 63 64 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 62 def date @date end |
#dates ⇒ Array[Object]
TODO: Write general description for this method
66 67 68 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 66 def dates @dates end |
#day ⇒ Integer
TODO: Write general description for this method
54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 54 def day @day end |
#days ⇒ Integer
TODO: Write general description for this method
58 59 60 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 58 def days @days end |
#description ⇒ String
TODO: Write general description for this method
70 71 72 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 70 def description @description end |
#expire_cycles ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 22 def expire_cycles @expire_cycles end |
#id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 14 def id @id end |
#is_archived ⇒ Integer
TODO: Write general description for this method
38 39 40 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 38 def is_archived @is_archived end |
#is_default ⇒ Object
TODO: Write general description for this method
46 47 48 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 46 def is_default @is_default end |
#is_preserve_quantity ⇒ Integer
TODO: Write general description for this method
42 43 44 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 42 def is_preserve_quantity @is_preserve_quantity end |
#name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 18 def name @name end |
#type ⇒ Object
TODO: Write general description for this method
74 75 76 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 74 def type @type end |
#updated_at ⇒ Object
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 34 def updated_at @updated_at end |
#updator ⇒ Object
TODO: Write general description for this method
82 83 84 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 82 def updator @updator end |
#week ⇒ Integer
TODO: Write general description for this method
50 51 52 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 50 def week @week end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 149 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil name = hash.key?('name') ? hash['name'] : nil expire_cycles = hash.key?('expire_cycles') ? hash['expire_cycles'] : nil buffer_days = hash.key?('buffer_days') ? hash['buffer_days'] : nil created_at = CreatedAt.from_hash(hash['created_at']) if hash['created_at'] updated_at = hash.key?('updated_at') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:DatumGetBillingModelsUpdatedAt), hash['updated_at'] ) : nil is_archived = hash.key?('is_archived') ? hash['is_archived'] : nil is_preserve_quantity = hash.key?('is_preserve_quantity') ? hash['is_preserve_quantity'] : nil is_default = hash.key?('is_default') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:DatumGetBillingModelsIsDefault), hash['is_default'] ) : nil week = hash.key?('week') ? hash['week'] : nil day = hash.key?('day') ? hash['day'] : nil days = hash.key?('days') ? hash['days'] : nil date = hash.key?('date') ? hash['date'] : nil dates = hash.key?('dates') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:DatumGetBillingModelsDates), hash['dates'] ) : nil description = hash.key?('description') ? hash['description'] : nil type = hash.key?('type') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:DatumGetBillingModelsType), hash['type'] ) : nil creator = Creator.from_hash(hash['creator']) if hash['creator'] updator = hash.key?('updator') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:DatumGetBillingModelsUpdator), hash['updator'] ) : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DatumGetBillingModels.new(id: id, name: name, expire_cycles: expire_cycles, buffer_days: buffer_days, created_at: created_at, updated_at: updated_at, is_archived: is_archived, is_preserve_quantity: is_preserve_quantity, is_default: is_default, week: week, day: day, days: days, date: date, dates: dates, description: description, type: type, creator: creator, updator: updator, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 85 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['name'] = 'name' @_hash['expire_cycles'] = 'expire_cycles' @_hash['buffer_days'] = 'buffer_days' @_hash['created_at'] = 'created_at' @_hash['updated_at'] = 'updated_at' @_hash['is_archived'] = 'is_archived' @_hash['is_preserve_quantity'] = 'is_preserve_quantity' @_hash['is_default'] = 'is_default' @_hash['week'] = 'week' @_hash['day'] = 'day' @_hash['days'] = 'days' @_hash['date'] = 'date' @_hash['dates'] = 'dates' @_hash['description'] = 'description' @_hash['type'] = 'type' @_hash['creator'] = 'creator' @_hash['updator'] = 'updator' @_hash end |
.nullables ⇒ Object
An array for nullable fields
114 115 116 117 118 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 114 def self.nullables %w[ is_default ] end |
.optionals ⇒ Object
An array for optional fields
109 110 111 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 109 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 214 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.id, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.name, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.expire_cycles, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.buffer_days, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.created_at, ->(val) { CreatedAt.validate(val) }, is_model_hash: true) and UnionTypeLookUp.get(:DatumGetBillingModelsUpdatedAt) .validate(value.updated_at) and APIHelper.valid_type?(value.is_archived, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.is_preserve_quantity, ->(val) { val.instance_of? Integer }) and UnionTypeLookUp.get(:DatumGetBillingModelsIsDefault) .validate(value.is_default) and APIHelper.valid_type?(value.week, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.day, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.days, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.date, ->(val) { val.instance_of? Integer }) and UnionTypeLookUp.get(:DatumGetBillingModelsDates) .validate(value.dates) and APIHelper.valid_type?(value.description, ->(val) { val.instance_of? String }) and UnionTypeLookUp.get(:DatumGetBillingModelsType) .validate(value.type) and APIHelper.valid_type?(value.creator, ->(val) { Creator.validate(val) }, is_model_hash: true) and UnionTypeLookUp.get(:DatumGetBillingModelsUpdator) .validate(value.updator) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['id'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['name'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['expire_cycles'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['buffer_days'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['created_at'], ->(val) { CreatedAt.validate(val) }, is_model_hash: true) and UnionTypeLookUp.get(:DatumGetBillingModelsUpdatedAt) .validate(value['updated_at']) and APIHelper.valid_type?(value['is_archived'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['is_preserve_quantity'], ->(val) { val.instance_of? Integer }) and UnionTypeLookUp.get(:DatumGetBillingModelsIsDefault) .validate(value['is_default']) and APIHelper.valid_type?(value['week'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['day'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['days'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['date'], ->(val) { val.instance_of? Integer }) and UnionTypeLookUp.get(:DatumGetBillingModelsDates) .validate(value['dates']) and APIHelper.valid_type?(value['description'], ->(val) { val.instance_of? String }) and UnionTypeLookUp.get(:DatumGetBillingModelsType) .validate(value['type']) and APIHelper.valid_type?(value['creator'], ->(val) { Creator.validate(val) }, is_model_hash: true) and UnionTypeLookUp.get(:DatumGetBillingModelsUpdator) .validate(value['updator']) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 314 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, expire_cycles:"\ " #{@expire_cycles.inspect}, buffer_days: #{@buffer_days.inspect}, created_at:"\ " #{@created_at.inspect}, updated_at: #{@updated_at.inspect}, is_archived:"\ " #{@is_archived.inspect}, is_preserve_quantity: #{@is_preserve_quantity.inspect},"\ " is_default: #{@is_default.inspect}, week: #{@week.inspect}, day: #{@day.inspect}, days:"\ " #{@days.inspect}, date: #{@date.inspect}, dates: #{@dates.inspect}, description:"\ " #{@description.inspect}, type: #{@type.inspect}, creator: #{@creator.inspect}, updator:"\ " #{@updator.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
303 304 305 306 307 308 309 310 311 |
# File 'lib/sticky_io_restful_api_v2025731/models/datum_get_billing_models.rb', line 303 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, name: #{@name}, expire_cycles: #{@expire_cycles}, buffer_days:"\ " #{@buffer_days}, created_at: #{@created_at}, updated_at: #{@updated_at}, is_archived:"\ " #{@is_archived}, is_preserve_quantity: #{@is_preserve_quantity}, is_default:"\ " #{@is_default}, week: #{@week}, day: #{@day}, days: #{@days}, date: #{@date}, dates:"\ " #{@dates}, description: #{@description}, type: #{@type}, creator: #{@creator}, updator:"\ " #{@updator}, additional_properties: #{@additional_properties}>" end |