Class: StickyIoRestfulApiV2025731::Discounts
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::Discounts
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/discounts.rb
Overview
Discounts Model.
Instance Attribute Summary collapse
-
#flat_amount ⇒ String
TODO: Write general description for this method.
-
#percent ⇒ Integer
TODO: Write general description for this method.
-
#prepaid ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(flat_amount:, percent:, prepaid:, additional_properties: nil) ⇒ Discounts
constructor
A new instance of Discounts.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(flat_amount:, percent:, prepaid:, additional_properties: nil) ⇒ Discounts
Returns a new instance of Discounts.
43 44 45 46 47 48 49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts.rb', line 43 def initialize(flat_amount:, percent:, prepaid:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @flat_amount = flat_amount @percent = percent @prepaid = prepaid @additional_properties = additional_properties end |
Instance Attribute Details
#flat_amount ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts.rb', line 14 def flat_amount @flat_amount end |
#percent ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts.rb', line 18 def percent @percent end |
#prepaid ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts.rb', line 22 def prepaid @prepaid end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. flat_amount = hash.key?('flat_amount') ? hash['flat_amount'] : nil percent = hash.key?('percent') ? hash['percent'] : nil prepaid = hash.key?('prepaid') ? hash['prepaid'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Discounts.new(flat_amount: flat_amount, percent: percent, prepaid: prepaid, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['flat_amount'] = 'flat_amount' @_hash['percent'] = 'percent' @_hash['prepaid'] = 'prepaid' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} flat_amount: #{@flat_amount.inspect}, percent: #{@percent.inspect},"\ " prepaid: #{@prepaid.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} flat_amount: #{@flat_amount}, percent: #{@percent}, prepaid: #{@prepaid},"\ " additional_properties: #{@additional_properties}>" end |