Class: StickyIoRestfulApiV2025731::DiscountsData
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::DiscountsData
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/discounts_data.rb
Overview
DiscountsData Model.
Instance Attribute Summary collapse
-
#code ⇒ String
TODO: Write general description for this method.
-
#error ⇒ String
TODO: Write general description for this method.
-
#total ⇒ String
TODO: Write general description for this method.
-
#type ⇒ String
TODO: Write general description for this method.
-
#valid ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(type:, code:, valid:, error:, total:, additional_properties: nil) ⇒ DiscountsData
constructor
A new instance of DiscountsData.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(type:, code:, valid:, error:, total:, additional_properties: nil) ⇒ DiscountsData
Returns a new instance of DiscountsData.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts_data.rb', line 53 def initialize(type:, code:, valid:, error:, total:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @type = type @code = code @valid = valid @error = error @total = total @additional_properties = additional_properties end |
Instance Attribute Details
#code ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts_data.rb', line 18 def code @code end |
#error ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts_data.rb', line 26 def error @error end |
#total ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts_data.rb', line 30 def total @total end |
#type ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts_data.rb', line 14 def type @type end |
#valid ⇒ TrueClass | FalseClass
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts_data.rb', line 22 def valid @valid end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts_data.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. type = hash.key?('type') ? hash['type'] : nil code = hash.key?('code') ? hash['code'] : nil valid = hash.key?('valid') ? hash['valid'] : nil error = hash.key?('error') ? hash['error'] : nil total = hash.key?('total') ? hash['total'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DiscountsData.new(type: type, code: code, valid: valid, error: error, total: total, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts_data.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['type'] = 'type' @_hash['code'] = 'code' @_hash['valid'] = 'valid' @_hash['error'] = 'error' @_hash['total'] = 'total' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts_data.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts_data.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 106 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts_data.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} type: #{@type.inspect}, code: #{@code.inspect}, valid: #{@valid.inspect},"\ " error: #{@error.inspect}, total: #{@total.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 |
# File 'lib/sticky_io_restful_api_v2025731/models/discounts_data.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} type: #{@type}, code: #{@code}, valid: #{@valid}, error: #{@error}, total:"\ " #{@total}, additional_properties: #{@additional_properties}>" end |