Class: StickyIoRestfulApiV2025731::LineItemData
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::LineItemData
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/line_item_data.rb
Overview
LineItemData Model.
Instance Attribute Summary collapse
-
#base_price ⇒ String
TODO: Write general description for this method.
-
#discount ⇒ DiscountLineItem
TODO: Write general description for this method.
-
#id ⇒ String
TODO: Write general description for this method.
-
#is_prepaid ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#is_shippable ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#is_taxable ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#product_price ⇒ String
TODO: Write general description for this method.
-
#qty ⇒ Integer
TODO: Write general description for this method.
-
#total ⇒ String
TODO: Write general description for this method.
-
#unit_price ⇒ String
TODO: Write general description for this method.
-
#variant_id ⇒ Integer
TODO: Write general description for this method.
-
#variant_price ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id:, name:, qty:, base_price:, unit_price:, product_price:, variant_price:, total:, is_taxable:, is_shippable:, is_prepaid:, variant_id:, discount:, additional_properties: nil) ⇒ LineItemData
constructor
A new instance of LineItemData.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, name:, qty:, base_price:, unit_price:, product_price:, variant_price:, total:, is_taxable:, is_shippable:, is_prepaid:, variant_id:, discount:, additional_properties: nil) ⇒ LineItemData
Returns a new instance of LineItemData.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 93 def initialize(id:, name:, qty:, base_price:, unit_price:, product_price:, variant_price:, total:, is_taxable:, is_shippable:, is_prepaid:, variant_id:, discount:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @name = name @qty = qty @base_price = base_price @unit_price = unit_price @product_price = product_price @variant_price = variant_price @total = total @is_taxable = is_taxable @is_shippable = is_shippable @is_prepaid = is_prepaid @variant_id = variant_id @discount = discount @additional_properties = additional_properties end |
Instance Attribute Details
#base_price ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 26 def base_price @base_price end |
#discount ⇒ DiscountLineItem
TODO: Write general description for this method
62 63 64 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 62 def discount @discount end |
#id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 14 def id @id end |
#is_prepaid ⇒ TrueClass | FalseClass
TODO: Write general description for this method
54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 54 def is_prepaid @is_prepaid end |
#is_shippable ⇒ TrueClass | FalseClass
TODO: Write general description for this method
50 51 52 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 50 def is_shippable @is_shippable end |
#is_taxable ⇒ TrueClass | FalseClass
TODO: Write general description for this method
46 47 48 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 46 def is_taxable @is_taxable end |
#name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 18 def name @name end |
#product_price ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 34 def product_price @product_price end |
#qty ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 22 def qty @qty end |
#total ⇒ String
TODO: Write general description for this method
42 43 44 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 42 def total @total end |
#unit_price ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 30 def unit_price @unit_price end |
#variant_id ⇒ Integer
TODO: Write general description for this method
58 59 60 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 58 def variant_id @variant_id end |
#variant_price ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 38 def variant_price @variant_price end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 117 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil name = hash.key?('name') ? hash['name'] : nil qty = hash.key?('qty') ? hash['qty'] : nil base_price = hash.key?('base_price') ? hash['base_price'] : nil unit_price = hash.key?('unit_price') ? hash['unit_price'] : nil product_price = hash.key?('product_price') ? hash['product_price'] : nil variant_price = hash.key?('variant_price') ? hash['variant_price'] : nil total = hash.key?('total') ? hash['total'] : nil is_taxable = hash.key?('is_taxable') ? hash['is_taxable'] : nil is_shippable = hash.key?('is_shippable') ? hash['is_shippable'] : nil is_prepaid = hash.key?('is_prepaid') ? hash['is_prepaid'] : nil variant_id = hash.key?('variant_id') ? hash['variant_id'] : nil discount = DiscountLineItem.from_hash(hash['discount']) if hash['discount'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LineItemData.new(id: id, name: name, qty: qty, base_price: base_price, unit_price: unit_price, product_price: product_price, variant_price: variant_price, total: total, is_taxable: is_taxable, is_shippable: is_shippable, is_prepaid: is_prepaid, variant_id: variant_id, discount: discount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 65 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['name'] = 'name' @_hash['qty'] = 'qty' @_hash['base_price'] = 'base_price' @_hash['unit_price'] = 'unit_price' @_hash['product_price'] = 'product_price' @_hash['variant_price'] = 'variant_price' @_hash['total'] = 'total' @_hash['is_taxable'] = 'is_taxable' @_hash['is_shippable'] = 'is_shippable' @_hash['is_prepaid'] = 'is_prepaid' @_hash['variant_id'] = 'variant_id' @_hash['discount'] = 'discount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
89 90 91 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 89 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
84 85 86 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 84 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
170 171 172 173 174 175 176 177 178 179 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 170 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, qty: #{@qty.inspect},"\ " base_price: #{@base_price.inspect}, unit_price: #{@unit_price.inspect}, product_price:"\ " #{@product_price.inspect}, variant_price: #{@variant_price.inspect}, total:"\ " #{@total.inspect}, is_taxable: #{@is_taxable.inspect}, is_shippable:"\ " #{@is_shippable.inspect}, is_prepaid: #{@is_prepaid.inspect}, variant_id:"\ " #{@variant_id.inspect}, discount: #{@discount.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
160 161 162 163 164 165 166 167 |
# File 'lib/sticky_io_restful_api_v2025731/models/line_item_data.rb', line 160 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, name: #{@name}, qty: #{@qty}, base_price: #{@base_price},"\ " unit_price: #{@unit_price}, product_price: #{@product_price}, variant_price:"\ " #{@variant_price}, total: #{@total}, is_taxable: #{@is_taxable}, is_shippable:"\ " #{@is_shippable}, is_prepaid: #{@is_prepaid}, variant_id: #{@variant_id}, discount:"\ " #{@discount}, additional_properties: #{@additional_properties}>" end |