Class: StickyIoRestfulApiV2025731::Note
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::Note
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/note.rb
Overview
Note Model.
Instance Attribute Summary collapse
-
#created_at ⇒ String
TODO: Write general description for this method.
-
#creator ⇒ Creator
TODO: Write general description for this method.
-
#deleted_at ⇒ String
TODO: Write general description for this method.
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#updated_at ⇒ String
TODO: Write general description for this method.
-
#updator ⇒ String
TODO: Write general description for this method.
-
#value ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(id: SKIP, value: SKIP, created_at: SKIP, updated_at: SKIP, deleted_at: SKIP, creator: SKIP, updator: SKIP, additional_properties: nil) ⇒ Note
constructor
A new instance of Note.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, value: SKIP, created_at: SKIP, updated_at: SKIP, deleted_at: SKIP, creator: SKIP, updator: SKIP, additional_properties: nil) ⇒ Note
Returns a new instance of Note.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/sticky_io_restful_api_v2025731/models/note.rb', line 74 def initialize(id: SKIP, value: SKIP, created_at: SKIP, updated_at: SKIP, deleted_at: SKIP, creator: SKIP, updator: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id unless id == SKIP @value = value unless value == SKIP @created_at = created_at unless created_at == SKIP @updated_at = updated_at unless updated_at == SKIP @deleted_at = deleted_at unless deleted_at == SKIP @creator = creator unless creator == SKIP @updator = updator unless updator == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#created_at ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/note.rb', line 22 def created_at @created_at end |
#creator ⇒ Creator
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/note.rb', line 34 def creator @creator end |
#deleted_at ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/note.rb', line 30 def deleted_at @deleted_at end |
#id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/note.rb', line 14 def id @id end |
#updated_at ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/note.rb', line 26 def updated_at @updated_at end |
#updator ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/sticky_io_restful_api_v2025731/models/note.rb', line 38 def updator @updator end |
#value ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/note.rb', line 18 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/sticky_io_restful_api_v2025731/models/note.rb', line 91 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP value = hash.key?('value') ? hash['value'] : SKIP created_at = hash.key?('created_at') ? hash['created_at'] : SKIP updated_at = hash.key?('updated_at') ? hash['updated_at'] : SKIP deleted_at = hash.key?('deleted_at') ? hash['deleted_at'] : SKIP creator = Creator.from_hash(hash['creator']) if hash['creator'] updator = hash.key?('updator') ? hash['updator'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Note.new(id: id, value: value, created_at: created_at, updated_at: updated_at, deleted_at: deleted_at, creator: creator, updator: updator, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/note.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['value'] = 'value' @_hash['created_at'] = 'created_at' @_hash['updated_at'] = 'updated_at' @_hash['deleted_at'] = 'deleted_at' @_hash['creator'] = 'creator' @_hash['updator'] = 'updator' @_hash end |
.nullables ⇒ Object
An array for nullable fields
67 68 69 70 71 72 |
# File 'lib/sticky_io_restful_api_v2025731/models/note.rb', line 67 def self.nullables %w[ deleted_at updator ] end |
.optionals ⇒ Object
An array for optional fields
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/sticky_io_restful_api_v2025731/models/note.rb', line 54 def self.optionals %w[ id value created_at updated_at deleted_at creator updator ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
123 124 125 126 127 128 129 |
# File 'lib/sticky_io_restful_api_v2025731/models/note.rb', line 123 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
140 141 142 143 144 145 146 |
# File 'lib/sticky_io_restful_api_v2025731/models/note.rb', line 140 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, value: #{@value.inspect}, created_at:"\ " #{@created_at.inspect}, updated_at: #{@updated_at.inspect}, deleted_at:"\ " #{@deleted_at.inspect}, creator: #{@creator.inspect}, updator: #{@updator.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
132 133 134 135 136 137 |
# File 'lib/sticky_io_restful_api_v2025731/models/note.rb', line 132 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, value: #{@value}, created_at: #{@created_at}, updated_at:"\ " #{@updated_at}, deleted_at: #{@deleted_at}, creator: #{@creator}, updator: #{@updator},"\ " additional_properties: #{@additional_properties}>" end |