Class: StickyIoRestfulApiV2025731::OfferCalculateOrderTotalRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::OfferCalculateOrderTotalRequest
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/offer_calculate_order_total_request.rb
Overview
OfferCalculateOrderTotalRequest Model.
Instance Attribute Summary collapse
-
#billing_model_id ⇒ Integer
TODO: Write general description for this method.
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#product_id ⇒ Integer
TODO: Write general description for this method.
-
#quantity ⇒ Integer
TODO: Write general description for this method.
-
#trial ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id:, product_id:, billing_model_id:, quantity:, trial:, additional_properties: nil) ⇒ OfferCalculateOrderTotalRequest
constructor
A new instance of OfferCalculateOrderTotalRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, product_id:, billing_model_id:, quantity:, trial:, additional_properties: nil) ⇒ OfferCalculateOrderTotalRequest
Returns a new instance of OfferCalculateOrderTotalRequest.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/sticky_io_restful_api_v2025731/models/offer_calculate_order_total_request.rb', line 53 def initialize(id:, product_id:, billing_model_id:, quantity:, trial:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @product_id = product_id @billing_model_id = billing_model_id @quantity = quantity @trial = trial @additional_properties = additional_properties end |
Instance Attribute Details
#billing_model_id ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/offer_calculate_order_total_request.rb', line 22 def billing_model_id @billing_model_id end |
#id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/offer_calculate_order_total_request.rb', line 14 def id @id end |
#product_id ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/offer_calculate_order_total_request.rb', line 18 def product_id @product_id end |
#quantity ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/offer_calculate_order_total_request.rb', line 26 def quantity @quantity end |
#trial ⇒ Integer
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/offer_calculate_order_total_request.rb', line 30 def trial @trial end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/sticky_io_restful_api_v2025731/models/offer_calculate_order_total_request.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil product_id = hash.key?('product_id') ? hash['product_id'] : nil billing_model_id = hash.key?('billing_model_id') ? hash['billing_model_id'] : nil quantity = hash.key?('quantity') ? hash['quantity'] : nil trial = hash.key?('trial') ? hash['trial'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OfferCalculateOrderTotalRequest.new(id: id, product_id: product_id, billing_model_id: billing_model_id, quantity: quantity, trial: trial, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/offer_calculate_order_total_request.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['product_id'] = 'product_id' @_hash['billing_model_id'] = 'billing_model_id' @_hash['quantity'] = 'quantity' @_hash['trial'] = 'trial' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/offer_calculate_order_total_request.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/offer_calculate_order_total_request.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
103 104 105 106 107 108 |
# File 'lib/sticky_io_restful_api_v2025731/models/offer_calculate_order_total_request.rb', line 103 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, product_id: #{@product_id.inspect}, billing_model_id:"\ " #{@billing_model_id.inspect}, quantity: #{@quantity.inspect}, trial: #{@trial.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
95 96 97 98 99 100 |
# File 'lib/sticky_io_restful_api_v2025731/models/offer_calculate_order_total_request.rb', line 95 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, product_id: #{@product_id}, billing_model_id:"\ " #{@billing_model_id}, quantity: #{@quantity}, trial: #{@trial}, additional_properties:"\ " #{@additional_properties}>" end |