Class: StickyIoRestfulApiV2025731::ProductOneOf0
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::ProductOneOf0
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/product_one_of0.rb
Overview
ProductOneOf0 Model.
Instance Attribute Summary collapse
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#is_bundle ⇒ Integer
TODO: Write general description for this method.
-
#is_custom_bundle ⇒ Integer
TODO: Write general description for this method.
-
#is_trial_allowed ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(is_trial_allowed: SKIP, id: SKIP, name: SKIP, is_bundle: SKIP, is_custom_bundle: SKIP, additional_properties: nil) ⇒ ProductOneOf0
constructor
A new instance of ProductOneOf0.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(is_trial_allowed: SKIP, id: SKIP, name: SKIP, is_bundle: SKIP, is_custom_bundle: SKIP, additional_properties: nil) ⇒ ProductOneOf0
Returns a new instance of ProductOneOf0.
59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/sticky_io_restful_api_v2025731/models/product_one_of0.rb', line 59 def initialize(is_trial_allowed: SKIP, id: SKIP, name: SKIP, is_bundle: SKIP, is_custom_bundle: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @is_trial_allowed = is_trial_allowed unless is_trial_allowed == SKIP @id = id unless id == SKIP @name = name unless name == SKIP @is_bundle = is_bundle unless is_bundle == SKIP @is_custom_bundle = is_custom_bundle unless is_custom_bundle == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#id ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/product_one_of0.rb', line 18 def id @id end |
#is_bundle ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/product_one_of0.rb', line 26 def is_bundle @is_bundle end |
#is_custom_bundle ⇒ Integer
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/product_one_of0.rb', line 30 def is_custom_bundle @is_custom_bundle end |
#is_trial_allowed ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/product_one_of0.rb', line 14 def is_trial_allowed @is_trial_allowed end |
#name ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/product_one_of0.rb', line 22 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/sticky_io_restful_api_v2025731/models/product_one_of0.rb', line 74 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. is_trial_allowed = hash.key?('is_trial_allowed') ? hash['is_trial_allowed'] : SKIP id = hash.key?('id') ? hash['id'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP is_bundle = hash.key?('is_bundle') ? hash['is_bundle'] : SKIP is_custom_bundle = hash.key?('is_custom_bundle') ? hash['is_custom_bundle'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProductOneOf0.new(is_trial_allowed: is_trial_allowed, id: id, name: name, is_bundle: is_bundle, is_custom_bundle: is_custom_bundle, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/product_one_of0.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['is_trial_allowed'] = 'is_trial_allowed' @_hash['id'] = 'id' @_hash['name'] = 'name' @_hash['is_bundle'] = 'is_bundle' @_hash['is_custom_bundle'] = 'is_custom_bundle' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 |
# File 'lib/sticky_io_restful_api_v2025731/models/product_one_of0.rb', line 55 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 50 51 52 |
# File 'lib/sticky_io_restful_api_v2025731/models/product_one_of0.rb', line 44 def self.optionals %w[ is_trial_allowed id name is_bundle is_custom_bundle ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
104 105 106 107 108 109 110 |
# File 'lib/sticky_io_restful_api_v2025731/models/product_one_of0.rb', line 104 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
121 122 123 124 125 126 |
# File 'lib/sticky_io_restful_api_v2025731/models/product_one_of0.rb', line 121 def inspect class_name = self.class.name.split('::').last "<#{class_name} is_trial_allowed: #{@is_trial_allowed.inspect}, id: #{@id.inspect}, name:"\ " #{@name.inspect}, is_bundle: #{@is_bundle.inspect}, is_custom_bundle:"\ " #{@is_custom_bundle.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
113 114 115 116 117 118 |
# File 'lib/sticky_io_restful_api_v2025731/models/product_one_of0.rb', line 113 def to_s class_name = self.class.name.split('::').last "<#{class_name} is_trial_allowed: #{@is_trial_allowed}, id: #{@id}, name: #{@name},"\ " is_bundle: #{@is_bundle}, is_custom_bundle: #{@is_custom_bundle}, additional_properties:"\ " #{@additional_properties}>" end |