Class: StickyIoRestfulApiV2025731::Representment
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::Representment
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/representment.rb
Overview
Representment Model.
Instance Attribute Summary collapse
-
#billing_address_1 ⇒ String
TODO: Write general description for this method.
-
#billing_city ⇒ String
TODO: Write general description for this method.
-
#billing_state ⇒ String
TODO: Write general description for this method.
-
#billing_zip ⇒ String
TODO: Write general description for this method.
-
#case_number ⇒ String
TODO: Write general description for this method.
-
#case_type ⇒ String
TODO: Write general description for this method.
-
#currency ⇒ String
TODO: Write general description for this method.
-
#dispute_amount ⇒ Integer
TODO: Write general description for this method.
-
#first_name ⇒ String
TODO: Write general description for this method.
-
#gateway_id ⇒ Integer
TODO: Write general description for this method.
-
#ip_address ⇒ String
TODO: Write general description for this method.
-
#last_name ⇒ String
TODO: Write general description for this method.
-
#order_id ⇒ String
TODO: Write general description for this method.
-
#posted_date_in ⇒ String
TODO: Write general description for this method.
-
#provider_alias ⇒ String
TODO: Write general description for this method.
-
#provider_mid ⇒ String
TODO: Write general description for this method.
-
#provider_status ⇒ String
TODO: Write general description for this method.
-
#provider_transaction_id ⇒ String
TODO: Write general description for this method.
-
#provider_verdict ⇒ String
TODO: Write general description for this method.
-
#reason_category ⇒ String
TODO: Write general description for this method.
-
#reason_code ⇒ String
TODO: Write general description for this method.
-
#transaction_date_in ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(provider_transaction_id:, provider_mid:, provider_alias:, gateway_id:, order_id:, reason_code:, reason_category:, case_number:, posted_date_in:, transaction_date_in:, dispute_amount:, first_name:, last_name:, billing_address_1:, billing_city:, billing_state:, billing_zip:, currency:, ip_address:, provider_status:, provider_verdict:, case_type:, additional_properties: nil) ⇒ Representment
constructor
A new instance of Representment.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(provider_transaction_id:, provider_mid:, provider_alias:, gateway_id:, order_id:, reason_code:, reason_category:, case_number:, posted_date_in:, transaction_date_in:, dispute_amount:, first_name:, last_name:, billing_address_1:, billing_city:, billing_state:, billing_zip:, currency:, ip_address:, provider_status:, provider_verdict:, case_type:, additional_properties: nil) ⇒ Representment
Returns a new instance of Representment.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 138 def initialize(provider_transaction_id:, provider_mid:, provider_alias:, gateway_id:, order_id:, reason_code:, reason_category:, case_number:, posted_date_in:, transaction_date_in:, dispute_amount:, first_name:, last_name:, billing_address_1:, billing_city:, billing_state:, billing_zip:, currency:, ip_address:, provider_status:, provider_verdict:, case_type:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @provider_transaction_id = provider_transaction_id @provider_mid = provider_mid @provider_alias = provider_alias @gateway_id = gateway_id @order_id = order_id @reason_code = reason_code @reason_category = reason_category @case_number = case_number @posted_date_in = posted_date_in @transaction_date_in = transaction_date_in @dispute_amount = dispute_amount @first_name = first_name @last_name = last_name @billing_address_1 = billing_address_1 @billing_city = billing_city @billing_state = billing_state @billing_zip = billing_zip @currency = currency @ip_address = ip_address @provider_status = provider_status @provider_verdict = provider_verdict @case_type = case_type @additional_properties = additional_properties end |
Instance Attribute Details
#billing_address_1 ⇒ String
TODO: Write general description for this method
66 67 68 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 66 def billing_address_1 @billing_address_1 end |
#billing_city ⇒ String
TODO: Write general description for this method
70 71 72 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 70 def billing_city @billing_city end |
#billing_state ⇒ String
TODO: Write general description for this method
74 75 76 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 74 def billing_state @billing_state end |
#billing_zip ⇒ String
TODO: Write general description for this method
78 79 80 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 78 def billing_zip @billing_zip end |
#case_number ⇒ String
TODO: Write general description for this method
42 43 44 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 42 def case_number @case_number end |
#case_type ⇒ String
TODO: Write general description for this method
98 99 100 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 98 def case_type @case_type end |
#currency ⇒ String
TODO: Write general description for this method
82 83 84 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 82 def currency @currency end |
#dispute_amount ⇒ Integer
TODO: Write general description for this method
54 55 56 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 54 def dispute_amount @dispute_amount end |
#first_name ⇒ String
TODO: Write general description for this method
58 59 60 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 58 def first_name @first_name end |
#gateway_id ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 26 def gateway_id @gateway_id end |
#ip_address ⇒ String
TODO: Write general description for this method
86 87 88 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 86 def ip_address @ip_address end |
#last_name ⇒ String
TODO: Write general description for this method
62 63 64 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 62 def last_name @last_name end |
#order_id ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 30 def order_id @order_id end |
#posted_date_in ⇒ String
TODO: Write general description for this method
46 47 48 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 46 def posted_date_in @posted_date_in end |
#provider_alias ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 22 def provider_alias @provider_alias end |
#provider_mid ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 18 def provider_mid @provider_mid end |
#provider_status ⇒ String
TODO: Write general description for this method
90 91 92 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 90 def provider_status @provider_status end |
#provider_transaction_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 14 def provider_transaction_id @provider_transaction_id end |
#provider_verdict ⇒ String
TODO: Write general description for this method
94 95 96 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 94 def provider_verdict @provider_verdict end |
#reason_category ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 38 def reason_category @reason_category end |
#reason_code ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 34 def reason_code @reason_code end |
#transaction_date_in ⇒ String
TODO: Write general description for this method
50 51 52 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 50 def transaction_date_in @transaction_date_in end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 174 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. provider_transaction_id = hash.key?('provider_transaction_id') ? hash['provider_transaction_id'] : nil provider_mid = hash.key?('provider_mid') ? hash['provider_mid'] : nil provider_alias = hash.key?('provider_alias') ? hash['provider_alias'] : nil gateway_id = hash.key?('gateway_id') ? hash['gateway_id'] : nil order_id = hash.key?('order_id') ? hash['order_id'] : nil reason_code = hash.key?('reason_code') ? hash['reason_code'] : nil reason_category = hash.key?('reason_category') ? hash['reason_category'] : nil case_number = hash.key?('case_number') ? hash['case_number'] : nil posted_date_in = hash.key?('posted_date_in') ? hash['posted_date_in'] : nil transaction_date_in = hash.key?('transaction_date_in') ? hash['transaction_date_in'] : nil dispute_amount = hash.key?('dispute_amount') ? hash['dispute_amount'] : nil first_name = hash.key?('first_name') ? hash['first_name'] : nil last_name = hash.key?('last_name') ? hash['last_name'] : nil billing_address_1 = hash.key?('billing_address_1') ? hash['billing_address_1'] : nil billing_city = hash.key?('billing_city') ? hash['billing_city'] : nil billing_state = hash.key?('billing_state') ? hash['billing_state'] : nil billing_zip = hash.key?('billing_zip') ? hash['billing_zip'] : nil currency = hash.key?('currency') ? hash['currency'] : nil ip_address = hash.key?('ip_address') ? hash['ip_address'] : nil provider_status = hash.key?('provider_status') ? hash['provider_status'] : nil provider_verdict = hash.key?('provider_verdict') ? hash['provider_verdict'] : nil case_type = hash.key?('case_type') ? hash['case_type'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Representment.new(provider_transaction_id: provider_transaction_id, provider_mid: provider_mid, provider_alias: provider_alias, gateway_id: gateway_id, order_id: order_id, reason_code: reason_code, reason_category: reason_category, case_number: case_number, posted_date_in: posted_date_in, transaction_date_in: transaction_date_in, dispute_amount: dispute_amount, first_name: first_name, last_name: last_name, billing_address_1: billing_address_1, billing_city: billing_city, billing_state: billing_state, billing_zip: billing_zip, currency: currency, ip_address: ip_address, provider_status: provider_status, provider_verdict: provider_verdict, case_type: case_type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 101 def self.names @_hash = {} if @_hash.nil? @_hash['provider_transaction_id'] = 'provider_transaction_id' @_hash['provider_mid'] = 'provider_mid' @_hash['provider_alias'] = 'provider_alias' @_hash['gateway_id'] = 'gateway_id' @_hash['order_id'] = 'order_id' @_hash['reason_code'] = 'reason_code' @_hash['reason_category'] = 'reason_category' @_hash['case_number'] = 'case_number' @_hash['posted_date_in'] = 'posted_date_in' @_hash['transaction_date_in'] = 'transaction_date_in' @_hash['dispute_amount'] = 'dispute_amount' @_hash['first_name'] = 'first_name' @_hash['last_name'] = 'last_name' @_hash['billing_address_1'] = 'billing_address_1' @_hash['billing_city'] = 'billing_city' @_hash['billing_state'] = 'billing_state' @_hash['billing_zip'] = 'billing_zip' @_hash['currency'] = 'currency' @_hash['ip_address'] = 'ip_address' @_hash['provider_status'] = 'provider_status' @_hash['provider_verdict'] = 'provider_verdict' @_hash['case_type'] = 'case_type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
134 135 136 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 134 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
129 130 131 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 129 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 259 def inspect class_name = self.class.name.split('::').last "<#{class_name} provider_transaction_id: #{@provider_transaction_id.inspect}, provider_mid:"\ " #{@provider_mid.inspect}, provider_alias: #{@provider_alias.inspect}, gateway_id:"\ " #{@gateway_id.inspect}, order_id: #{@order_id.inspect}, reason_code:"\ " #{@reason_code.inspect}, reason_category: #{@reason_category.inspect}, case_number:"\ " #{@case_number.inspect}, posted_date_in: #{@posted_date_in.inspect}, transaction_date_in:"\ " #{@transaction_date_in.inspect}, dispute_amount: #{@dispute_amount.inspect}, first_name:"\ " #{@first_name.inspect}, last_name: #{@last_name.inspect}, billing_address_1:"\ " #{@billing_address_1.inspect}, billing_city: #{@billing_city.inspect}, billing_state:"\ " #{@billing_state.inspect}, billing_zip: #{@billing_zip.inspect}, currency:"\ " #{@currency.inspect}, ip_address: #{@ip_address.inspect}, provider_status:"\ " #{@provider_status.inspect}, provider_verdict: #{@provider_verdict.inspect}, case_type:"\ " #{@case_type.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/sticky_io_restful_api_v2025731/models/representment.rb', line 244 def to_s class_name = self.class.name.split('::').last "<#{class_name} provider_transaction_id: #{@provider_transaction_id}, provider_mid:"\ " #{@provider_mid}, provider_alias: #{@provider_alias}, gateway_id: #{@gateway_id},"\ " order_id: #{@order_id}, reason_code: #{@reason_code}, reason_category:"\ " #{@reason_category}, case_number: #{@case_number}, posted_date_in: #{@posted_date_in},"\ " transaction_date_in: #{@transaction_date_in}, dispute_amount: #{@dispute_amount},"\ " first_name: #{@first_name}, last_name: #{@last_name}, billing_address_1:"\ " #{@billing_address_1}, billing_city: #{@billing_city}, billing_state: #{@billing_state},"\ " billing_zip: #{@billing_zip}, currency: #{@currency}, ip_address: #{@ip_address},"\ " provider_status: #{@provider_status}, provider_verdict: #{@provider_verdict}, case_type:"\ " #{@case_type}, additional_properties: #{@additional_properties}>" end |