Class: StickyIoRestfulApiV2025731::TokenizePaymentRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::TokenizePaymentRequest
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/tokenize_payment_request.rb
Overview
TokenizePaymentRequest Model.
Instance Attribute Summary collapse
-
#brand ⇒ String
TODO: Write general description for this method.
-
#card_number ⇒ String
TODO: Write general description for this method.
-
#cvv ⇒ String
TODO: Write general description for this method.
-
#expiry ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(card_number:, cvv:, expiry:, brand:, additional_properties: nil) ⇒ TokenizePaymentRequest
constructor
A new instance of TokenizePaymentRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(card_number:, cvv:, expiry:, brand:, additional_properties: nil) ⇒ TokenizePaymentRequest
Returns a new instance of TokenizePaymentRequest.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/sticky_io_restful_api_v2025731/models/tokenize_payment_request.rb', line 48 def initialize(card_number:, cvv:, expiry:, brand:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @card_number = card_number @cvv = cvv @expiry = expiry @brand = brand @additional_properties = additional_properties end |
Instance Attribute Details
#brand ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/tokenize_payment_request.rb', line 26 def brand @brand end |
#card_number ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/tokenize_payment_request.rb', line 14 def card_number @card_number end |
#cvv ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/tokenize_payment_request.rb', line 18 def cvv @cvv end |
#expiry ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/tokenize_payment_request.rb', line 22 def expiry @expiry end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/sticky_io_restful_api_v2025731/models/tokenize_payment_request.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. card_number = hash.key?('card_number') ? hash['card_number'] : nil cvv = hash.key?('cvv') ? hash['cvv'] : nil expiry = hash.key?('expiry') ? hash['expiry'] : nil brand = hash.key?('brand') ? hash['brand'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TokenizePaymentRequest.new(card_number: card_number, cvv: cvv, expiry: expiry, brand: brand, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/tokenize_payment_request.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['card_number'] = 'card_number' @_hash['cvv'] = 'cvv' @_hash['expiry'] = 'expiry' @_hash['brand'] = 'brand' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/tokenize_payment_request.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/tokenize_payment_request.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 98 |
# File 'lib/sticky_io_restful_api_v2025731/models/tokenize_payment_request.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} card_number: #{@card_number.inspect}, cvv: #{@cvv.inspect}, expiry:"\ " #{@expiry.inspect}, brand: #{@brand.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/sticky_io_restful_api_v2025731/models/tokenize_payment_request.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} card_number: #{@card_number}, cvv: #{@cvv}, expiry: #{@expiry}, brand:"\ " #{@brand}, additional_properties: #{@additional_properties}>" end |