Class: StickyIoRestfulApiV2025731::TypeShippingProfile
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::TypeShippingProfile
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/type_shipping_profile.rb
Overview
TypeShippingProfile Model.
Instance Attribute Summary collapse
-
#code ⇒ String
TODO: Write general description for this method.
-
#created_at ⇒ CreatedAt
TODO: Write general description for this method.
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#updated_at ⇒ Object
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(id:, name:, code:, created_at:, updated_at:, additional_properties: nil) ⇒ TypeShippingProfile
constructor
A new instance of TypeShippingProfile.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, name:, code:, created_at:, updated_at:, additional_properties: nil) ⇒ TypeShippingProfile
Returns a new instance of TypeShippingProfile.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/sticky_io_restful_api_v2025731/models/type_shipping_profile.rb', line 53 def initialize(id:, name:, code:, created_at:, updated_at:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @name = name @code = code @created_at = created_at @updated_at = updated_at @additional_properties = additional_properties end |
Instance Attribute Details
#code ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/type_shipping_profile.rb', line 22 def code @code end |
#created_at ⇒ CreatedAt
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/type_shipping_profile.rb', line 26 def created_at @created_at end |
#id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/type_shipping_profile.rb', line 14 def id @id end |
#name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/type_shipping_profile.rb', line 18 def name @name end |
#updated_at ⇒ Object
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/type_shipping_profile.rb', line 30 def updated_at @updated_at end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/sticky_io_restful_api_v2025731/models/type_shipping_profile.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil name = hash.key?('name') ? hash['name'] : nil code = hash.key?('code') ? hash['code'] : nil created_at = CreatedAt.from_hash(hash['created_at']) if hash['created_at'] updated_at = hash.key?('updated_at') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:TypeShippingProfileUpdatedAt), hash['updated_at'] ) : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TypeShippingProfile.new(id: id, name: name, code: code, created_at: created_at, updated_at: updated_at, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/type_shipping_profile.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['name'] = 'name' @_hash['code'] = 'code' @_hash['created_at'] = 'created_at' @_hash['updated_at'] = 'updated_at' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/sticky_io_restful_api_v2025731/models/type_shipping_profile.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/type_shipping_profile.rb', line 44 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/sticky_io_restful_api_v2025731/models/type_shipping_profile.rb', line 97 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.id, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.name, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.code, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.created_at, ->(val) { CreatedAt.validate(val) }, is_model_hash: true) and UnionTypeLookUp.get(:TypeShippingProfileUpdatedAt) .validate(value.updated_at) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['id'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['name'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['code'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['created_at'], ->(val) { CreatedAt.validate(val) }, is_model_hash: true) and UnionTypeLookUp.get(:TypeShippingProfileUpdatedAt) .validate(value['updated_at']) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
139 140 141 142 143 144 |
# File 'lib/sticky_io_restful_api_v2025731/models/type_shipping_profile.rb', line 139 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, code: #{@code.inspect},"\ " created_at: #{@created_at.inspect}, updated_at: #{@updated_at.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
132 133 134 135 136 |
# File 'lib/sticky_io_restful_api_v2025731/models/type_shipping_profile.rb', line 132 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, name: #{@name}, code: #{@code}, created_at: #{@created_at},"\ " updated_at: #{@updated_at}, additional_properties: #{@additional_properties}>" end |