Class: StickyIoRestfulApiV2025731::UpdateProductVariantRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::UpdateProductVariantRequest
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/update_product_variant_request.rb
Overview
UpdateProductVariantRequest Model.
Instance Attribute Summary collapse
-
#price ⇒ Float
TODO: Write general description for this method.
-
#quantity ⇒ Float
TODO: Write general description for this method.
-
#sku_num ⇒ String
TODO: Write general description for this method.
-
#weight ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(price:, quantity:, weight:, sku_num:, additional_properties: nil) ⇒ UpdateProductVariantRequest
constructor
A new instance of UpdateProductVariantRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(price:, quantity:, weight:, sku_num:, additional_properties: nil) ⇒ UpdateProductVariantRequest
Returns a new instance of UpdateProductVariantRequest.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_variant_request.rb', line 48 def initialize(price:, quantity:, weight:, sku_num:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @price = price @quantity = quantity @weight = weight @sku_num = sku_num @additional_properties = additional_properties end |
Instance Attribute Details
#price ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_variant_request.rb', line 14 def price @price end |
#quantity ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_variant_request.rb', line 18 def quantity @quantity end |
#sku_num ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_variant_request.rb', line 26 def sku_num @sku_num end |
#weight ⇒ Float
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_variant_request.rb', line 22 def weight @weight end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_variant_request.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. price = hash.key?('price') ? hash['price'] : nil quantity = hash.key?('quantity') ? hash['quantity'] : nil weight = hash.key?('weight') ? hash['weight'] : nil sku_num = hash.key?('sku_num') ? hash['sku_num'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UpdateProductVariantRequest.new(price: price, quantity: quantity, weight: weight, sku_num: sku_num, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_variant_request.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['price'] = 'price' @_hash['quantity'] = 'quantity' @_hash['weight'] = 'weight' @_hash['sku_num'] = 'sku_num' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_variant_request.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_variant_request.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 98 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_variant_request.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} price: #{@price.inspect}, quantity: #{@quantity.inspect}, weight:"\ " #{@weight.inspect}, sku_num: #{@sku_num.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/sticky_io_restful_api_v2025731/models/update_product_variant_request.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} price: #{@price}, quantity: #{@quantity}, weight: #{@weight}, sku_num:"\ " #{@sku_num}, additional_properties: #{@additional_properties}>" end |