Class: StickyIoRestfulApiV2025731::Updator
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- StickyIoRestfulApiV2025731::Updator
- Defined in:
- lib/sticky_io_restful_api_v2025731/models/updator.rb
Overview
Updator Model.
Instance Attribute Summary collapse
-
#call_center_provider_id ⇒ Integer
TODO: Write general description for this method.
-
#department_id ⇒ Integer
TODO: Write general description for this method.
-
#email ⇒ String
TODO: Write general description for this method.
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#is_active ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(department_id: SKIP, id: SKIP, is_active: SKIP, name: SKIP, email: SKIP, call_center_provider_id: SKIP, additional_properties: nil) ⇒ Updator
constructor
A new instance of Updator.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(department_id: SKIP, id: SKIP, is_active: SKIP, name: SKIP, email: SKIP, call_center_provider_id: SKIP, additional_properties: nil) ⇒ Updator
Returns a new instance of Updator.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator.rb', line 65 def initialize(department_id: SKIP, id: SKIP, is_active: SKIP, name: SKIP, email: SKIP, call_center_provider_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @department_id = department_id unless department_id == SKIP @id = id unless id == SKIP @is_active = is_active unless is_active == SKIP @name = name unless name == SKIP @email = email unless email == SKIP @call_center_provider_id = call_center_provider_id unless call_center_provider_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#call_center_provider_id ⇒ Integer
TODO: Write general description for this method
34 35 36 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator.rb', line 34 def call_center_provider_id @call_center_provider_id end |
#department_id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator.rb', line 14 def department_id @department_id end |
#email ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator.rb', line 30 def email @email end |
#id ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator.rb', line 18 def id @id end |
#is_active ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator.rb', line 22 def is_active @is_active end |
#name ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator.rb', line 26 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator.rb', line 81 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. department_id = hash.key?('department_id') ? hash['department_id'] : SKIP id = hash.key?('id') ? hash['id'] : SKIP is_active = hash.key?('is_active') ? hash['is_active'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP email = hash.key?('email') ? hash['email'] : SKIP call_center_provider_id = hash.key?('call_center_provider_id') ? hash['call_center_provider_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Updator.new(department_id: department_id, id: id, is_active: is_active, name: name, email: email, call_center_provider_id: call_center_provider_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['department_id'] = 'department_id' @_hash['id'] = 'id' @_hash['is_active'] = 'is_active' @_hash['name'] = 'name' @_hash['email'] = 'email' @_hash['call_center_provider_id'] = 'call_center_provider_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
61 62 63 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator.rb', line 61 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator.rb', line 49 def self.optionals %w[ department_id id is_active name email call_center_provider_id ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
112 113 114 115 116 117 118 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator.rb', line 112 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
129 130 131 132 133 134 135 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator.rb', line 129 def inspect class_name = self.class.name.split('::').last "<#{class_name} department_id: #{@department_id.inspect}, id: #{@id.inspect}, is_active:"\ " #{@is_active.inspect}, name: #{@name.inspect}, email: #{@email.inspect},"\ " call_center_provider_id: #{@call_center_provider_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
121 122 123 124 125 126 |
# File 'lib/sticky_io_restful_api_v2025731/models/updator.rb', line 121 def to_s class_name = self.class.name.split('::').last "<#{class_name} department_id: #{@department_id}, id: #{@id}, is_active: #{@is_active},"\ " name: #{@name}, email: #{@email}, call_center_provider_id: #{@call_center_provider_id},"\ " additional_properties: #{@additional_properties}>" end |